4rddldlurruu8lddlldd3(rdr)urruuruul2(udrddlddr)uul4druuluu3r3dllrr4urr3dlr3ulld3luu3l3druul4dr3uluurr3ururrdrdrr3d4urrdlu3rdlu3l3dlldd3ldlluluurr3urur4urr3du3rdllu4rdldulu3luull4drdr3dulldrruurrulrruruuludll3drruululddldduruu3ru3rd4l3dldd3ruuruuddldd3luulullddlld3ld2(drdrr)ur3(ru)dldldlld2(llulu)u3rurruurrdluld4r3uluurdrruld3l3d3ul4urrdrrddrdrruldlldlluuldlurrddrrulr4uldlldd3ullullurrluuluurdl3urdlddrdrr3ullddldrddl4d3rdrrdrr3urrddrdlrdl3dlddlruur8uld4lulluururrd3rddrdl3u3l4ulr3dlldlddrrdrrurd3lur3luul5urrdrr4d3rdduu3luurrdulldllurdr3dlluurlddrddl3ud3rdlrrddlurul4dr3uluuluudd3ldrdrul3druu4dl6uluur3l4dr4dldld4lulul4uruur3d5u6r4lddlruu3ldrddld3luulldruruurrdrrurr3u3r4lddr4ul3dr5ul3dr6drr4ldld3luurur3uruuldr3urlldrddldll3urrll3drrdd3lul3url3drdrrdd3l3u3drrdd3rur3u5ruruu3ldlldr3ull3(rd)l3dlluululuu3rurduurddl4urdld3(drr)lldlddru3lurlldluldldlu4l3dllurd3lurd3r3u3lddrrdruud3luu3rdd3rudlddrr4dll4udd3lurruu3d4lu3rlluu3rddurruudldrr4dll3u5dlldd3ulldru3ldrrurrd3rdd6luudd4rddlururuud3rdllrddrddluulluu6rddrddlu3ldlur3dlur4uddrruuddrddlur3dluuddrruuluu3rdrddllrruuluurd3luluu3rdu3ldllulullu3lulldldd3rdrr4drrd3r3lull4ulldlludrrddrl3urrururrdrdrr4dld3lulludrrd3rurrurlluldruuru3lulullu3luluuruulld3lurrdrruulururuu3lddldduuruu3rddl7dldldd2(rddr)rdrrd3rdrudru3rurrur3(ru)uruur8uluulu3(ul)lullu3lulduld3ldlldl3(ld)urururrurru8rdrrdr3(rd)drddr8dlddld3(dl)ldlld8lullull3urrdrrdrrllu3lruuruul3duu3rdllulduullulldrrdduul4ulldru3lur3uruurlddl3dlddru3r3dldll3ulur4drrurrdl3uld4ud3rur5dlruulurul3drddru3d3rdrr3dllurdrudru5lullrruurrdrru3luldrrd4ru6l
