3u3rudllurd5ludrruruulddldrurdrrulluurdlddrruld3rull4ruu3ldurdurr3d3l6drluurdl3uruddrrulldlu3druurrdlullddrul3druu4drr3ulrdlrdd3l3u6ldurrdlu3rdrllddruulur3ldrrddluruulldru3ldrr4lu3ruuldrdlr4ulddulldrrur3u3rddld3lddrddl3u3dllurdrull3d3rudludll3u3ruuldruurruruu4lulld3r4duuldllurrdrudrrurrd4l3r3ullulldrldull3u3rduldduullddr
