d12luulldl3ulurl4urdu9rddlld3ldlddrd3ldl3udd3r4u4rurrddrrdld6l6ruuluulld3lddld3u4rurrddrdd6ld3ldluud4ruuldrd3ldluruld3ru7ruuldrd6luldrd3ldlu3r5u3lul3d4u5rdluldu10rdllul5drd6luldrd4l3ru6r3u5l5r3u3ld3ld3luldd3u3rdrd3luld4r4drdllrddruul4u4ru3rddrdld6lulddrd3lurru7ruuldrd6lulddrdllrd8ruu3ruuruuluru5lul5drd6luldrd3ldrrd8ruu3r5uru3ldrlullul5drd6lulddrdllrd8ruu3r5uru5lul5drd6luldrdll
