ldllddrr3drr3(dl)rruurrdrr3dluluruu3lddruluu2(rrdl)rddluurrdl3dl3uruulu4ldldl3drdru3rud5l3urrd4rdrdrulluurd3lurrd4l3u3rdurdduu4l4durruuddrddllul3u3rlddldluulurrldlldr3l3(ul)uuruurr3u3ruurr3urr3drrdd3rdd3lu3dll3d3(ru)l3ulluuddrrd3ruul4(lu)ull3dlldd3lddlddll3d3(rd)3ruurr4ulluurrd4urrddrr5dll3u6dldlddrr3u3(ru)l4u4rddrr3d3(lu)drdrddlulud3r3u3(ld)llul5ulluull4drr3drdld5ull4urrddrrd4rdrdld4rululdllddldllul4u4ru3drruulrdd3rululd2(lluu)rrddurul4d6u3rdrdldlr3u3lddrrdrddllrruulull3dulldr4l4drdrrur4u4ldd3r3luu3r3urrddlddrld3uruurrdluluurdldd3rdd4luurdurruldrrddlluluurrdldllu3lululu3(ur)rdrdrldrr4dllulurddrr4ullddrlddu3luluu3r5l3ururu3rdrdlddrdduuluurrdrdululluu3ldldrldrurr4l3d5ruululluuruu3(ld)urdrddldduururulluurddldd4luururrdrruulddu3ldllurlluurur3dldrurdrrurr3uld3ldldd3ruudd3luururrdrldd3lddrddluluudluurrl3druu4dl3u5d4luull3urdrduluurd4r6l3drurud4rdrul3dllu3luu3l3(dr)ud3r3ldrdruddlldd3l3(ur)ldldlluluuru3rurrddlu4lddrulu3rllddrrudlluuruulldldururrddlddrddlludrd3r2(ulrr)uuluulludrrddlluludr4d3urrdrdllru3(ur)r4u3ldl4drrurruu3l3rdd3l4dll3d3(rd)rrurr3ululu3lrdllru3rdrdrddldd3lul4udd3ldrdrd3r3luuru2(ldrd)rluu3rluudll3ururrdl3dll3url3drruulul3duur3ul3u3ruurruuldd4luu3r4d3l4d3rulldlur3drdruuldluruu3rdrrdd4ldlu5ruuldl5urrddrr3dlld3l3rurrdllrr4ulldlr3ull3dlluurdluulldrurd3ulldu4ruu2(rrdd)rd3rdrrdrdld6lddrdrrurudldlluluu4rurluldr3dldllul8u6d3ruullrrdd3l3u5drdrruurudlddlluluurdrrddlludrruullul3ulldllulul3u3luurru4(ur)rddr4(rd)d3l5drdululldllulul3urruurr3u3dllddll3drd3r6urr3d3ull6drllulurluluurduurrddlluldldurrd3u4rddll5ruulld3ulull3drrdrululudd4luluur3d5rddlludrruu3rdd2(lluu)4ldd4ruulldru3ldrl3urduurrddlldlddru3dluudd4luurrdrlullddrr
