rrddr3drddl6u5dlldlluru3(ur)3drddlulldlu3r3uluur4drdl3ulld3ldllu4rlu3r3ulldldd3rur3drddl4u3dlldllu3rlluulldllu3rurddul3uruul4d3ullddrluu5r3drddrddlulldllur3uluurul3r3dll3rddrddlulldl3ulldllu3r3ururr3drddrdl3uluurdd3lrr3ulldldduuruuld3rurddldd3lulluu4r4lddrrudd3ruuruuld3l3d4ruu4drddlulldlluruul4u3rdr4drddlulldlu3r3u3ldl3uruuld3rdr4drdl5uluur4d4lulluu4r4lddrrd4r4uldr5drddlulldlluruul3urul4r3d3l3rddrddlulldl3ulldllu3rurrlluuruuld4r5drddl3udd3luulurlulluu5rurddu6lddrrudlluu5rurd
