ld4lu3l3rdrru4ldrrurrdrru5lrdru3ruld3rd3(dl)lu7lul4uru8rddrd3lurlddlluurrdl6rd3(dl)lu7lul4uru8rddrd3lurd4rd3(dl)luruurulullddrluurrdl4rd3(dl)lu7lul4uru8rddldrrl3u8ldl4drd7rdrruluurul3u8ldl4drd7rdr3uddrruruul
