rdrdrrurrdru3ldlluruurull4r3ulluld3l4d4u3rddldlruruu3r3d3l3dllu4ldluru3ldlluurddu3rd5rdrr6u3l4d4u3r6dllu4ldluru3l3ruurdulluurrdrlulldd3ldd3rd5rdrr6u3l4d4u3r3dllrr3dllu4ldluru4lulddr3u3ruurrdrr3du6rdrru7lrr3dllu4ldluru3ldlluurdldr3u3ruurrdrr3du3r3d3rdrru4ldl3uru3lrr3dllu4ldluru4luldruu3ruurrdrr3du3r3d4ruuru7lrr3dllu4ldluru4luu3ruurrdrr3du3r3dllu4ldluruurd4l3ruu4ldduu3ruurrddurr4d3ldluru3l3ruurdd3urr4d3ldlurull
