drddl4(lu)ll5(dr)ruruuluu4ldrdrduluu3rddrddldlurruuluu3ldll3(dr)rlluluurdrduluu3rdd3l4urrdull4d3ruulrdd4lr4uldduu3rddlrrdd3luurr3urrdlulddu3lddrdd3ruulrdd4lud4ruuluull3dldruluruurrddrddllr2(ruull)ddldllu3ruu2(rrddl)lullrrdrruuluullddlddrluullddrluu3ruuld
