3u6ruudd6l3drrurrd3lrrddlddr3uddrrdrru3lrr7urruululldr8d5u3lurrd4lu3rd5lurrl3dlddr3uddrrurrd3lrrddlddr3uddrrdrru3lrr7urruululldr8d5u5lulld5rurld4lddlddr3uddrrurrd3lrrddlddr3uddrrdrru3lrr7ulld3lulld4r3lddlddr3uddrrurrd3lrrddlddr3udd3r7urruululldr8d6u3ldllu4r6ld3rllddlddr3uddrrurrd3lrr3drrdrrul7u7ldrrlddlddr3udd3r3drrdrrul7urruululldrddrruululdrrdd9ldr3d3r3drrdr4u
