u7luu7ruu5rdu5ldd5rdu12ldd12r10ludlluurrdd5rdd7ldd7rdd5lud5ruu5lud12ruulldurrddlluu5luu5rdu5ldd5lud5ruu5luu5ruu5ldu5ruu3ldu3r4d5luu4r4lddrrud3ruu3ld2(dllddrru)d8rdd5ldd5rud5ldd3rud3l4u5rdd4l4ruulldu3ldd3ru2(urruulld)u6ldd6ruurruulldurruu5lddldulluurrdrdluull6d3ruul4rdd8lddrrudlldd5ruurudrr4u3ldd3l4rddlddruluruuluu3ruulldu4ruulldu6luurrdu4rdu3ldd3r4l4drruurrllu3dlluurrlluurd3u3rddlldluluurrdullddrruuldu3l10drrud4lddrrud6rddllud4lud3ruu3l4r4ull3dullrruurrddllrrddlu3d3luurrurdrddlludrruullddru
