-- create a new campaign
local c = Campaign.new("secondice")
-- set an ingame icon for this campaign
c:setSetting("icon", "icon-campaign-ice")
-- set the on screen message when this campaign is activated
c:setSetting("text", "SecondIce")
-- now add all maps
c:addMaps("second-ice-01")
c:addMaps("second-ice-02")
c:addMaps("second-ice-03")
c:addMaps("second-ice-04")
c:addMaps("second-ice-05")
c:addMaps("second-ice-06")
c:addMaps("second-ice-07")
c:addMaps("second-ice-08")
c:addMaps("second-ice-09")
c:addMaps("second-ice-10")
c:addMaps("second-ice-11")
c:addMaps("second-ice-12")
c:addMaps("second-ice-13")
c:addMaps("second-ice-14")
c:addMaps("second-ice-15")
c:addMaps("second-ice-16")
