3d4ldllur3u3d4rdrrul4uluuruuld5lulldrddlddrurrurdl4d4rdrrul4uluuruuld5lulldrddld3r4d4rdrrul4uluuruuld5lul3dlddrurr4d4rdrrul4uluuru6lulldrddlddrurru3r3l3drruldldd4rdrrul4ulu3ldu3ruruuld5lulldrddld3ru4ruruuld5lul3dlddrurru4rurul3dr4d4ldllu5rdr3ul3u4l4d4u4r3drdd4ldlluruurruluddlu3d4rdrruluul4uruuld5lulldrddlddrurrurdl4d4rdrru5ldl5u4d5ruuluur3dul3ullrruruul4d3u5lulldrddld3r4d4rdrru5ldl3udd5r4ul3u5lul3dldrrl3u6r3drddl4uru6lul3dldr
