textures = {
	["bones"] = {
		image = "cavepacker-ui-small",
		x0 = 0,
		y0 = 0,
		x1 = 0.478515625,
		y1 = 0.080078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 245,
		trimmedheight = 41,
		untrimmedwidth = 245,
		untrimmedheight = 41,
	},
	["icon-close"] = {
		image = "cavepacker-ui-small",
		x0 = 0.125,
		y0 = 0.5859375,
		x1 = 0.06640625,
		y1 = 0.056640625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 34,
		trimmedheight = 29,
		untrimmedwidth = 34,
		untrimmedheight = 29,
	},
	["icon-cursor-down"] = {
		image = "cavepacker-ui-small",
		x0 = 0.25,
		y0 = 0.080078125,
		x1 = 0.1953125,
		y1 = 0.1953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 100,
		trimmedheight = 100,
		untrimmedwidth = 100,
		untrimmedheight = 100,
	},
	["icon-cursor-left"] = {
		image = "cavepacker-ui-small",
		x0 = 0.4453125,
		y0 = 0.24609375,
		x1 = 0.1953125,
		y1 = 0.1953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 100,
		trimmedheight = 100,
		untrimmedwidth = 100,
		untrimmedheight = 100,
	},
	["icon-cursor-right"] = {
		image = "cavepacker-ui-small",
		x0 = 0.25,
		y0 = 0.275390625,
		x1 = 0.1953125,
		y1 = 0.1953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 100,
		trimmedheight = 100,
		untrimmedwidth = 100,
		untrimmedheight = 100,
	},
	["icon-cursor-up"] = {
		image = "cavepacker-ui-small",
		x0 = 0,
		y0 = 0.330078125,
		x1 = 0.1953125,
		y1 = 0.1953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 100,
		trimmedheight = 100,
		untrimmedwidth = 100,
		untrimmedheight = 100,
	},
	["icon-google-login"] = {
		image = "cavepacker-ui-small",
		x0 = 0.8359375,
		y0 = 0.24609375,
		x1 = 0.140625,
		y1 = 0.140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 72,
		trimmedheight = 72,
		untrimmedwidth = 72,
		untrimmedheight = 72,
	},
	["icon-reload"] = {
		image = "cavepacker-ui-small",
		x0 = 0.8359375,
		y0 = 0.38671875,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["icon-scroll-page-DIR"] = {
		image = "cavepacker-ui-small",
		x0 = 0.125,
		y0 = 0.525390625,
		x1 = 0.068359375,
		y1 = 0.060546875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 35,
		trimmedheight = 31,
		untrimmedwidth = 35,
		untrimmedheight = 31,
	},
	["icon-settings"] = {
		image = "cavepacker-ui-small",
		x0 = 0.8203125,
		y0 = 0.51171875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 32,
		trimmedheight = 32,
		untrimmedwidth = 32,
		untrimmedheight = 32,
	},
	["icon-star-disabled"] = {
		image = "cavepacker-ui-small",
		x0 = 0.478515625,
		y0 = 0,
		x1 = 0.255859375,
		y1 = 0.24609375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 131,
		trimmedheight = 126,
		untrimmedwidth = 131,
		untrimmedheight = 126,
	},
	["icon-star-enabled"] = {
		image = "cavepacker-ui-small",
		x0 = 0.734375,
		y0 = 0,
		x1 = 0.255859375,
		y1 = 0.24609375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 131,
		trimmedheight = 126,
		untrimmedwidth = 131,
		untrimmedheight = 126,
	},
	["icon-undo"] = {
		image = "cavepacker-ui-small",
		x0 = 0.640625,
		y0 = 0.24609375,
		x1 = 0.1953125,
		y1 = 0.1953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 100,
		trimmedheight = 100,
		untrimmedwidth = 100,
		untrimmedheight = 100,
	},
	["map-icon-locked"] = {
		image = "cavepacker-ui-small",
		x0 = 0.4453125,
		y0 = 0.44140625,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["map-icon-unlocked-0"] = {
		image = "cavepacker-ui-small",
		x0 = 0.1953125,
		y0 = 0.470703125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["map-icon-unlocked-1"] = {
		image = "cavepacker-ui-small",
		x0 = 0.3203125,
		y0 = 0.470703125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["map-icon-unlocked-2"] = {
		image = "cavepacker-ui-small",
		x0 = 0,
		y0 = 0.525390625,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["map-icon-unlocked-3"] = {
		image = "cavepacker-ui-small",
		x0 = 0.5703125,
		y0 = 0.44140625,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["map-icon-unlocked"] = {
		image = "cavepacker-ui-small",
		x0 = 0.6953125,
		y0 = 0.44140625,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["mouse"] = {
		image = "cavepacker-ui-small",
		x0 = 0.1953125,
		y0 = 0.330078125,
		x1 = 0.048828125,
		y1 = 0.068359375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 25,
		trimmedheight = 35,
		untrimmedwidth = 25,
		untrimmedheight = 35,
	},
	["ui-button-start"] = {
		image = "cavepacker-ui-small",
		x0 = 0,
		y0 = 0.080078125,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
}
