3rddrr5ulld3ldu3rurr5dlluu3l4r4luu3rurr3d5lddll3u3d3rddl4u5r3ulldduurr3d3lrddlldlull3uluurd4r4l3dlddru5ruurr3ullddu5l3dlddru7rud7l3uluurddu5ru2(rrdd)rrudll3u5ruurr3du5luull5drru3rud3ldll5urrdd3r4l4rdd3ldll3u5ruuluur4d5l3drruuddll3u3rluurrurdrr3drddlu4l4r3uruuld5lddll3drruud5r3uruulddu7ld
