durl3urrurr3d3ullddrdrul4drdd3l3ruulldldru4ldll3ur3uluurrurd3lddrrurulddl3dl3drruldlurrddrurul3rd3l3ruurrdlrdluurrululd3ur3d3ulluurdurdlluuldldr3ldlddrruruulld3ldrurr3urdrrl3dldlludrrurrdllr4ulldrurdlldldllururlurl3drddluu
