rr5dldllulldrddldr6ururrdrddldlluldlulldlddrdrlulldrrl3ulu4rd4rurrdlddrdl4u3rdrddldlrurrdllr3uru4ldlluruululld4lulldr5dldr4u3rdrdd3r3luuruluu3lul6d3u3r3luu4r3d3ururrd4rurrdl5drdl4u3ldldduuluruu3rur6d3u3l3ruu3lul4d6u4l3du3r3luu4r3d
