r3d4rurrllddrruldlu4luu3rdu3lddrddl3ud3ruu3ldl4urulldlluu2(rddr)5dllurdr3ud3ruu3ldl4uru3luldd3rddr3d4rdrru5ldluud3ruu3ldl4urullr3dr3d5ruld4luu3rdrd3ldluud3ruu3ldl4uruld3luurdld3rulr3dr3d8ruuld3ld4luu3rdrd3ldluud3ruu3ldl4ulur4d4rd5rd7ldluud3ruu3ldl4u4lddrulu3rllddrulurlur
