4rd3ru5ruruu3ld3lulldllulddu3ruluurululldurrd3l3rd5rdd4rddluru3l3d3luurrlldd3ruu3lulld4rurd3l3d5rdrd3ldlu4rddluruluu2(7lu3ld)5ldldd3ru3rdrrurrdruud7ldlud3luurdldr4u7rddu3rdd5l4rdlddldrdrrudllu4ruruu4l4rddld4l3uru3ldlurruu4rurd3r4url4dll3ul3urru3r2(3dll)3u3rd4r4lu4luurrurdduurr3dldrrddldrlddlld3ull4u3rl3urr3d5l3urrdr3drrurdl5ull3du6lu5rll3d5r4ulldd8lu7rdr5dlluu3lulldlull3u7r7ldllu7r5ld3lddr3drr3ull3d3lulu3rurd4luurdldrdd8ruururdrru5r4ull6duu3l3urrdrddrr4ull3duurr3d4lrruu3lddrd7l6r3ullu4rdrddrr4ull3duurr3d4lrr3u10ld4lu13rll3d5r4ull3duurr3d4ld4lu4ldu3rd4ru5ruu3ru4lul5drr3u5ru6lul3duurr4drrur2(dlul)l3urrd7ru8luldd5lddldrddrrdrurrd5ldd4ldrurrd4rddld4l3u3drr10u6dlldl3urul3dr3d3ldrruruurr4dll4udd5ld6rdr8u6d4rd3lul3ulldlur5drr5u3d6rd5luluull4drr3uddll3u4rurddu3ldd4rdrrurrd7luluull4drr3uddll3u4rurddu3l3d8r3u4rurd3lulldlulld5r3d9luluull4drr3uddll3u4rurd3l3d4ru3rdruuddrr4u3ldrrurdll3drrurrd11luluull4drr3uddllu7ld6ruruurrdd7rdrudrru4rd14ldlluudrdruu
