ll4rdrrul3ululld4rullr4d3lulld4rdr4u3lddld3rdru3lu4ld4r4ullulldr3dldrrurr3ullul3duu3r3dlldllur3u3rdrrulld4rulldll3dll4rdrruluudd3l4ullulldr3drd4rdru5lulld4r4ullul3duu3rdrrurrdllu4luld3r4drrdrrul3uru4l4drrdr3udd3l4urrdlu3rdl3d5lurd3lurrd5r3ulu4lulldrdduu5rdr3d7lur3u5rdrru6lul4dld6rdr3udd6l4u7rdl
