rd4r5uruulldldrd4ruld3l3urrddrdl3ullddr4drd4lu3lddrru4r4ul3urrddrdl3uruul4dl4drd4lulluldldd3ru4ruuluururrdl3ulldldrr4drd4lullull3d3ru4ruul5urrddrdlul4drd4luulldrurdu4l3d3ru4r3luulldrurdu4ld3rd3r3luurdldrrlldllulu3rurdldr
