dlluullddlluld3r3u4ldlldd4r4luurru4r8d4lul3udrrllddrd4r8u4ldllddr3dlldrur3uluurru4r8d5ldluud6r8u4ldllddrddrrururldldlluuluurru4r6d5urrddlruullu4ldllddr4drd5rul5udlluld3r5d4lul4u4r5luurru3rdr5d3u5lddrrudlluu4r5luurru4r5duu3l3druulurr5luurru4r4du5l4dlddr5udrruu3r3u4ldlldd5r5luurru4r3drruulrdd8luurru4rdu4ldllddr4dllurdr3udrruu5ruullu4ldlldd5r5luurru3rd3r2(ddrruurr)dru3l3d4rurruu4l4rddlld4l8u4rdr3dullrruulu4l8d4rurruul3urruldl3drddlld4l8u5rurddu6l8d4rurruuluulldldlrururrddrddlld4l6u5dlluurlddrrd4rurruul4ulu5ldr5durrdru3l5u4rdr4d4l5rddlld3lul5u3d5ruulldurrdd4l5rddlld4l5udd3r3ulddrdll5rddlld4l4ud5r4uruul5dulldd3l3d4rurruu5l5rddlld4l3ullddrluu8rddlld4lulluu7r4urrdlul3dulldd5lddrrd4rurruu5l
