5r4drddluru4lruull5dldrrl4u4rddrrdrddluludrrululrddluluuru4lruull6dld3ruudll4u4r3drruldluuru4lruull5dldrrdrull4u4rddrr3d3rul2(ldluru)ldluuru4lruull6dldrrl5u4rddrr3d7ru6l2(dlurul)dluuru4lruull6dldr5u5r4d4ruul4u4r3dldlurr2(3ull3d)rddul4u5ruurr6dlldld5l2(dlurul)dluuru4lruull6d4u5r4d4ruul4u4r3dldlruruu3(ld)duuru2(ruur)r7dldlldllu3l2(dlurul)dluuru4lruull5d3u4rddrr3d6ru5l2(dlurul)dluuru5lul5drrl4u5r4d4r3ururrdldlruuldldduurr3u3rluurr6dlldld5l2(dlurul)dluuru4lruull5dldr4u5r4d4r3urrdlulddurr4u4r4dr3(dll)u3l2(dlurul)dluuru4lruull5d3u4rddrr3d6ru5l2(dlurul)dluuru4lruull4duu5r4d4ruul4urr3drdl4u4ldrurddldrrddurr4u4r4dlldld5l2(dlurul)dluuru4lruull3du5r4d4ruurruuldrdlu3l5ur4dldrrddurr4u4r4dlddlldllu3l2(dlurul)dluuru5lul4d3u5rddrr3d6ru5l2(dlurul)dluuru5lul3duu6r4d4ruurruuldrdlulddur4u5r4dldd7l2(dlurul)dluuru5luldd
