dr5(ru)ululldldl3d5(ul)ldlddrdrd3r5(ld)drdr3(ru)u4(rd)rruruululu3l3rdrdruu3luurdldrdrrulrruulduluurd3uldduulu3l3dllurdruruurrdlullduulldrldllur3ldrrlldl3d3rd5rlluudd3ldlurululluurdlddrllddrudrddlu3druu3drrurur3u3dldldrrdrru3lr3urrdlulddur3uruul3duullr4dlddr3u4drrulrurrdrr3ud3(dll)urlu3ldrr3luluurdld3r
