#include "CavePackerSpriteType.h"

namespace cavepacker {

namespace SpriteTypes {
SpriteType SOLID("solid");
SpriteType GROUND("ground");
SpriteType TARGET("target");
SpriteType PACKAGE("package");
}

}
