lddru3ldruruulldllrrurrdlddlldlldd4ldd3ru3rurddu4ld3luu4r4ulluurr6dld3rurd3l3urrurruu3l3rddlld2(lluu)rr6dld3rll3ur3(ru)3lrrddld2(lluu)rr6dldrrlurrddull3urruurullr3d2(lluu)rrdrrd4rd3luu3l5dldrrurdll3urruurullr3d2(lluu)rr6dldrrl3urruu5ru6lr3d2(lluu)rr6dldrlddruulurrluurru4rddl3uru5lr3d2(lluu)rr6dlddruluruurruu6rdlldluuru5lr3d2(lluu)rr4drrur4uldrdllr3dll3u7ru4luldrdllr3dllddlddr5u5d5ldllu5rldllullddrulurrluu5rdr3u5dlud4lu4rdr4u3d7lddrulu6rdr3uddllurd3luu3r
