lulrdrrullruuruuldd3ldldd3rurudld3luuru6rdrruldl6ud3l2(uurr)dd4l3r6d3lddrdllr3u3ldlddrurrdr3u3ldld3rdruud3luu4ruuldrdrrdrruldl6ud3l2(uurr)dd3lrr6d3ldd3luu6rdrruldl6u5d6l4drulurrdruud3luu6rdrruldl5u3lulluurdurdrruurrddl6d6u3lduullddrd3r3luluurdrdu3r3d3u5ldrd3r3luu4rdduu3ldld3r
