lul3u3drddldll3(rur)urr3l3dr3durruurrdd3lruuruurruull3d2(uull)uurr3dullulluulldd3r2(lldd)lluu3rlddlddllddrr3u2(ddrr)ddll3udrrdrrddrruu3lrru3(ul)ldllrurruul3u3d3ru3r3l3dr3du4ruululdruurruull3duull4ulldldrulluulldd3rlldd4lddrdrulddllddrr3uddrr4drruruldrrddrruu3lrruu4ruul3ull4ulld3ldd4lddr3drr4drru3r4ulldrurddu4luldduur4urd4rdl3dldrrl3ulullrddrd4lr4urullrd4rdruu
