textures = {
	["tile-background-04-back-01"] = {
		image = "environment",
		x0 = 0.75,
		y0 = 0.75,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-background-big-01-back-01"] = {
		image = "environment",
		x0 = 0.5,
		y0 = 0,
		x1 = 0.5,
		y1 = 0.5,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-rock-01-middle-01"] = {
		image = "environment",
		x0 = 0.75,
		y0 = 0.5,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-rock-02-middle-01"] = {
		image = "environment",
		x0 = 0.5,
		y0 = 0.75,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-rock-03-middle-01"] = {
		image = "environment",
		x0 = 0.5,
		y0 = 0.5,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-rock-big-01-middle-01"] = {
		image = "environment",
		x0 = 0,
		y0 = 0.5,
		x1 = 0.5,
		y1 = 0.5,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-rock-big-02-middle-01"] = {
		image = "environment",
		x0 = 0,
		y0 = 0,
		x1 = 0.5,
		y1 = 0.5,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
}
