u3luurrdull4(uurrdd4l)u2(urr4dllu)u3(4rddlluu)5rdd3l4urrdull4d3ruullrddll3udrruulluurur4du4luu3rur3d6luu4r4d6l4u4r4lddllulu5r4d4l3ulu3r6dldl5udd4rdd3ldl3u6rdd4luu6rdd3ruu4lrdd4lrr3udrruurrdu4l4d5ruullrddll3udrruulluurur4dull4d3ruu5l4u3rur4dull4d4l6u5rur3duu6l4dll4u6r6lddllulu7rll4d4l3ulu5rll6dldl4ud4rdd3ldluud11ruu3luurrddll4urur4dull4dll6urrll4d3lruulruurrddlr4drruu3lrdd5ruu3l4urur4dull4dll6u3rurddull2(ddlr)dd3ruullrrdd3l3u3drrurullrd3rull
