r2(3dll3u)4r3u6l4drl4u8r3dlr3u2(ll3d)6luuluurrllddrdd12r4ulr4d6l3urr3u8ldu14rddrddllrruuluu6l3dll3d6luuluuruu8r3dllurd3lurlddrurdurruddlu3rdlruul3rddl4ruu4l3ruu14lddldd4rluurlddlldd14rud14luuluurdldr2(rluu)14rddrddllrurull
