4rdr4urullulldrddldd3r4ululdrr4d5l3uluurdrrurrdr4d5l3u3d5r4ululldll4drruurdldll4urrurrdr4d3lddlluurlddrruu3r4ululldll4d3ulldruruulddu3rurrdr4d5l3ulur4d3ruuldrdl3r4ululldrddldd3r4ululdrr4d3lddll5uluurdrrurrdr4d3lddll5u5drruu3r4ululldll6drr4urdl3dll6urrurrdr4dllrr4ululldll6drr3ud3r4ull3dl3dll6urrurdrr4dllrr4ull3d3u3l6drruur4u3ldlldruruuld4r4dlddlluurl3udlluru3rur3duu4lddrulu3rurddurr4dl
