sprites = {
	["arrow-white"] = { type = "decal", width = 1.29, height = 0.77, rotateable = 90, },
	["arrow-yellow"] = { type = "decal", width = 1.29, height = 0.77, rotateable = 90, },
	["barrel-blue-down"] = { type = "moveable", width = 0.54, height = 0.375, rotateable = 90, },
	["barrel-blue"] = { type = "moveable", width = 0.43, height = 0.43, rotateable = 90, },
	["barrel-red-down"] = { type = "moveable", width = 0.54, height = 0.375, rotateable = 90, },
	["barrel-red"] = { type = "moveable", width = 0.43, height = 0.43, rotateable = 90, },
	["barrier-red"] = { type = "road", width = 1.5, height = 0.5, rotateable = 45, },
	["barrier-red-race"] = { type = "road", width = 1.5, height = 0.5, rotateable = 45, },
	["barrier-white"] = { type = "road", width = 1.5, height = 0.5, rotateable = 45, },
	["barrier-white-race"] = { type = "road", width = 1.5, height = 0.5, rotateable = 45, },
	["car-black-01"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-black-02"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-black-03"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-black-04"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-black-05"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-blue-01"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-blue-02"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-blue-03"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-blue-04"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-blue-05"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-green-01"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-green-02"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-green-03"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-green-04"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-green-05"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-red-01"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-red-02"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-red-03"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-red-04"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-red-05"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-yellow-01"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-yellow-02"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-yellow-03"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-yellow-04"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["car-yellow-05"] = { type = "vehicle", width = 0.54, height = 0.94, },
	["character-black-blue"] = { type = "moveable", },
	["character-black-green"] = { type = "moveable", },
	["character-black-red"] = { type = "moveable", },
	["character-black-white"] = { type = "moveable", },
	["character-blonde-blue"] = { type = "moveable", },
	["character-blonde-green"] = { type = "moveable", },
	["character-blonde-red"] = { type = "moveable", },
	["character-blonde-white"] = { type = "moveable", },
	["character-brown-blue"] = { type = "moveable", },
	["character-brown-green"] = { type = "moveable", },
	["character-brown-red"] = { type = "moveable", },
	["character-brown-white"] = { type = "moveable", },
	["cone-down"] = { type = "moveable", width = 0.33, height = 0.33, },
	["cone-straight"] = { type = "moveable", width = 0.33, height = 0.33, },
	["land-dirt-01"] = { type = "land", },
	["land-dirt-02"] = { type = "land", },
	["land-dirt-03"] = { type = "land", },
	["land-dirt-04"] = { type = "land", },
	["land-dirt-05"] = { type = "land", },
	["land-dirt-06"] = { type = "land", },
	["land-dirt-07"] = { type = "land", },
	["land-dirt-08"] = { type = "land", },
	["land-dirt-09"] = { type = "land", },
	["land-dirt-10"] = { type = "land", },
	["land-dirt-11"] = { type = "land", },
	["land-dirt-12"] = { type = "land", },
	["land-dirt-13"] = { type = "land", },
	["land-dirt-14"] = { type = "land", },
	["land-grass-01"] = { type = "land", },
	["land-grass-02"] = { type = "land", },
	["land-grass-03"] = { type = "land", },
	["land-grass-04"] = { type = "land", },
	["land-grass-05"] = { type = "land", },
	["land-grass-06"] = { type = "land", },
	["land-grass-07"] = { type = "land", },
	["land-grass-08"] = { type = "land", },
	["land-grass-09"] = { type = "land", },
	["land-grass-10"] = { type = "land", },
	["land-grass-11"] = { type = "land", },
	["land-grass-12"] = { type = "land", },
	["land-grass-13"] = { type = "land", },
	["land-grass-14"] = { type = "land", },
	["land-sand-01"] = { type = "land", },
	["land-sand-02"] = { type = "land", },
	["land-sand-03"] = { type = "land", },
	["land-sand-04"] = { type = "land", },
	["land-sand-05"] = { type = "land", },
	["land-sand-06"] = { type = "land", },
	["land-sand-07"] = { type = "land", },
	["land-sand-08"] = { type = "land", },
	["land-sand-09"] = { type = "land", },
	["land-sand-10"] = { type = "land", },
	["land-sand-11"] = { type = "land", },
	["land-sand-12"] = { type = "land", },
	["land-sand-13"] = { type = "land", },
	["land-sand-14"] = { type = "land", },
	["lights"] = { type = "solid", },
	["light-white"] = { type = "lights", },
	["light-yellow"] = { type = "lights", },
	["motorcycle-black"] = { type = "vehicle", },
	["motorcycle-blue"] = { type = "vehicle", },
	["motorcycle-green"] = { type = "vehicle", },
	["motorcycle-red"] = { type = "vehicle", },
	["motorcycle-yellow"] = { type = "vehicle", },
	["oil-01"] = { type = "oil", },
	["racer-black"] = { type = "racer", },
	["racer-blue"] = { type = "racer", },
	["racer-green"] = { type = "racer", },
	["racer-red"] = { type = "racer", },
	["racer-yellow"] = { type = "racer", },
	["road-asphalt-01"] = { type = "road", },
	["road-asphalt-02"] = { type = "road", },
	["road-asphalt-03"] = { type = "road", },
	["road-asphalt-04"] = { type = "road", },
	["road-asphalt-05"] = { type = "road", },
	["road-asphalt-06"] = { type = "road", },
	["road-asphalt-07"] = { type = "road", },
	["road-asphalt-08"] = { type = "road", },
	["road-asphalt-09"] = { type = "road", },
	["road-asphalt-10"] = { type = "road", },
	["road-asphalt-11"] = { type = "road", },
	["road-asphalt-12"] = { type = "road", },
	["road-asphalt-13"] = { type = "road", },
	["road-asphalt-14"] = { type = "road", },
	["road-asphalt-15"] = { type = "road", },
	["road-asphalt-16"] = { type = "road", },
	["road-asphalt-17"] = { type = "road", },
	["road-asphalt-18"] = { type = "road", },
	["road-asphalt-19"] = { type = "road", },
	["road-asphalt-20"] = { type = "road", },
	["road-asphalt-21"] = { type = "road", },
	["road-asphalt-22"] = { type = "road", },
	["road-asphalt-23"] = { type = "road", },
	["road-asphalt-24"] = { type = "road", },
	["road-asphalt-25"] = { type = "road", },
	["road-asphalt-26"] = { type = "road", },
	["road-asphalt-27"] = { type = "road", },
	["road-asphalt-28"] = { type = "road", },
	["road-asphalt-29"] = { type = "road", },
	["road-asphalt-30"] = { type = "road", },
	["road-asphalt-31"] = { type = "road", },
	["road-asphalt-32"] = { type = "road", },
	["road-asphalt-33"] = { type = "road", },
	["road-asphalt-34"] = { type = "road", },
	["road-asphalt-35"] = { type = "road", },
	["road-asphalt-36"] = { type = "road", },
	["road-asphalt-37"] = { type = "road", },
	["road-asphalt-38"] = { type = "road", },
	["road-asphalt-39"] = { type = "road", },
	["road-asphalt-40"] = { type = "road", },
	["road-asphalt-41"] = { type = "road", },
	["road-asphalt-42"] = { type = "road", },
	["road-asphalt-43"] = { type = "road", },
	["road-asphalt-44"] = { type = "road", },
	["road-asphalt-45"] = { type = "road", },
	["road-asphalt-46"] = { type = "road", },
	["road-asphalt-47"] = { type = "road", },
	["road-asphalt-48"] = { type = "road", },
	["road-asphalt-49"] = { type = "road", },
	["road-asphalt-50"] = { type = "road", },
	["road-asphalt-51"] = { type = "road", },
	["road-asphalt-52"] = { type = "road", },
	["road-asphalt-53"] = { type = "road", },
	["road-asphalt-54"] = { type = "road", },
	["road-asphalt-55"] = { type = "road", },
	["road-asphalt-56"] = { type = "road", },
	["road-asphalt-57"] = { type = "road", },
	["road-asphalt-58"] = { type = "road", },
	["road-asphalt-59"] = { type = "road", },
	["road-asphalt-60"] = { type = "road", },
	["road-asphalt-61"] = { type = "road", },
	["road-asphalt-62"] = { type = "road", },
	["road-asphalt-63"] = { type = "road", },
	["road-asphalt-64"] = { type = "road", },
	["road-asphalt-65"] = { type = "road", },
	["road-asphalt-66"] = { type = "road", },
	["road-asphalt-67"] = { type = "road", },
	["road-asphalt-68"] = { type = "road", },
	["road-asphalt-69"] = { type = "road", },
	["road-asphalt-70"] = { type = "road", },
	["road-asphalt-71"] = { type = "road", },
	["road-asphalt-72"] = { type = "road", },
	["road-asphalt-73"] = { type = "road", },
	["road-asphalt-74"] = { type = "road", },
	["road-asphalt-75"] = { type = "road", },
	["road-asphalt-76"] = { type = "road", },
	["road-asphalt-77"] = { type = "road", },
	["road-asphalt-78"] = { type = "road", },
	["road-asphalt-79"] = { type = "road", },
	["road-asphalt-80"] = { type = "road", },
	["road-asphalt-81"] = { type = "road", },
	["road-asphalt-82"] = { type = "road", },
	["road-asphalt-83"] = { type = "road", },
	["road-asphalt-84"] = { type = "road", },
	["road-asphalt-85"] = { type = "road", },
	["road-asphalt-86"] = { type = "road", },
	["road-asphalt-87"] = { type = "road", },
	["road-asphalt-88"] = { type = "road", },
	["road-asphalt-89"] = { type = "road", },
	["road-asphalt-90"] = { type = "road", },
	["road-dirt-01"] = { type = "road", },
	["road-dirt-02"] = { type = "road", },
	["road-dirt-03"] = { type = "road", },
	["road-dirt-04"] = { type = "road", },
	["road-dirt-05"] = { type = "road", },
	["road-dirt-06"] = { type = "road", },
	["road-dirt-07"] = { type = "road", },
	["road-dirt-08"] = { type = "road", },
	["road-dirt-09"] = { type = "road", },
	["road-dirt-10"] = { type = "road", },
	["road-dirt-11"] = { type = "road", },
	["road-dirt-12"] = { type = "road", },
	["road-dirt-13"] = { type = "road", },
	["road-dirt-14"] = { type = "road", },
	["road-dirt-15"] = { type = "road", },
	["road-dirt-16"] = { type = "road", },
	["road-dirt-17"] = { type = "road", },
	["road-dirt-18"] = { type = "road", },
	["road-dirt-19"] = { type = "road", },
	["road-dirt-20"] = { type = "road", },
	["road-dirt-21"] = { type = "land", },
	["road-dirt-22"] = { type = "road", },
	["road-dirt-23"] = { type = "road", },
	["road-dirt-24"] = { type = "road", },
	["road-dirt-25"] = { type = "road", },
	["road-dirt-26"] = { type = "road", },
	["road-dirt-27"] = { type = "road", },
	["road-dirt-28"] = { type = "road", },
	["road-dirt-29"] = { type = "road", },
	["road-dirt-30"] = { type = "road", },
	["road-dirt-31"] = { type = "road", },
	["road-dirt-32"] = { type = "road", },
	["road-dirt-33"] = { type = "road", },
	["road-dirt-34"] = { type = "road", },
	["road-dirt-35"] = { type = "road", },
	["road-dirt-36"] = { type = "road", },
	["road-dirt-37"] = { type = "road", },
	["road-dirt-38"] = { type = "road", },
	["road-dirt-39"] = { type = "road", },
	["road-dirt-40"] = { type = "road", },
	["road-dirt-41"] = { type = "road", },
	["road-dirt-42"] = { type = "road", },
	["road-dirt-43"] = { type = "road", },
	["road-dirt-44"] = { type = "road", },
	["road-dirt-45"] = { type = "road", },
	["road-dirt-46"] = { type = "road", },
	["road-dirt-47"] = { type = "road", },
	["road-dirt-48"] = { type = "road", },
	["road-dirt-49"] = { type = "road", },
	["road-dirt-50"] = { type = "road", },
	["road-dirt-51"] = { type = "road", },
	["road-dirt-52"] = { type = "road", },
	["road-dirt-53"] = { type = "road", },
	["road-dirt-54"] = { type = "road", },
	["road-dirt-55"] = { type = "road", },
	["road-dirt-56"] = { type = "road", },
	["road-dirt-57"] = { type = "road", },
	["road-dirt-58"] = { type = "road", },
	["road-dirt-59"] = { type = "road", },
	["road-dirt-60"] = { type = "road", },
	["road-dirt-61"] = { type = "road", },
	["road-dirt-62"] = { type = "road", },
	["road-dirt-63"] = { type = "road", },
	["road-dirt-64"] = { type = "road", },
	["road-dirt-65"] = { type = "road", },
	["road-dirt-66"] = { type = "road", },
	["road-dirt-67"] = { type = "road", },
	["road-dirt-68"] = { type = "road", },
	["road-dirt-69"] = { type = "road", },
	["road-dirt-70"] = { type = "road", },
	["road-dirt-71"] = { type = "road", },
	["road-dirt-72"] = { type = "road", },
	["road-dirt-73"] = { type = "road", },
	["road-dirt-74"] = { type = "road", },
	["road-dirt-75"] = { type = "road", },
	["road-dirt-76"] = { type = "road", },
	["road-dirt-77"] = { type = "road", },
	["road-dirt-78"] = { type = "road", },
	["road-dirt-79"] = { type = "road", },
	["road-dirt-80"] = { type = "road", },
	["road-dirt-81"] = { type = "road", },
	["road-dirt-82"] = { type = "road", },
	["road-dirt-83"] = { type = "road", },
	["road-dirt-84"] = { type = "road", },
	["road-dirt-85"] = { type = "road", },
	["road-dirt-86"] = { type = "road", },
	["road-dirt-87"] = { type = "road", },
	["road-dirt-88"] = { type = "road", },
	["road-dirt-89"] = { type = "road", },
	["road-dirt-90"] = { type = "road", },
	["road-sand-01"] = { type = "road", },
	["road-sand-02"] = { type = "road", },
	["road-sand-03"] = { type = "road", },
	["road-sand-04"] = { type = "road", },
	["road-sand-05"] = { type = "road", },
	["road-sand-06"] = { type = "road", },
	["road-sand-07"] = { type = "road", },
	["road-sand-08"] = { type = "road", },
	["road-sand-09"] = { type = "road", },
	["road-sand-10"] = { type = "road", },
	["road-sand-11"] = { type = "road", },
	["road-sand-12"] = { type = "road", },
	["road-sand-13"] = { type = "road", },
	["road-sand-14"] = { type = "road", },
	["road-sand-15"] = { type = "road", },
	["road-sand-16"] = { type = "road", },
	["road-sand-17"] = { type = "road", },
	["road-sand-18"] = { type = "road", },
	["road-sand-19"] = { type = "road", },
	["road-sand-20"] = { type = "road", },
	["road-sand-21"] = { type = "road", },
	["road-sand-22"] = { type = "road", },
	["road-sand-23"] = { type = "road", },
	["road-sand-24"] = { type = "road", },
	["road-sand-25"] = { type = "road", },
	["road-sand-26"] = { type = "road", },
	["road-sand-27"] = { type = "road", },
	["road-sand-28"] = { type = "road", },
	["road-sand-29"] = { type = "road", },
	["road-sand-30"] = { type = "road", },
	["road-sand-31"] = { type = "road", },
	["road-sand-32"] = { type = "road", },
	["road-sand-33"] = { type = "road", },
	["road-sand-34"] = { type = "road", },
	["road-sand-35"] = { type = "road", },
	["road-sand-36"] = { type = "road", },
	["road-sand-37"] = { type = "road", },
	["road-sand-38"] = { type = "road", },
	["road-sand-39"] = { type = "road", },
	["road-sand-40"] = { type = "road", },
	["road-sand-41"] = { type = "road", },
	["road-sand-42"] = { type = "road", },
	["road-sand-43"] = { type = "road", },
	["road-sand-44"] = { type = "road", },
	["road-sand-45"] = { type = "road", },
	["road-sand-46"] = { type = "road", },
	["road-sand-47"] = { type = "road", },
	["road-sand-48"] = { type = "road", },
	["road-sand-49"] = { type = "road", },
	["road-sand-50"] = { type = "road", },
	["road-sand-51"] = { type = "road", },
	["road-sand-52"] = { type = "road", },
	["road-sand-53"] = { type = "road", },
	["road-sand-54"] = { type = "road", },
	["road-sand-55"] = { type = "road", },
	["road-sand-56"] = { type = "road", },
	["road-sand-57"] = { type = "road", },
	["road-sand-58"] = { type = "road", },
	["road-sand-59"] = { type = "road", },
	["road-sand-60"] = { type = "road", },
	["road-sand-61"] = { type = "road", },
	["road-sand-62"] = { type = "road", },
	["road-sand-63"] = { type = "road", },
	["road-sand-64"] = { type = "road", },
	["road-sand-65"] = { type = "road", },
	["road-sand-66"] = { type = "road", },
	["road-sand-67"] = { type = "road", },
	["road-sand-68"] = { type = "road", },
	["road-sand-69"] = { type = "road", },
	["road-sand-70"] = { type = "road", },
	["road-sand-71"] = { type = "road", },
	["road-sand-72"] = { type = "road", },
	["road-sand-73"] = { type = "road", },
	["road-sand-74"] = { type = "road", },
	["road-sand-75"] = { type = "road", },
	["road-sand-76"] = { type = "road", },
	["road-sand-77"] = { type = "road", },
	["road-sand-78"] = { type = "road", },
	["road-sand-79"] = { type = "road", },
	["road-sand-80"] = { type = "road", },
	["road-sand-81"] = { type = "road", },
	["road-sand-82"] = { type = "road", },
	["road-sand-83"] = { type = "road", },
	["road-sand-84"] = { type = "road", },
	["road-sand-85"] = { type = "road", },
	["road-sand-86"] = { type = "road", },
	["road-sand-87"] = { type = "road", },
	["road-sand-88"] = { type = "road", },
	["road-sand-89"] = { type = "road", },
	["road-sand-90"] = { type = "road", },
	["rock-01"] = { type = "solid", },
	["rock-02"] = { type = "solid", },
	["rock-03"] = { type = "solid", },
	["rock-04"] = { type = "solid", },
	["rock-05"] = { type = "solid", },
	["rock-06"] = { type = "solid", },
	["rock-07"] = { type = "solid", },
	["rock-08"] = { type = "solid", },
	["rock-09"] = { type = "solid", },
	["rock-10"] = { type = "solid", },
	["rock-11"] = { type = "solid", },
	["rock-12"] = { type = "solid", },
	["rock-13"] = { type = "solid", },
	["rock-14"] = { type = "solid", },
	["rock-15"] = { type = "solid", },
	["rock-16"] = { type = "solid", },
	["rock-17"] = { type = "solid", },
	["rock-18"] = { type = "solid", },
	["rock-19"] = { type = "solid", },
	["rock-20"] = { type = "solid", },
	["rock-21"] = { type = "solid", },
	["rock-22"] = { type = "solid", },
	["rock-23"] = { type = "solid", },
	["rock-24"] = { type = "solid", },
	["skidmark-long-1"] = { type = "decal", },
	["skidmark-long-2"] = { type = "decal", },
	["skidmark-long-3"] = { type = "decal", },
	["skidmark-short-1"] = { type = "decal", },
	["skidmark-short-2"] = { type = "decal", },
	["skidmark-short-3"] = { type = "decal", },
	["tent-blue-large"] = { type = "solid", width = 2, height = 2, rotateable = 90, },
	["tent-blue"] = { type = "solid", },
	["tent-red-large"] = { type = "solid", width = 2, height = 2, rotateable = 90, },
	["tent-red"] = { type = "solid", },
	["tires-red-alt"] = { type = "solid", width = 0.3, height = 0.3, },
	["tires-red"] = { type = "solid", width = 0.3, height = 0.3, },
	["tires-white-alt"] = { type = "solid", width = 0.3, height = 0.3, },
	["tires-white"] = { type = "solid", width = 0.3, height = 0.3, },
	["tree-large"] = { type = "solid", width = 1.5, height = 1.5, rotateable = 10,},
	["tree-small"] = { type = "solid", width = 1, height = 1, rotateable = 10, },
	["tribune-empty"] = { type = "solid", width = 3, height = 1, rotateable = 45, },
	["tribune-full"] = { type = "solid", width = 3, height = 1, rotateable = 45, },
	["tribune-overhang-red"] = { type = "solid", width = 3, height = 0.5, rotateable = 45, },
	["tribune-overhang-striped"] = { type = "solid", width = 3, height = 0.5, rotateable = 45, },
}
