dru4rdrru2(luul)uurrdrddldludlu4rdllrdd4ldllu5rdr3ululldlldurrurrdrruluululldll3drrurrdru3d4ldllu5rdr3ululldlldurrurrdrrullr3d4ldllu5r4luu4rurd5l3urrdduull3d4rurrd4l3ull5d4rdrru5l4ruu4lr3ull3drr4urrdll3drruludd3ruldlluuluurrdrddldludlu4rdllrdd4ldllu5rdr3ululldlldurrurrdrrullr3d4ldllu5rdr3ulur3d5luurrurldlldd5r5ululldduurrdluldrdurr5d5l5urrurd3l3d4r4ldd5ruu
