textures = {
	["ui-npc-mammut-middle-01"] = {
		image = "caveexpress-ui-npc-mammut-big",
		x0 = 0.611328125,
		y0 = 0,
		x1 = 0.310546875,
		y1 = 0.4892578125,
		trimmedoffsetx = 70,
		trimmedoffsety = 6,
		trimmedwidth = 636,
		trimmedheight = 501,
		untrimmedwidth = 854,
		untrimmedheight = 507,
	},
	["ui-npc-mammut-middle-02"] = {
		image = "caveexpress-ui-npc-mammut-big",
		x0 = 0,
		y0 = 0,
		x1 = 0.3125,
		y1 = 0.4912109375,
		trimmedoffsetx = 66,
		trimmedoffsety = 4,
		trimmedwidth = 640,
		trimmedheight = 503,
		untrimmedwidth = 854,
		untrimmedheight = 507,
	},
	["ui-npc-mammut-middle-03"] = {
		image = "caveexpress-ui-npc-mammut-big",
		x0 = 0.3125,
		y0 = 0,
		x1 = 0.298828125,
		y1 = 0.4912109375,
		trimmedoffsetx = 96,
		trimmedoffsety = 4,
		trimmedwidth = 612,
		trimmedheight = 503,
		untrimmedwidth = 854,
		untrimmedheight = 507,
	},
	["ui-npc-mammut-middle-04"] = {
		image = "caveexpress-ui-npc-mammut-big",
		x0 = 0.310546875,
		y0 = 0.4912109375,
		x1 = 0.3017578125,
		y1 = 0.4912109375,
		trimmedoffsetx = 87,
		trimmedoffsety = 4,
		trimmedwidth = 618,
		trimmedheight = 503,
		untrimmedwidth = 854,
		untrimmedheight = 507,
	},
	["ui-npc-mammut-middle-05"] = {
		image = "caveexpress-ui-npc-mammut-big",
		x0 = 0,
		y0 = 0.4912109375,
		x1 = 0.310546875,
		y1 = 0.4912109375,
		trimmedoffsetx = 70,
		trimmedoffsety = 4,
		trimmedwidth = 636,
		trimmedheight = 503,
		untrimmedwidth = 854,
		untrimmedheight = 507,
	},
}
