textures = {
	["ui-npc-grandpa-middle-01"] = {
		image = "caveexpress-ui-player-grandpa-small",
		x0 = 0.810546875,
		y0 = 0.1630859375,
		x1 = 0.177734375,
		y1 = 0.15625,
		trimmedoffsetx = 24,
		trimmedoffsety = 4,
		trimmedwidth = 91,
		trimmedheight = 160,
		untrimmedwidth = 115,
		untrimmedheight = 164,
	},
	["ui-npc-grandpa-middle-02"] = {
		image = "caveexpress-ui-player-grandpa-small",
		x0 = 0.787109375,
		y0 = 0.3193359375,
		x1 = 0.203125,
		y1 = 0.15625,
		trimmedoffsetx = 20,
		trimmedoffsety = 5,
		trimmedwidth = 104,
		trimmedheight = 160,
		untrimmedwidth = 124,
		untrimmedheight = 166,
	},
	["ui-npc-grandpa-middle-03"] = {
		image = "caveexpress-ui-player-grandpa-small",
		x0 = 0.453125,
		y0 = 0.353515625,
		x1 = 0.22265625,
		y1 = 0.1533203125,
		trimmedoffsetx = 2,
		trimmedoffsety = 7,
		trimmedwidth = 114,
		trimmedheight = 157,
		untrimmedwidth = 116,
		untrimmedheight = 165,
	},
	["ui-npc-grandpa-middle-04"] = {
		image = "caveexpress-ui-player-grandpa-small",
		x0 = 0.27734375,
		y0 = 0.2216796875,
		x1 = 0.17578125,
		y1 = 0.1640625,
		trimmedoffsetx = 26,
		trimmedoffsety = 2,
		trimmedwidth = 90,
		trimmedheight = 168,
		untrimmedwidth = 116,
		untrimmedheight = 170,
	},
	["ui-npc-grandpa-middle-05"] = {
		image = "caveexpress-ui-player-grandpa-small",
		x0 = 0.27734375,
		y0 = 0.3857421875,
		x1 = 0.173828125,
		y1 = 0.166015625,
		trimmedoffsetx = 24,
		trimmedoffsety = 0,
		trimmedwidth = 89,
		trimmedheight = 170,
		untrimmedwidth = 113,
		untrimmedheight = 170,
	},
	["ui-npc-grandpa-middle-06"] = {
		image = "caveexpress-ui-player-grandpa-small",
		x0 = 0,
		y0 = 0.3984375,
		x1 = 0.21875,
		y1 = 0.158203125,
		trimmedoffsetx = 15,
		trimmedoffsety = 5,
		trimmedwidth = 112,
		trimmedheight = 162,
		untrimmedwidth = 128,
		untrimmedheight = 168,
	},
	["ui-npc-grandpa-middle-07"] = {
		image = "caveexpress-ui-player-grandpa-small",
		x0 = 0.810546875,
		y0 = 0,
		x1 = 0.189453125,
		y1 = 0.1630859375,
		trimmedoffsetx = 18,
		trimmedoffsety = 2,
		trimmedwidth = 97,
		trimmedheight = 167,
		untrimmedwidth = 115,
		untrimmedheight = 169,
	},
	["ui-player-middle-01"] = {
		image = "caveexpress-ui-player-grandpa-small",
		x0 = 0.478515625,
		y0 = 0.1767578125,
		x1 = 0.30859375,
		y1 = 0.1767578125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 158,
		trimmedheight = 181,
		untrimmedwidth = 170,
		untrimmedheight = 185,
	},
	["ui-player-middle-02"] = {
		image = "caveexpress-ui-player-grandpa-small",
		x0 = 0,
		y0 = 0.2216796875,
		x1 = 0.27734375,
		y1 = 0.1767578125,
		trimmedoffsetx = 6,
		trimmedoffsety = 0,
		trimmedwidth = 142,
		trimmedheight = 181,
		untrimmedwidth = 170,
		untrimmedheight = 185,
	},
	["ui-player-middle-03"] = {
		image = "caveexpress-ui-player-grandpa-small",
		x0 = 0.478515625,
		y0 = 0,
		x1 = 0.33203125,
		y1 = 0.1767578125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 170,
		trimmedheight = 181,
		untrimmedwidth = 170,
		untrimmedheight = 185,
	},
	["ui-scene-player"] = {
		image = "caveexpress-ui-player-grandpa-small",
		x0 = 0,
		y0 = 0,
		x1 = 0.478515625,
		y1 = 0.2216796875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 245,
		trimmedheight = 227,
		untrimmedwidth = 247,
		untrimmedheight = 227,
	},
}
