rr3u3ruulullddldr4lulld4rurr4d5luu4lddrulur4u5rud5l4drruul3rdrrurruullulld4l3durrdrru4luu4rurrd4rdrdd3rddld3ldld11luluurrur4u4rurrdrr6d5luudd5r3urrdlu3rdlu3lulld3rl3ullulld4lddrrddrdd5ruururrdlr3ulullddldr3d5luuluurrdrrllu4lddrrurru4luu4rurrdrr6d5luu4lddrulu3ruurrdlu3luu4rurrdrr6d5luudd5r3urrdlululldl4rl3ullddrdl4ulldrur3duu6l5d3lddrd11ruru3rur3uluululu4lulldurrd4r3(dr)4dld3ldld11luluurru4rdd5ruurul3urrdlduuldduu8ldlldrurd
