d6ruururll3druruldd4luul4u5r3dlddrd3lrr3ur3u5l3dll3drrdr4u3d3rurrululddrd3l3r6u5l3dll3drrdru4r6urrururrdldlddlldl3d4luulurlurrdll3u5r3dlddrruluu3ruuldldl4d4luul4u5r3dlddrd3lrr3ur3u5l3dll3drrdr4u3d3rurrul3u3rdllulddlddrd3lrr3ur3u5l3dll3drrdr3udd3rurrul2(uurr)uulul4drdllulddlddrd6lrruulu3l4dr3ulurrl3d6rurrul2(uurr)ulul3drdllulddlddrd6lrruulurlurd4l4dr3ulurrl3d6rurrulruluurrdlulddlddrd4l4uldll3drrdru3rurruluu3rdlluldlddrd6lrr3u4l4druud6rurrul4u5ldu6rdrruul3drdlluldlddrd6l5rurrululddrd4l3u4lddrulu3r3l4dr3ulurrl3drrdruu
