3rddrdrr4dlluurr4dlldd4luul3ullrr3drddrruul3urrll3drddrruuluurdurr4ullull4dlddrluur4uruu4lddldd3l4drruu3r3ulr3dlddrluullddll4u3rdu3l2(uurr)3drddlruul3u4rddl3dlruulu3rdrrdd3lrdurruulldul3u4ldd3r3luurrdu4lddr3lddrrudll4drr3udrlddr3luur
