d3ruld3rdrdrrdl3uruuldrdd3luurrdlddrdrul3drurr4u3lddrduluurddl4urddu4ldllu4rdl3ruuldrdllu3ld3lu6rdrruuldd3rddlludrruu3l3r4dlld3luldllul3u3drd6r4udrruullu8ldrrl4drd3ruulullrr3dllul3u3drrurrdld4rddldllurd3luruu4r6u8ldr4drdrr3drruuddll3ullul5u7r8dld3l3u3r3l3drruudrr5u5dld3l3u3rlddrr3ud4lddrdruudlluu3r5lul5u7rdrr4d2(lldurruu)lldd3u7l5drd3ruulullrdrrddllull4ulu7rur3duu7l5drrurullrddll4ulu7rurddu7l3drrdrrdldluurullrddll4ulu7rurd
