rdrlulldduulu3(ul)ldr3dlddru3r3u5rddrddl3u4d3ldlluruul3ulululldr3dld4r3ulululdrrd5rurrdl3dllullrrdrr3u4lulldrdd3rdrrdd3ldlluruul3u4rurrdl3dllullrrdrr3u4lulld5rur3drddld3ldl3uluudr3d4ruruuluu4lulldrlululld3rll3dlddru3rurddul3ulull3dld4r3u4rurrdlddrddlullullrrdrrdd3ldlluruu4l4urrdrru3lul4dld4ruudd3l4u4rdl4rurrdlddrddlullullrrdrrdd3ldlluruulurd4l4u3rddu4rurrd5l4rddrddl3u4d3ldl3u4l4u4rd3rurrd4l
