3d3(ld)drdrdr9(ru)u8(lu)l9(ld)d4(rd)rururuuddldlddrurur4u4dldllururlddruruuddlluruurdr3uddll3druulurrdruull4d5l3(ul)uu4(rd)3rdrulurdruulurrl3d5l3(ul)uu4(rd)3rdd3l3(ul)u3(dr)dd4(lu)drdrd3r3drdrdrr3(ul)rdrdd3(lu)drdrr3(ul)rdrddluluuddrruldd4r3(ul)rdrdd3l4udrrdrdlldluud5r3(ul)rdrdrr4(ul)urrdr3duurdr4(ru)u4(ld)urururr3(dl)lrdllruu3l3rdrruruuldldurrdldlruuldldu3r4u3(ld)4l4rururuu3(ld)ururr3(dl)ruruu3(ld)uru4rddlurulul3(ld)ll4(ur)l3(dl)l4(ur)ldldlddlldrr3l3(dl)l9(ur)l8(dl)l3(ur)l3du3luluurdrdulldrdrrlluurdldrurdll4urdrdu3(ur)u3(dl)dd3(ru)rdlld4ldrrurru4rdrddllulu3l3rdrdrrulu3l3rddlurululr4(ru)u4(ld)u3(ru)u4(ld)uru3rl3u3(ld)urrurd
