function getName()
	return "Wind 03"
end

function onMapLoaded()
end

function initMap()
	-- get the current map context
	local map = Map.get()
	map:addTile("tile-background-04", 0, 0)
	map:addTile("tile-background-04", 0, 1)
	map:addTile("tile-ground-04", 0, 2)
	map:addTile("tile-rock-big-01", 0, 3)
	map:addTile("tile-rock-02", 0, 5)
	map:addTile("tile-rock-01", 0, 6)
	map:addTile("tile-rock-02", 0, 7)
	map:addTile("tile-rock-01", 0, 8)
	map:addTile("tile-rock-02", 0, 9)
	map:addTile("tile-background-cave-art-01", 1, 0)
	map:addTile("tile-background-01", 1, 1)
	map:addTile("tile-ground-01", 1, 2)
	map:addTile("tile-rock-01", 1, 5)
	map:addTile("tile-rock-big-01", 1, 6)
	map:addTile("tile-ground-04", 1, 8)
	map:addTile("tile-rock-01", 1, 9)
	map:addTile("tile-background-cave-art-01", 2, 0)
	map:addTile("tile-background-04", 2, 1)
	map:addTile("tile-ground-03", 2, 2)
	map:addTile("tile-rock-03", 2, 3)
	map:addTile("tile-rock-01", 2, 4)
	map:addTile("tile-rock-02", 2, 5)
	map:addTile("tile-rock-02", 2, 8)
	map:addTile("tile-rock-02", 2, 9)
	map:addTile("tile-background-01", 3, 0)
	map:addTile("tile-background-01", 3, 1)
	map:addTile("tile-ground-04", 3, 2)
	map:addTile("tile-ground-04", 3, 3)
	map:addTile("tile-rock-02", 3, 4)
	map:addTile("tile-rock-01", 3, 5)
	map:addTile("tile-ground-03", 3, 6)
	map:addTile("tile-rock-03", 3, 7)
	map:addTile("tile-rock-01", 3, 8)
	map:addTile("tile-rock-02", 3, 9)
	map:addTile("tile-background-01", 4, 0)
	map:addTile("tile-background-02", 4, 1)
	map:addTile("tile-background-cave-art-01", 4, 2)
	map:addTile("tile-background-04", 4, 3)
	map:addTile("tile-rock-02", 4, 4)
	map:addTile("tile-rock-big-01", 4, 5)
	map:addTile("tile-rock-01", 4, 7)
	map:addTile("tile-rock-big-01", 4, 8)
	map:addTile("tile-background-02", 5, 0)
	map:addTile("tile-background-cave-art-01", 5, 1)
	map:addTile("tile-background-04", 5, 2)
	map:addTile("tile-background-04", 5, 3)
	map:addTile("tile-ground-03", 5, 4)
	map:addTile("tile-rock-03", 5, 7)
	map:addTile("tile-background-02", 6, 0)
	map:addTile("tile-background-02", 6, 1)
	map:addTile("tile-background-02", 6, 2)
	map:addTile("tile-background-04", 6, 3)
	map:addTile("tile-ground-03", 6, 4)
	map:addTile("tile-rock-02", 6, 5)
	map:addTile("tile-rock-big-01", 6, 6)
	map:addTile("tile-rock-03", 6, 8)
	map:addTile("tile-rock-02", 6, 9)
	map:addTile("tile-background-04", 7, 0)
	map:addTile("tile-background-03", 7, 1)
	map:addTile("tile-background-02", 7, 2)
	map:addTile("tile-background-04", 7, 3)
	map:addTile("tile-rock-slope-right-01", 7, 4)
	map:addTile("tile-rock-02", 7, 5)
	map:addTile("tile-rock-big-01", 7, 8)
	map:addTile("tile-background-01", 8, 0)
	map:addTile("tile-background-01", 8, 1)
	map:addTile("tile-background-01", 8, 2)
	map:addTile("tile-background-04", 8, 3)
	map:addTile("tile-background-04", 8, 4)
	map:addTile("tile-background-02", 8, 5)
	map:addTile("tile-packagetarget-rock-01-idle", 8, 6)
	map:addTile("tile-rock-01", 8, 7)
	map:addTile("tile-background-03", 9, 0)
	map:addTile("tile-background-04", 9, 1)
	map:addTile("tile-background-01", 9, 2)
	map:addTile("tile-background-02", 9, 3)
	map:addTile("tile-background-04", 9, 4)
	map:addTile("tile-ground-03", 9, 5)
	map:addTile("tile-rock-big-01", 9, 6)
	map:addTile("tile-rock-02", 9, 8)
	map:addTile("tile-rock-02", 9, 9)
	map:addTile("tile-background-04", 10, 0)
	map:addTile("tile-background-01", 10, 1)
	map:addTile("tile-background-04", 10, 2)
	map:addTile("tile-background-02", 10, 3)
	map:addTile("tile-background-04", 10, 4)
	map:addTile("tile-ground-01", 10, 5)
	map:addTile("tile-rock-03", 10, 8)
	map:addTile("tile-ground-03", 10, 9)
	map:addTile("tile-background-03", 11, 0)
	map:addTile("tile-background-03", 11, 1)
	map:addTile("tile-background-01", 11, 2)
	map:addTile("tile-background-02", 11, 3)
	map:addTile("tile-rock-slope-left-01", 11, 4)
	map:addTile("tile-rock-big-01", 11, 5)
	map:addTile("tile-rock-03", 11, 7)
	map:addTile("tile-rock-big-01", 11, 8)
	map:addTile("tile-background-04", 12, 0)
	map:addTile("tile-background-04", 12, 1)
	map:addTile("tile-background-02", 12, 2)
	map:addTile("tile-rock-slope-left-01", 12, 3)
	map:addTile("tile-ground-03", 12, 4)
	map:addTile("tile-rock-03", 12, 7)
	map:addTile("tile-background-02", 13, 0)
	map:addTile("tile-background-02", 13, 1)
	map:addTile("tile-rock-slope-left-01", 13, 2)
	map:addTile("tile-rock-big-01", 13, 3)
	map:addTile("tile-rock-02", 13, 5)
	map:addTile("tile-rock-slope-right-02", 13, 6)
	map:addTile("tile-background-02", 13, 7)
	map:addTile("tile-background-04", 13, 8)
	map:addTile("tile-ground-03", 13, 9)
	map:addTile("tile-background-02", 14, 0)
	map:addTile("tile-background-04", 14, 1)
	map:addTile("tile-ground-01", 14, 2)
	map:addTile("tile-rock-slope-right-02", 14, 5)
	map:addTile("tile-background-big-01", 14, 6)
	map:addTile("tile-background-04", 14, 8)
	map:addTile("tile-ground-01", 14, 9)
	map:addTile("tile-background-04", 15, 0)
	map:addTile("tile-background-01", 15, 1)
	map:addTile("tile-ground-03", 15, 2)
	map:addTile("tile-rock-03", 15, 3)
	map:addTile("tile-rock-slope-right-02", 15, 4)
	map:addTile("tile-background-02", 15, 5)
	map:addTile("tile-background-04", 15, 8)
	map:addTile("tile-ground-03", 15, 9)
	map:addTile("tile-background-big-01", 16, 0)
	map:addTile("tile-ground-01", 16, 2)
	map:addTile("tile-rock-slope-right-02", 16, 3)
	map:addTile("tile-background-03", 16, 4)
	map:addTile("tile-background-big-01", 16, 5)
	map:addTile("tile-background-big-01", 16, 7)
	map:addTile("tile-ground-01", 16, 9)
	map:addTile("tile-ground-ledge-right-01", 17, 2)
	map:addTile("tile-background-02", 17, 3)
	map:addTile("tile-background-01", 17, 4)
	map:addTile("tile-ground-01", 17, 9)
	map:addTile("tile-background-04", 18, 0)
	map:addTile("tile-background-big-01", 18, 1)
	map:addTile("tile-background-04", 18, 3)
	map:addTile("tile-background-02", 18, 4)
	map:addTile("tile-background-01", 18, 5)
	map:addTile("tile-background-01", 18, 6)
	map:addTile("tile-background-02", 18, 7)
	map:addTile("tile-background-01", 18, 8)
	map:addTile("tile-ground-02", 18, 9)
	map:addTile("tile-background-02", 19, 0)
	map:addTile("tile-background-01", 19, 3)
	map:addTile("tile-background-04", 19, 4)
	map:addTile("tile-ground-03", 19, 5)
	map:addTile("tile-rock-shim-01", 19, 6)
	map:addTile("tile-background-01", 19, 7)
	map:addTile("tile-background-02", 19, 8)
	map:addTile("tile-ground-03", 19, 9)
	map:addTile("tile-background-big-01", 20, 0)
	map:addTile("tile-background-01", 20, 2)
	map:addTile("tile-background-02", 20, 3)
	map:addTile("tile-background-04", 20, 4)
	map:addTile("tile-background-big-01", 20, 5)
	map:addTile("bridge-wall-left-01", 20, 5)
	map:addTile("tile-background-01", 20, 7)
	map:addTile("tile-background-01", 20, 8)
	map:addTile("tile-ground-02", 20, 9)
	map:addTile("tile-background-02", 21, 2)
	map:addTile("tile-background-03", 21, 3)
	map:addTile("tile-background-04", 21, 4)
	map:addTile("bridge-plank-01", 21, 5)
	map:addTile("tile-background-big-01", 21, 7)
	map:addTile("tile-ground-01", 21, 9)
	map:addTile("tile-background-01", 22, 0)
	map:addTile("tile-background-01", 22, 1)
	map:addTile("tile-background-02", 22, 2)
	map:addTile("tile-background-04", 22, 3)
	map:addTile("tile-background-cave-art-01", 22, 4)
	map:addTile("tile-background-03", 22, 5)
	map:addTile("bridge-wall-right-01", 22, 5)
	map:addTile("tile-background-02", 22, 6)
	map:addTile("tile-background-cave-art-01", 22, 9)
	map:addTile("bridge-wall-left-01", 22, 9)
	map:addTile("tile-background-01", 23, 0)
	map:addTile("tile-background-big-01", 23, 1)
	map:addTile("tile-background-02", 23, 3)
	map:addTile("tile-background-03", 23, 4)
	map:addTile("tile-ground-03", 23, 5)
	map:addTile("tile-background-01", 23, 6)
	map:addTile("tile-background-01", 23, 7)
	map:addTile("tile-background-big-01", 23, 8)
	map:addTile("bridge-plank-01", 23, 9)
	map:addTile("tile-background-01", 24, 0)
	map:addTile("tile-background-04", 24, 3)
	map:addTile("tile-background-01", 24, 4)
	map:addTile("tile-ground-04", 24, 5)
	map:addTile("tile-background-02", 24, 6)
	map:addTile("liane-01", 24, 6)
	map:addTile("tile-background-04", 24, 7)
	map:addTile("bridge-plank-01", 24, 9)
	map:addTile("tile-rock-01", 25, 0)
	map:addTile("tile-rock-02", 25, 1)
	map:addTile("tile-rock-slope-left-02", 25, 2)
	map:addTile("tile-background-04", 25, 3)
	map:addTile("tile-background-02", 25, 4)
	map:addTile("tile-ground-02", 25, 5)
	map:addTile("tile-background-03", 25, 6)
	map:addTile("tile-background-big-01", 25, 7)
	map:addTile("tile-background-01", 25, 9)
	map:addTile("bridge-plank-01", 25, 9)
	map:addTile("tile-rock-big-01", 26, 0)
	map:addTile("tile-rock-02", 26, 2)
	map:addTile("tile-background-02", 26, 3)
	map:addTile("tile-geyser-rock-01-active", 26, 4)
	map:addTile("tile-background-01", 26, 6)
	map:addTile("liane-01", 26, 6)
	map:addTile("tile-background-cave-art-01", 26, 9)
	map:addTile("bridge-plank-01", 26, 9)
	map:addTile("tile-rock-01", 27, 2)
	map:addTile("tile-background-04", 27, 3)
	map:addTile("tile-background-02", 27, 4)
	map:addTile("tile-ground-02", 27, 5)
	map:addTile("tile-background-02", 27, 6)
	map:addTile("tile-background-01", 27, 7)
	map:addTile("tile-background-01", 27, 8)
	map:addTile("tile-background-02", 27, 9)
	map:addTile("bridge-plank-01", 27, 9)
	map:addTile("tile-rock-01", 28, 0)
	map:addTile("tile-rock-02", 28, 1)
	map:addTile("tile-rock-slope-right-02", 28, 2)
	map:addTile("tile-background-big-01", 28, 3)
	map:addTile("tile-ground-04", 28, 5)
	map:addTile("tile-background-04", 28, 6)
	map:addTile("tile-background-big-01", 28, 7)
	map:addTile("tile-background-02", 28, 9)
	map:addTile("bridge-plank-01", 28, 9)
	map:addTile("tile-rock-slope-right-02", 29, 0)
	map:addTile("tile-background-big-01", 29, 1)
	map:addTile("tile-ground-02", 29, 5)
	map:addTile("tile-background-03", 29, 6)
	map:addTile("tile-background-cave-art-01", 29, 9)
	map:addTile("bridge-wall-right-01", 29, 9)
	map:addTile("tile-background-02", 30, 0)
	map:addTile("tile-background-01", 30, 3)
	map:addTile("tile-background-01", 30, 4)
	map:addTile("tile-ground-04", 30, 5)
	map:addTile("tile-background-04", 30, 6)
	map:addTile("tile-background-02", 30, 7)
	map:addTile("tile-background-01", 30, 8)
	map:addTile("tile-ground-04", 30, 9)
	map:addTile("tile-background-big-01", 31, 0)
	map:addTile("tile-ground-02", 31, 2)
	map:addTile("tile-rock-big-01", 31, 3)
	map:addTile("tile-rock-02", 31, 5)
	map:addTile("tile-background-02", 31, 6)
	map:addTile("tile-background-04", 31, 7)
	map:addTile("tile-background-01", 31, 8)
	map:addTile("tile-ground-02", 31, 9)
	map:addTile("tile-ground-04", 32, 2)
	map:addTile("tile-rock-slope-right-02", 32, 5)
	map:addTile("tile-background-01", 32, 6)
	map:addTile("tile-background-03", 32, 7)
	map:addTile("tile-rock-slope-left-01", 32, 8)
	map:addTile("tile-rock-01", 32, 9)
	map:addTile("tile-background-04", 33, 0)
	map:addTile("tile-background-02", 33, 1)
	map:addTile("tile-ground-02", 33, 2)
	map:addTile("tile-rock-03", 33, 3)
	map:addTile("tile-rock-slope-right-02", 33, 4)
	map:addTile("tile-background-02", 33, 5)
	map:addTile("tile-background-01", 33, 6)
	map:addTile("tile-background-01", 33, 7)
	map:addTile("tile-rock-slope-right-01", 33, 8)
	map:addTile("tile-rock-02", 33, 9)
	map:addTile("tile-background-01", 34, 0)
	map:addTile("tile-background-04", 34, 1)
	map:addTile("tile-ground-04", 34, 2)
	map:addTile("tile-rock-left-04", 34, 3)
	map:addTile("tile-background-big-01", 34, 4)
	map:addTile("tile-background-big-01", 34, 6)
	map:addTile("tile-background-02", 34, 8)
	map:addTile("tile-ground-03", 34, 9)
	map:addTile("tile-background-02", 35, 0)
	map:addTile("tile-background-02", 35, 1)
	map:addTile("tile-background-01", 35, 2)
	map:addTile("tile-background-02", 35, 3)
	map:addTile("tile-background-03", 35, 8)
	map:addTile("tile-ground-04", 35, 9)
	map:addTile("tile-background-04", 36, 0)
	map:addTile("tile-background-02", 36, 1)
	map:addTile("tile-background-02", 36, 2)
	map:addTile("tile-background-03", 36, 3)
	map:addTile("tile-background-02", 36, 4)
	map:addTile("tile-rock-right-04", 36, 5)
	map:addTile("tile-background-03", 36, 6)
	map:addTile("tile-background-02", 36, 7)
	map:addTile("tile-background-02", 36, 8)
	map:addTile("tile-ground-03", 36, 9)
	map:addTile("tile-rock-big-01", 37, 0)
	map:addTile("tile-rock-slope-left-02", 37, 2)
	map:addTile("tile-background-02", 37, 3)
	map:addTile("tile-background-01", 37, 4)
	map:addTile("tile-ground-03", 37, 5)
	map:addTile("tile-rock-shim-01", 37, 6)
	map:addTile("tile-background-02", 37, 7)
	map:addTile("tile-background-02", 37, 8)
	map:addTile("tile-packagetarget-rock-01-idle", 37, 9)
	map:addTile("tile-rock-02", 38, 2)
	map:addTile("tile-background-04", 38, 3)
	map:addTile("tile-background-02", 38, 4)
	map:addTile("tile-ground-04", 38, 5)
	map:addTile("tile-background-02", 38, 6)
	map:addTile("tile-background-02", 38, 7)
	map:addTile("tile-geyser-rock-01-active", 38, 8)
	map:addTile("tile-background-04", 39, 0)
	map:addTile("tile-ground-04", 39, 1)
	map:addTile("tile-rock-03", 39, 2)
	map:addTile("tile-rock-slope-left-02", 39, 3)
	map:addTile("tile-background-02", 39, 4)
	map:addTile("tile-ground-04", 39, 5)
	map:addTile("tile-background-03", 39, 6)
	map:addTile("tile-background-03", 39, 7)
	map:addTile("tile-background-04", 39, 8)
	map:addTile("tile-ground-04", 39, 9)
	map:addTile("liane-01", 39.8, 6)
	map:addTile("tile-background-01", 40, 0)
	map:addTile("tile-background-04", 40, 1)
	map:addTile("tile-ground-04", 40, 2)
	map:addTile("tile-rock-03", 40, 3)
	map:addTile("tile-rock-03", 40, 4)
	map:addTile("tile-rock-slope-right-02", 40, 5)
	map:addTile("tile-background-03", 40, 6)
	map:addTile("tile-background-04", 40, 7)
	map:addTile("tile-background-01", 40, 8)
	map:addTile("tile-ground-ledge-right-01", 40, 9)
	map:addTile("tile-background-04", 41, 0)
	map:addTile("tile-background-04", 41, 1)
	map:addTile("tile-ground-03", 41, 2)
	map:addTile("tile-rock-03", 41, 3)
	map:addTile("tile-rock-slope-right-02", 41, 4)
	map:addTile("tile-background-01", 41, 5)
	map:addTile("tile-background-02", 41, 6)
	map:addTile("tile-background-02", 41, 7)
	map:addTile("tile-background-01", 41, 8)
	map:addTile("tile-ground-ledge-right-02", 41, 9)
	map:addTile("tile-background-01", 42, 0)
	map:addTile("tile-background-big-01", 42, 1)
	map:addTile("tile-background-01", 42, 3)
	map:addTile("tile-background-01", 42, 4)
	map:addTile("tile-background-04", 42, 5)
	map:addTile("tile-background-big-01", 42, 6)
	map:addTile("tile-background-02", 42, 8)
	map:addTile("tile-ground-ledge-left-01", 42, 9)
	map:addTile("tile-background-01", 43, 0)
	map:addTile("tile-background-03", 43, 3)
	map:addTile("tile-background-01", 43, 4)
	map:addTile("tile-background-04", 43, 5)
	map:addTile("tile-rock-slope-left-01", 43, 8)
	map:addTile("tile-rock-02", 43, 9)
	map:addTile("tile-rock-big-01", 44, 0)
	map:addTile("tile-background-03", 44, 2)
	map:addTile("tile-background-04", 44, 3)
	map:addTile("tile-background-04", 44, 4)
	map:addTile("tile-background-03", 44, 5)
	map:addTile("tile-background-03", 44, 6)
	map:addTile("tile-rock-slope-left-01", 44, 7)
	map:addTile("tile-rock-big-01", 44, 8)
	map:addTile("liane-01", 44.7, 2)
	map:addTile("tile-background-04", 45, 2)
	map:addTile("tile-background-04", 45, 3)
	map:addTile("tile-background-02", 45, 4)
	map:addTile("tile-background-03", 45, 5)
	map:addTile("tile-background-01", 45, 6)
	map:addTile("tile-rock-slope-right-01", 45, 7)
	map:addTile("liane-01", 45.1, 2)
	map:addTile("tile-rock-01", 46, 0)
	map:addTile("tile-rock-slope-right-02", 46, 1)
	map:addTile("tile-background-04", 46, 2)
	map:addTile("tile-background-02", 46, 3)
	map:addTile("tile-ground-03", 46, 4)
	map:addTile("tile-rock-slope-left-02", 46, 5)
	map:addTile("tile-background-04", 46, 6)
	map:addTile("tile-background-02", 46, 7)
	map:addTile("tile-rock-slope-right-01", 46, 8)
	map:addTile("tile-rock-02", 46, 9)
	map:addTile("tile-background-big-01", 47, 0)
	map:addTile("tile-background-01", 47, 2)
	map:addTile("tile-background-01", 47, 3)
	map:addTile("tile-ground-01", 47, 4)
	map:addTile("tile-rock-big-01", 47, 5)
	map:addTile("tile-background-02", 47, 7)
	map:addTile("tile-background-01", 47, 8)
	map:addTile("tile-background-01", 47, 9)
	map:addTile("tile-background-01", 48, 2)
	map:addTile("tile-ground-03", 48, 3)
	map:addTile("tile-rock-03", 48, 4)
	map:addTile("tile-rock-slope-left-02", 48, 7)
	map:addTile("tile-background-03", 48, 8)
	map:addTile("tile-background-02", 48, 9)
	map:addTile("tile-background-01", 49, 0)
	map:addTile("tile-background-01", 49, 1)
	map:addTile("tile-background-01", 49, 2)
	map:addTile("tile-ground-01", 49, 3)
	map:addTile("tile-rock-01", 49, 4)
	map:addTile("tile-rock-02", 49, 5)
	map:addTile("tile-rock-02", 49, 6)
	map:addTile("tile-rock-02", 49, 7)
	map:addTile("tile-background-04", 49, 8)
	map:addTile("tile-background-01", 49, 9)
	map:addTile("tile-background-04", 50, 0)
	map:addTile("tile-background-03", 50, 1)
	map:addTile("tile-background-02", 50, 2)
	map:addTile("tile-ground-03", 50, 3)
	map:addTile("tile-rock-01", 50, 4)
	map:addTile("tile-rock-02", 50, 5)
	map:addTile("tile-rock-02", 50, 6)
	map:addTile("tile-rock-slope-right-02", 50, 7)
	map:addTile("tile-background-big-01", 50, 8)
	map:addTile("tile-background-02", 51, 0)
	map:addTile("tile-background-01", 51, 1)
	map:addTile("tile-background-03", 51, 2)
	map:addTile("tile-ground-01", 51, 3)
	map:addTile("tile-rock-03", 51, 4)
	map:addTile("tile-rock-03", 51, 5)
	map:addTile("tile-rock-slope-right-02", 51, 6)
	map:addTile("tile-background-04", 51, 7)
	map:addTile("tile-background-01", 52, 0)
	map:addTile("tile-background-03", 52, 1)
	map:addTile("tile-background-03", 52, 2)
	map:addTile("tile-ground-03", 52, 3)
	map:addTile("tile-rock-03", 52, 4)
	map:addTile("tile-rock-03", 52, 5)
	map:addTile("tile-background-01", 52, 6)
	map:addTile("liane-01", 52, 6)
	map:addTile("tile-background-04", 52, 7)
	map:addTile("tile-background-01", 52, 8)
	map:addTile("tile-background-01", 52, 9)
	map:addTile("tile-background-03", 53, 0)
	map:addTile("tile-background-01", 53, 1)
	map:addTile("tile-background-03", 53, 2)
	map:addTile("tile-background-01", 53, 3)
	map:addTile("tile-ground-01", 53, 4)
	map:addTile("tile-rock-slope-right-02", 53, 5)
	map:addTile("tile-background-03", 53, 6)
	map:addTile("tile-background-big-01", 53, 7)
	map:addTile("tile-background-04", 53, 9)
	map:addTile("tile-background-02", 54, 0)
	map:addTile("tile-background-02", 54, 1)
	map:addTile("tile-background-01", 54, 2)
	map:addTile("tile-background-big-01", 54, 3)
	map:addTile("tile-background-04", 54, 5)
	map:addTile("tile-background-01", 54, 6)
	map:addTile("tile-background-04", 54, 9)
	map:addTile("tile-rock-big-01", 55, 0)
	map:addTile("tile-rock-slope-left-02", 55, 2)
	map:addTile("tile-background-04", 55, 5)
	map:addTile("tile-background-04", 55, 6)
	map:addTile("tile-background-02", 55, 7)
	map:addTile("tile-background-03", 55, 8)
	map:addTile("tile-background-04", 55, 9)
	map:addTile("tile-rock-01", 56, 2)
	map:addTile("tile-rock-03", 56, 3)
	map:addTile("tile-rock-01", 56, 4)
	map:addTile("tile-rock-03", 56, 5)
	map:addTile("tile-rock-shim-01", 56, 6)
	map:addTile("tile-background-01", 56, 7)
	map:addTile("tile-background-02", 56, 8)
	map:addTile("tile-background-02", 56, 9)
	map:addTile("tile-background-01", 57, 0)
	map:addTile("tile-background-02", 57, 1)
	map:addTile("tile-background-02", 57, 2)
	map:addTile("tile-background-03", 57, 3)
	map:addTile("tile-background-03", 57, 4)
	map:addTile("tile-background-04", 57, 5)
	map:addTile("tile-background-01", 57, 6)
	map:addTile("tile-background-03", 57, 7)
	map:addTile("tile-background-04", 57, 8)
	map:addTile("tile-background-cave-art-01", 57, 9)
	map:addTile("tile-background-02", 58, 0)
	map:addTile("tile-background-03", 58, 1)
	map:addTile("tile-background-03", 58, 2)
	map:addTile("tile-background-01", 58, 3)
	map:addTile("tile-background-01", 58, 4)
	map:addTile("tile-background-01", 58, 5)
	map:addTile("tile-background-04", 58, 6)
	map:addTile("tile-background-cave-art-01", 58, 7)
	map:addTile("tile-background-04", 58, 8)
	map:addTile("tile-background-cave-art-01", 58, 9)
	map:addTile("tile-background-01", 59, 0)
	map:addTile("tile-background-03", 59, 1)
	map:addTile("tile-background-03", 59, 2)
	map:addTile("tile-ground-02", 59, 3)
	map:addTile("tile-rock-big-01", 59, 4)
	map:addTile("tile-rock-03", 59, 6)
	map:addTile("tile-rock-01", 59, 7)
	map:addTile("tile-rock-shim-01", 59, 8)
	map:addTile("tile-background-04", 59, 9)
	map:addTile("tile-background-04", 60, 0)
	map:addTile("tile-background-04", 60, 1)
	map:addTile("tile-background-04", 60, 2)
	map:addTile("tile-ground-03", 60, 3)
	map:addTile("tile-background-big-01", 60, 6)
	map:addTile("tile-background-big-01", 60, 8)
	map:addTile("tile-background-big-01", 61, 0)
	map:addTile("tile-background-01", 61, 2)
	map:addTile("tile-background-01", 61, 3)
	map:addTile("tile-background-03", 61, 4)
	map:addTile("tile-background-01", 61, 5)
	map:addTile("tile-background-big-01", 62, 2)
	map:addTile("tile-background-03", 62, 4)
	map:addTile("tile-background-04", 62, 5)
	map:addTile("tile-background-03", 62, 6)
	map:addTile("tile-background-01", 62, 7)
	map:addTile("tile-background-04", 62, 8)
	map:addTile("tile-background-01", 62, 9)
	map:addTile("tile-background-03", 63, 0)
	map:addTile("tile-background-01", 63, 1)
	map:addTile("tile-background-04", 63, 4)
	map:addTile("tile-background-01", 63, 5)
	map:addTile("tile-background-03", 63, 6)
	map:addTile("tile-background-03", 63, 7)
	map:addTile("tile-background-04", 63, 8)
	map:addTile("tile-background-03", 63, 9)
	map:addTile("tile-background-04", 64, 0)
	map:addTile("tile-background-03", 64, 1)
	map:addTile("tile-ground-02", 64, 2)
	map:addTile("tile-rock-slope-left-02", 64, 3)
	map:addTile("tile-background-03", 64, 4)
	map:addTile("tile-background-04", 64, 5)
	map:addTile("tile-background-04", 64, 6)
	map:addTile("tile-background-03", 64, 7)
	map:addTile("tile-background-03", 64, 8)
	map:addTile("tile-background-cave-art-01", 64, 9)
	map:addTile("tile-background-04", 65, 0)
	map:addTile("tile-background-03", 65, 1)
	map:addTile("tile-ground-03", 65, 2)
	map:addTile("tile-rock-03", 65, 3)
	map:addTile("tile-rock-02", 65, 4)
	map:addTile("tile-background-cave-art-01", 65, 5)
	map:addTile("tile-background-01", 65, 6)
	map:addTile("tile-background-03", 65, 7)
	map:addTile("tile-background-02", 65, 8)
	map:addTile("tile-background-cave-art-01", 65, 9)
	map:addTile("tile-background-04", 66, 0)
	map:addTile("tile-background-01", 66, 1)
	map:addTile("tile-ground-02", 66, 2)
	map:addTile("tile-rock-03", 66, 3)
	map:addTile("tile-rock-02", 66, 4)
	map:addTile("tile-rock-shim-01", 66, 5)
	map:addTile("tile-background-02", 66, 6)
	map:addTile("tile-background-01", 66, 7)
	map:addTile("tile-background-03", 66, 8)
	map:addTile("tile-background-04", 66, 9)
	map:addTile("tile-background-01", 67, 0)
	map:addTile("tile-background-03", 67, 1)
	map:addTile("tile-ground-01", 67, 2)
	map:addTile("tile-rock-big-01", 67, 3)
	map:addTile("tile-background-03", 67, 5)
	map:addTile("tile-background-04", 67, 6)
	map:addTile("tile-background-03", 67, 7)
	map:addTile("tile-background-03", 67, 8)
	map:addTile("tile-background-cave-art-01", 67, 9)
	map:addTile("liane-01", 67.4, 5)
	map:addTile("tile-background-01", 68, 0)
	map:addTile("tile-background-04", 68, 1)
	map:addTile("tile-ground-02", 68, 2)
	map:addTile("tile-background-01", 68, 5)
	map:addTile("liane-01", 68, 5)
	map:addTile("tile-background-01", 68, 6)
	map:addTile("tile-background-01", 68, 7)
	map:addTile("tile-background-03", 68, 8)
	map:addTile("tile-background-03", 68, 9)
	map:addTile("tile-background-01", 69, 0)
	map:addTile("tile-background-01", 69, 1)
	map:addTile("tile-ground-03", 69, 2)
	map:addTile("tile-rock-03", 69, 3)
	map:addTile("tile-rock-slope-right-02", 69, 4)
	map:addTile("tile-background-02", 69, 5)
	map:addTile("tile-background-04", 69, 6)
	map:addTile("tile-background-04", 69, 7)
	map:addTile("tile-background-01", 69, 8)
	map:addTile("tile-background-04", 69, 9)
	map:addTile("tile-background-big-01", 70, 0)
	map:addTile("tile-ground-03", 70, 2)
	map:addTile("tile-rock-02", 70, 3)
	map:addTile("tile-background-big-01", 70, 4)
	map:addTile("tile-background-02", 70, 6)
	map:addTile("tile-background-04", 70, 7)
	map:addTile("tile-background-03", 70, 8)
	map:addTile("tile-background-cave-art-01", 70, 9)
	map:addTile("tile-ground-02", 71, 2)
	map:addTile("tile-rock-02", 71, 3)
	map:addTile("tile-background-01", 71, 6)
	map:addTile("tile-rock-slope-left-01", 71, 7)
	map:addTile("tile-rock-big-01", 71, 8)
	map:addTile("tile-background-01", 72, 0)
	map:addTile("tile-background-03", 72, 1)
	map:addTile("tile-ground-03", 72, 2)
	map:addTile("tile-rock-big-01", 72, 3)
	map:addTile("tile-background-01", 72, 5)
	map:addTile("tile-background-04", 72, 6)
	map:addTile("tile-ground-04", 72, 7)
	map:addTile("tile-background-01", 73, 0)
	map:addTile("tile-background-01", 73, 1)
	map:addTile("tile-ground-03", 73, 2)
	map:addTile("tile-background-01", 73, 5)
	map:addTile("tile-background-01", 73, 6)
	map:addTile("tile-ground-03", 73, 7)
	map:addTile("tile-rock-02", 73, 8)
	map:addTile("tile-rock-02", 73, 9)
	map:addTile("liane-01", 73.4, 5)
	map:addTile("tile-background-big-01", 74, 0)
	map:addTile("tile-ground-02", 74, 2)
	map:addTile("tile-rock-03", 74, 3)
	map:addTile("tile-rock-slope-right-02", 74, 4)
	map:addTile("tile-background-02", 74, 5)
	map:addTile("tile-background-04", 74, 6)
	map:addTile("tile-ground-04", 74, 7)
	map:addTile("tile-rock-big-01", 74, 8)
	map:addTile("tile-ground-ledge-right-01", 75, 2)
	map:addTile("tile-background-01", 75, 3)
	map:addTile("tile-background-03", 75, 4)
	map:addTile("tile-background-04", 75, 5)
	map:addTile("tile-background-03", 75, 6)
	map:addTile("tile-ground-01", 75, 7)
	map:addTile("tile-background-04", 76, 0)
	map:addTile("tile-background-02", 76, 1)
	map:addTile("tile-ground-ledge-right-02", 76, 2)
	map:addTile("tile-background-02", 76, 3)
	map:addTile("tile-background-03", 76, 4)
	map:addTile("tile-background-04", 76, 5)
	map:addTile("tile-background-02", 76, 6)
	map:addTile("tile-ground-04", 76, 7)
	map:addTile("tile-rock-01", 76, 8)
	map:addTile("tile-rock-01", 76, 9)
	map:addTile("tile-background-big-01", 77, 0)
	map:addTile("tile-background-03", 77, 2)
	map:addTile("tile-background-04", 77, 3)
	map:addTile("tile-background-02", 77, 4)
	map:addTile("tile-background-04", 77, 5)
	map:addTile("tile-background-03", 77, 6)
	map:addTile("tile-ground-01", 77, 7)
	map:addTile("tile-rock-01", 77, 8)
	map:addTile("tile-rock-02", 77, 9)
	map:addTile("tile-background-01", 78, 2)
	map:addTile("tile-background-02", 78, 3)
	map:addTile("tile-background-03", 78, 4)
	map:addTile("tile-background-01", 78, 5)
	map:addTile("tile-background-02", 78, 6)
	map:addTile("tile-ground-02", 78, 7)
	map:addTile("tile-rock-03", 78, 8)
	map:addTile("tile-rock-01", 78, 9)
	map:addTile("tile-background-04", 79, 0)
	map:addTile("tile-background-03", 79, 1)
	map:addTile("tile-background-03", 79, 2)
	map:addTile("tile-background-02", 79, 3)
	map:addTile("tile-background-02", 79, 4)
	map:addTile("tile-background-01", 79, 5)
	map:addTile("tile-background-02", 79, 6)
	map:addTile("tile-ground-01", 79, 7)
	map:addTile("tile-rock-big-01", 79, 8)
	map:addTile("tile-background-02", 80, 0)
	map:addTile("tile-background-03", 80, 1)
	map:addTile("tile-background-01", 80, 2)
	map:addTile("tile-background-01", 80, 3)
	map:addTile("tile-background-01", 80, 4)
	map:addTile("tile-background-03", 80, 5)
	map:addTile("tile-background-cave-art-01", 80, 6)
	map:addTile("tile-ground-01", 80, 7)
	map:addTile("tile-background-03", 81, 0)
	map:addTile("tile-background-03", 81, 1)
	map:addTile("tile-background-04", 81, 2)
	map:addTile("tile-background-03", 81, 3)
	map:addTile("tile-ground-06", 81, 4)
	map:addTile("tile-background-04", 81, 5)
	map:addTile("tile-background-cave-art-01", 81, 6)
	map:addTile("tile-ground-04", 81, 7)
	map:addTile("tile-rock-03", 81, 8)
	map:addTile("tile-rock-01", 81, 9)
	map:addTile("tile-background-big-01", 82, 0)
	map:addTile("tile-background-02", 82, 2)
	map:addTile("tile-background-02", 82, 3)
	map:addTile("tile-ground-ledge-left-01", 82, 4)
	map:addTile("tile-background-01", 82, 5)
	map:addTile("tile-background-03", 82, 6)
	map:addTile("tile-background-04", 82, 7)
	map:addTile("tile-background-04", 82, 8)
	map:addTile("tile-background-04", 82, 9)
	map:addTile("tile-background-01", 83, 2)
	map:addTile("tile-background-03", 83, 3)
	map:addTile("tile-ground-01", 83, 4)
	map:addTile("tile-rock-shim-01", 83, 5)
	map:addTile("tile-background-cave-art-01", 83, 6)
	map:addTile("tile-background-04", 83, 7)
	map:addTile("tile-background-04", 83, 8)
	map:addTile("tile-background-cave-art-01", 83, 9)
	map:addTile("tile-background-big-01", 84, 0)
	map:addTile("tile-background-04", 84, 2)
	map:addTile("tile-ground-04", 84, 3)
	map:addTile("tile-rock-02", 84, 4)
	map:addTile("tile-background-cave-art-01", 84, 5)
	map:addTile("tile-background-03", 84, 6)
	map:addTile("tile-background-03", 84, 7)
	map:addTile("tile-background-big-01", 84, 8)
	map:addTile("tile-background-03", 85, 2)
	map:addTile("tile-ground-04", 85, 3)
	map:addTile("tile-rock-01", 85, 4)
	map:addTile("tile-background-03", 85, 5)
	map:addTile("tile-background-big-01", 85, 6)
	map:addTile("tile-background-03", 86, 0)
	map:addTile("tile-background-04", 86, 1)
	map:addTile("tile-background-02", 86, 2)
	map:addTile("tile-rock-01", 86, 3)
	map:addTile("tile-rock-02", 86, 4)
	map:addTile("tile-background-02", 86, 5)
	map:addTile("liane-01", 86, 5)
	map:addTile("tile-background-03", 86, 8)
	map:addTile("tile-background-04", 86, 9)
	map:addTile("tile-background-03", 87, 0)
	map:addTile("tile-background-03", 87, 1)
	map:addTile("tile-ground-02", 87, 2)
	map:addTile("tile-rock-03", 87, 3)
	map:addTile("tile-rock-02", 87, 4)
	map:addTile("tile-background-03", 87, 5)
	map:addTile("tile-background-01", 87, 6)
	map:addTile("tile-background-04", 87, 7)
	map:addTile("tile-background-03", 87, 8)
	map:addTile("tile-background-03", 87, 9)
	map:addTile("tile-background-04", 88, 0)
	map:addTile("tile-background-02", 88, 1)
	map:addTile("tile-ground-04", 88, 2)
	map:addTile("tile-rock-03", 88, 3)
	map:addTile("tile-rock-slope-right-02", 88, 4)
	map:addTile("tile-background-01", 88, 5)
	map:addTile("tile-background-03", 88, 6)
	map:addTile("tile-background-03", 88, 7)
	map:addTile("tile-background-02", 88, 8)
	map:addTile("tile-background-02", 88, 9)
	map:addTile("tile-background-big-01", 89, 0)
	map:addTile("tile-ground-01", 89, 2)
	map:addTile("tile-rock-03", 89, 3)
	map:addTile("tile-background-02", 89, 4)
	map:addTile("tile-background-01", 89, 5)
	map:addTile("tile-background-01", 89, 6)
	map:addTile("tile-background-01", 89, 7)
	map:addTile("tile-background-04", 89, 8)
	map:addTile("tile-background-03", 89, 9)
	map:addTile("liane-01", 89.4, 4)
	map:addTile("tile-ground-01", 90, 2)
	map:addTile("tile-rock-slope-right-02", 90, 3)
	map:addTile("tile-background-03", 90, 4)
	map:addTile("tile-background-04", 90, 5)
	map:addTile("tile-background-03", 90, 6)
	map:addTile("tile-background-04", 90, 7)
	map:addTile("tile-background-big-01", 90, 8)
	map:addTile("tile-background-02", 91, 0)
	map:addTile("tile-background-03", 91, 1)
	map:addTile("tile-rock-left-04", 91, 2)
	map:addTile("tile-background-02", 91, 3)
	map:addTile("tile-background-03", 91, 4)
	map:addTile("tile-background-02", 91, 5)
	map:addTile("tile-background-03", 91, 6)
	map:addTile("tile-background-02", 91, 7)
	map:addTile("tile-background-big-01", 92, 0)
	map:addTile("tile-background-01", 92, 2)
	map:addTile("tile-background-04", 92, 3)
	map:addTile("tile-background-02", 92, 4)
	map:addTile("tile-background-02", 92, 5)
	map:addTile("tile-background-01", 92, 6)
	map:addTile("tile-background-03", 92, 7)
	map:addTile("tile-background-04", 92, 8)
	map:addTile("tile-background-03", 92, 9)
	map:addTile("tile-background-04", 93, 2)
	map:addTile("tile-background-02", 93, 3)
	map:addTile("tile-background-04", 93, 4)
	map:addTile("tile-ground-03", 93, 5)
	map:addTile("tile-background-04", 93, 6)
	map:addTile("tile-background-big-01", 93, 7)
	map:addTile("tile-background-01", 93, 9)
	map:addTile("tile-background-04", 94, 0)
	map:addTile("tile-background-04", 94, 1)
	map:addTile("tile-background-02", 94, 2)
	map:addTile("tile-background-02", 94, 3)
	map:addTile("tile-background-04", 94, 4)
	map:addTile("tile-ground-01", 94, 5)
	map:addTile("tile-rock-slope-left-02", 94, 6)
	map:addTile("tile-background-cave-art-01", 94, 9)
	map:addTile("tile-background-big-01", 95, 0)
	map:addTile("tile-background-big-01", 95, 2)
	map:addTile("tile-ground-01", 95, 4)
	map:addTile("tile-rock-big-01", 95, 5)
	map:addTile("tile-background-big-01", 95, 7)
	map:addTile("tile-background-02", 95, 9)
	map:addTile("tile-ground-01", 96, 4)
	map:addTile("tile-background-01", 96, 9)
	map:addTile("tile-background-01", 97, 0)
	map:addTile("tile-background-04", 97, 1)
	map:addTile("tile-background-01", 97, 2)
	map:addTile("tile-background-02", 97, 3)
	map:addTile("tile-ground-03", 97, 4)
	map:addTile("tile-rock-03", 97, 5)
	map:addTile("tile-rock-slope-right-02", 97, 6)
	map:addTile("tile-background-01", 97, 7)
	map:addTile("tile-background-02", 97, 8)
	map:addTile("tile-background-01", 97, 9)
	map:addTile("tile-background-04", 98, 0)
	map:addTile("tile-background-03", 98, 1)
	map:addTile("tile-ground-03", 98, 2)
	map:addTile("tile-rock-big-01", 98, 3)
	map:addTile("tile-rock-left-04", 98, 5)
	map:addTile("tile-background-03", 98, 6)
	map:addTile("tile-background-big-01", 98, 7)
	map:addTile("tile-background-02", 98, 9)
	map:addTile("tile-background-01", 99, 0)
	map:addTile("tile-background-03", 99, 1)
	map:addTile("tile-ground-03", 99, 2)
	map:addTile("tile-background-04", 99, 5)
	map:addTile("liane-01", 99, 5)
	map:addTile("liane-01", 99, 5)
	map:addTile("liane-01", 99, 5)
	map:addTile("tile-background-03", 99, 6)
	map:addTile("tile-background-04", 99, 9)
	map:addTile("tile-background-02", 100, 0)
	map:addTile("tile-background-02", 100, 1)
	map:addTile("tile-ground-03", 100, 2)
	map:addTile("tile-rock-03", 100, 3)
	map:addTile("tile-rock-big-01", 100, 4)
	map:addTile("tile-background-03", 100, 6)
	map:addTile("tile-background-big-01", 100, 7)
	map:addTile("tile-background-03", 100, 9)
	map:addTile("liane-01", 100.4, 6)
	map:addTile("tile-background-04", 101, 0)
	map:addTile("tile-background-03", 101, 1)
	map:addTile("tile-ground-03", 101, 2)
	map:addTile("tile-rock-03", 101, 3)
	map:addTile("tile-rock-slope-left-02", 101, 6)
	map:addTile("tile-background-04", 101, 9)
	map:addTile("tile-background-04", 102, 0)
	map:addTile("tile-background-03", 102, 1)
	map:addTile("tile-ground-01", 102, 2)
	map:addTile("tile-rock-01", 102, 3)
	map:addTile("tile-rock-01", 102, 4)
	map:addTile("tile-rock-02", 102, 5)
	map:addTile("tile-rock-02", 102, 6)
	map:addTile("tile-background-03", 102, 7)
	map:addTile("tile-background-02", 102, 8)
	map:addTile("tile-background-02", 102, 9)
	map:addTile("tile-background-02", 103, 0)
	map:addTile("tile-background-04", 103, 1)
	map:addTile("tile-background-03", 103, 2)
	map:addTile("tile-ground-03", 103, 3)
	map:addTile("tile-rock-slope-right-02", 103, 4)
	map:addTile("tile-background-03", 103, 5)
	map:addTile("tile-background-02", 103, 6)
	map:addTile("tile-background-04", 103, 7)
	map:addTile("tile-background-03", 103, 8)
	map:addTile("tile-rock-slope-left-01", 103, 9)
	map:addTile("tile-background-01", 104, 0)
	map:addTile("tile-background-02", 104, 1)
	map:addTile("tile-background-01", 104, 2)
	map:addTile("tile-background-02", 104, 3)
	map:addTile("tile-background-01", 104, 4)
	map:addTile("tile-background-02", 104, 5)
	map:addTile("tile-background-02", 104, 6)
	map:addTile("tile-background-04", 104, 7)
	map:addTile("tile-rock-slope-left-01", 104, 8)
	map:addTile("tile-rock-01", 104, 9)
	map:addTile("tile-background-02", 105, 0)
	map:addTile("tile-background-01", 105, 1)
	map:addTile("tile-background-01", 105, 2)
	map:addTile("tile-background-02", 105, 3)
	map:addTile("tile-background-01", 105, 4)
	map:addTile("tile-background-03", 105, 5)
	map:addTile("tile-background-03", 105, 6)
	map:addTile("tile-rock-slope-left-01", 105, 7)
	map:addTile("tile-rock-01", 105, 8)
	map:addTile("tile-rock-03", 105, 9)
	map:addTile("tile-background-01", 106, 0)
	map:addTile("tile-background-01", 106, 1)
	map:addTile("tile-background-01", 106, 2)
	map:addTile("tile-ground-03", 106, 3)
	map:addTile("tile-rock-01", 106, 4)
	map:addTile("tile-rock-big-01", 106, 5)
	map:addTile("tile-rock-01", 106, 7)
	map:addTile("tile-rock-big-01", 106, 8)
	map:addTile("tile-background-01", 107, 0)
	map:addTile("tile-background-04", 107, 1)
	map:addTile("tile-background-03", 107, 2)
	map:addTile("tile-packagetarget-rock-01-idle", 107, 3)
	map:addTile("tile-rock-03", 107, 4)
	map:addTile("tile-rock-02", 107, 7)
	map:addTile("liane-01", 107.4, 0)
	map:addTile("tile-background-big-01", 108, 0)
	map:addTile("tile-ground-04", 108, 2)
	map:addTile("tile-rock-02", 108, 3)
	map:addTile("tile-rock-01", 108, 4)
	map:addTile("tile-rock-03", 108, 5)
	map:addTile("tile-rock-01", 108, 6)
	map:addTile("tile-rock-02", 108, 7)
	map:addTile("tile-rock-01", 108, 8)
	map:addTile("tile-rock-02", 108, 9)
	map:addTile("tile-ground-03", 109, 2)
	map:addTile("tile-rock-01", 109, 3)
	map:addTile("tile-rock-big-01", 109, 4)
	map:addTile("tile-rock-02", 109, 6)
	map:addTile("tile-rock-big-01", 109, 7)
	map:addTile("tile-rock-01", 109, 9)
	map:addTile("tile-background-cave-art-01", 110, 0)
	map:addTile("tile-background-01", 110, 1)
	map:addTile("tile-ground-04", 110, 2)
	map:addTile("tile-rock-03", 110, 3)
	map:addTile("tile-rock-02", 110, 6)
	map:addTile("tile-rock-01", 110, 9)
	map:addTile("tile-background-big-01", 111, 0)
	map:addTile("liane-01", 111, 0)
	map:addTile("tile-ground-04", 111, 2)
	map:addTile("tile-rock-02", 111, 3)
	map:addTile("tile-rock-02", 111, 4)
	map:addTile("tile-rock-02", 111, 5)
	map:addTile("tile-rock-01", 111, 6)
	map:addTile("tile-rock-01", 111, 7)
	map:addTile("tile-rock-big-01", 111, 8)
	map:addTile("tile-ground-02", 112, 2)
	map:addTile("tile-rock-03", 112, 3)
	map:addTile("tile-rock-01", 112, 4)
	map:addTile("tile-rock-big-01", 112, 5)
	map:addTile("tile-rock-01", 112, 7)
	map:addTile("tile-background-03", 113, 0)
	map:addTile("tile-background-02", 113, 1)
	map:addTile("tile-rock-slope-right-01", 113, 2)
	map:addTile("tile-rock-03", 113, 3)
	map:addTile("tile-rock-01", 113, 4)
	map:addTile("tile-rock-01", 113, 7)
	map:addTile("tile-rock-01", 113, 8)
	map:addTile("tile-rock-01", 113, 9)
	map:addTile("tile-rock-slope-left-02", 114, 0)
	map:addTile("tile-background-02", 114, 1)
	map:addTile("tile-background-01", 114, 2)
	map:addTile("tile-rock-slope-right-01", 114, 3)
	map:addTile("tile-rock-03", 114, 4)
	map:addTile("tile-rock-01", 114, 5)
	map:addTile("tile-rock-01", 114, 6)
	map:addTile("tile-rock-01", 114, 7)
	map:addTile("tile-rock-big-01", 114, 8)
	map:addTile("tile-rock-01", 115, 0)
	map:addTile("tile-rock-right-04", 115, 1)
	map:addTile("tile-background-02", 115, 2)
	map:addTile("tile-background-02", 115, 3)
	map:addTile("tile-rock-slope-right-01", 115, 4)
	map:addTile("tile-rock-03", 115, 5)
	map:addTile("tile-rock-big-01", 115, 6)
	map:addTile("tile-rock-big-01", 116, 0)
	map:addTile("tile-rock-slope-left-02", 116, 2)
	map:addTile("tile-background-cave-art-01", 116, 3)
	map:addTile("tile-background-02", 116, 4)
	map:addTile("tile-rock-slope-right-01", 116, 5)
	map:addTile("tile-rock-01", 116, 8)
	map:addTile("tile-rock-01", 116, 9)
	map:addTile("tile-rock-01", 117, 2)
	map:addTile("tile-rock-slope-left-02", 117, 3)
	map:addTile("tile-background-01", 117, 4)
	map:addTile("tile-background-cave-art-01", 117, 5)
	map:addTile("tile-background-02", 117, 6)
	map:addTile("tile-background-02", 117, 7)
	map:addTile("tile-rock-slope-right-01", 117, 8)
	map:addTile("tile-rock-01", 117, 9)
	map:addTile("tile-rock-02", 118, 0)
	map:addTile("tile-rock-big-01", 118, 1)
	map:addTile("tile-rock-01", 118, 3)
	map:addTile("tile-rock-right-04", 118, 4)
	map:addTile("tile-background-01", 118, 5)
	map:addTile("tile-background-02", 118, 6)
	map:addTile("tile-background-03", 118, 7)
	map:addTile("tile-background-04", 118, 8)
	map:addTile("tile-packagetarget-rock-01-idle", 118, 9)
	map:addTile("tile-rock-02", 119, 0)
	map:addTile("tile-rock-02", 119, 3)
	map:addTile("tile-rock-02", 119, 4)
	map:addTile("tile-rock-slope-left-02", 119, 5)
	map:addTile("tile-background-03", 119, 6)
	map:addTile("tile-background-02", 119, 7)
	map:addTile("tile-background-04", 119, 8)
	map:addTile("tile-ground-02", 119, 9)
	map:addTile("tile-rock-big-01", 120, 0)
	map:addTile("tile-rock-02", 120, 2)
	map:addTile("tile-rock-02", 120, 3)
	map:addTile("tile-rock-01", 120, 4)
	map:addTile("tile-rock-03", 120, 5)
	map:addTile("tile-rock-right-04", 120, 6)
	map:addTile("tile-background-03", 120, 7)
	map:addTile("tile-background-01", 120, 8)
	map:addTile("tile-rock-slope-right-01", 120, 9)
	map:addTile("tile-background-03", 121, 2)
	map:addTile("tile-rock-slope-right-01", 121, 3)
	map:addTile("tile-ground-01", 121, 4)
	map:addTile("tile-rock-02", 121, 5)
	map:addTile("tile-rock-01", 121, 6)
	map:addTile("tile-rock-shim-01", 121, 7)
	map:addTile("tile-background-04", 121, 8)
	map:addTile("tile-background-03", 121, 9)
	map:addTile("tile-rock-big-01", 122, 0)
	map:addTile("tile-background-03", 122, 2)
	map:addTile("tile-background-cave-art-01", 122, 3)
	map:addTile("tile-ground-02", 122, 4)
	map:addTile("tile-rock-02", 122, 5)
	map:addTile("tile-rock-slope-right-02", 122, 6)
	map:addTile("tile-background-02", 122, 7)
	map:addTile("tile-background-04", 122, 8)
	map:addTile("tile-background-cave-art-01", 122, 9)
	map:addTile("tile-background-01", 123, 2)
	map:addTile("tile-background-03", 123, 3)
	map:addTile("tile-ground-01", 123, 4)
	map:addTile("tile-rock-slope-right-02", 123, 5)
	map:addTile("tile-background-02", 123, 6)
	map:addTile("tile-background-01", 123, 7)
	map:addTile("tile-background-02", 123, 8)
	map:addTile("tile-rock-slope-left-01", 123, 9)
	map:addTile("tile-rock-02", 124, 0)
	map:addTile("tile-rock-left-04", 124, 1)
	map:addTile("tile-background-02", 124, 2)
	map:addTile("tile-background-04", 124, 3)
	map:addTile("tile-ground-ledge-right-01", 124, 4)
	map:addTile("tile-background-01", 124, 5)
	map:addTile("tile-background-02", 124, 6)
	map:addTile("tile-background-03", 124, 7)
	map:addTile("tile-rock-slope-left-01", 124, 8)
	map:addTile("tile-rock-01", 124, 9)
	map:addTile("tile-rock-slope-right-02", 125, 0)
	map:addTile("tile-background-02", 125, 1)
	map:addTile("tile-background-02", 125, 2)
	map:addTile("tile-background-02", 125, 3)
	map:addTile("tile-ground-06", 125, 4)
	map:addTile("tile-background-02", 125, 5)
	map:addTile("tile-background-02", 125, 6)
	map:addTile("tile-rock-slope-left-01", 125, 7)
	map:addTile("tile-rock-big-01", 125, 8)
	map:addTile("tile-background-03", 126, 0)
	map:addTile("tile-background-03", 126, 1)
	map:addTile("tile-background-02", 126, 2)
	map:addTile("tile-background-03", 126, 3)
	map:addTile("tile-background-02", 126, 4)
	map:addTile("tile-background-02", 126, 5)
	map:addTile("tile-background-01", 126, 6)
	map:addTile("tile-ground-03", 126, 7)
	map:addTile("tile-background-01", 127, 0)
	map:addTile("tile-background-01", 127, 1)
	map:addTile("tile-background-02", 127, 2)
	map:addTile("tile-background-big-01", 127, 3)
	map:addTile("tile-background-02", 127, 5)
	map:addTile("tile-rock-slope-left-01", 127, 6)
	map:addTile("tile-rock-01", 127, 7)
	map:addTile("tile-rock-01", 127, 8)
	map:addTile("tile-rock-01", 127, 9)
	map:addTile("tile-background-02", 128, 0)
	map:addTile("tile-background-03", 128, 1)
	map:addTile("tile-background-01", 128, 2)
	map:addTile("tile-rock-slope-left-01", 128, 5)
	map:addTile("tile-rock-big-01", 128, 6)
	map:addTile("tile-rock-big-01", 128, 8)
	map:addTile("tile-background-03", 129, 0)
	map:addTile("tile-background-02", 129, 1)
	map:addTile("tile-ground-03", 129, 2)
	map:addTile("tile-rock-02", 129, 3)
	map:addTile("tile-rock-02", 129, 4)
	map:addTile("tile-rock-01", 129, 5)
	map:addTile("tile-background-cave-art-01", 130, 0)
	map:addTile("tile-background-cave-art-01", 130, 1)
	map:addTile("tile-ground-03", 130, 2)
	map:addTile("tile-rock-02", 130, 3)
	map:addTile("tile-rock-01", 130, 4)
	map:addTile("tile-rock-02", 130, 5)
	map:addTile("tile-rock-01", 130, 6)
	map:addTile("tile-rock-01", 130, 7)
	map:addTile("tile-rock-01", 130, 8)
	map:addTile("tile-rock-01", 130, 9)

	map:addEmitter("item-package", 2, 1, 1, 0, "")
	map:addEmitter("tree", 5, 2, 1, 0, "")
	map:addEmitter("item-apple", 10, 4, 1, 0, "")
	map:addEmitter("tree", 15, 7, 1, 0, "")
	map:addEmitter("item-stone", 16, 1, 1, 0, "")
	map:addEmitter("item-package", 19, 8, 1, 0, "")
	map:addEmitter("item-stone", 20, 8, 1, 0, "")
	map:addEmitter("npc-walking", 22, 4, 1, 0, "")
	map:addEmitter("tree", 23, 3, 1, 0, "")
	map:addEmitter("item-package", 30, 4, 1, 0, "")
	map:addEmitter("item-egg", 31, 8, 1, 0, "")
	map:addEmitter("tree", 34, 7, 1, 0, "")
	map:addEmitter("npc-walking", 38, 4, 1, 0, "right=false")
	map:addEmitter("item-apple", 40, 8, 1, 0, "")
	map:addEmitter("item-stone", 41, 8, 1, 0, "")
	map:addEmitter("item-apple", 46, 3, 1, 0, "")
	map:addEmitter("npc-blowing", 49, 2, 1, 0, "right=false")
	map:addEmitter("item-stone", 53, 3, 1, 0, "")
	map:addEmitter("tree", 59, 1, 1, 0, "")
	map:addEmitter("npc-walking", 68, 1, 1, 0, "right=false")
	map:addEmitter("item-stone", 72, 6, 1, 0, "")
	map:addEmitter("tree", 76, 5, 1, 0, "")
	map:addEmitter("npc-blowing", 79, 6, 1, 0, "")
	map:addEmitter("npc-walking", 85, 2, 1, 0, "")
	map:addEmitter("tree", 95, 2, 1, 0, "")
	map:addEmitter("item-package", 97, 3, 1, 0, "")
	map:addEmitter("item-apple", 108, 1, 1, 0, "")
	map:addEmitter("item-stone", 119, 8, 1, 0, "")
	map:addEmitter("tree", 122, 2, 1, 0, "")

	map:setSetting("width", "131")
	map:setSetting("height", "10")
	map:setSetting("fishnpc", "false")
	map:setSetting("flyingnpc", "false")
	map:setSetting("gravity", "9.81")
	map:setSetting("packagetransfercount", "3")
	map:setSetting("points", "100")
	map:setSetting("referencetime", "30")
	map:setSetting("sideborderfail", "true")
	map:setSetting("theme", "rock")
	map:setSetting("waterchangespeed", "0")
	map:setSetting("waterfallingdelay", "0")
	map:setSetting("waterheight", "0.8")
	map:setSetting("waterrisingdelay", "0")
	map:setSetting("wind", "4")
	map:addStartPosition("1", "1")
end
