ur3ur3u3l4dlruurr4d3lud3r4ull3dldr4urr3dl3dldr3ur3urrdlulull3dldrur3drrddlullr3urru3luuldr3u3l3drrur3u3rddl3drdlul3dlld3rdrruuld2(ullu)3r3ur2(rdlul3d)ldrrl3ur3urrdlulddrdlul3dldllurdrr3ur4ull3dldrur3drdllr3ul5u3l3drrurddldrur3d3r3dlluulrddrruluddlu
