rruu3lul3dlluul3u3rur3dld3rur3drruur3u3lul3dr3d3ldl3u3rurddul3u4rddl3d3ldrurruu3rurddul3u3r3uruul4dr3drdldd4l4r5u3lul3drd3l3ul3uruul4drd3l3uluur4dld3rur3dlddu3rurddul3u4r5d3luu3l3u4lddr3drrlluu2(3l3u)luur4dld3rur3dlddu3rurddul3u4rddl3dllddrul3u3l3u4lddr3drrlluu3lulddur3u3l3uluur4dl3dldrdd4r4l5u3rur3dld3rurddul3u3r3uruul4dr3dl3dllrrddlur3ur3u3l3ul4ur6dl3drd3lulddur3u4l5d3ruur3ul3uruul4drd3l3ul4ur6dl3drddldr3ulldrurddl4u3r3ur4ul6drd3lul5d4u4rddld2(3r3u)r4ul6drd3lul3drddu3lulddu3r3u4rddld3r3ur3ul4ur6dld3r3ur4ul6drd3lul3drddu3lulddu3r3u4rddld3r3ur3uluur4dld3r3ur4ul6dr3dlddrdl3urrdl3u3l3ul4ur6dl3drddu3lulddu3r3u3rur5duuldd
