u5l4drdrru5rdldd3ldllu4rdrrul3u4ldllulld3rll5u5rdd4l4ruu5l4dldrr2(l3ul)ul4dlddrddldd3(rurrdr)rul3u6ld2(l3ul)l3dlddrddldd3(rurrdr)u3ldllurr4ldllu4rdrrurrdrruluuru7ldlluruu5ruu5ldlluull3dlddrddld3r2(drrurr)dr3uru5l4r3d3ldllu4rdr3uru4l3r3d7ldllu8rdr3uru3lrr3d11l3uluur4dld11rdr3urullr3d11l8urrddrr3dldr5u3rdurrdd4l4rurrdrrurrdl4drddlulldl3urul3d11l8urrddrr3d4urdurrddll4rurrdrrurrdl4drd3ldl3udd11l8u2(rrdd)u5rurrdrrur5drd3ldluu
