function getName()
	return "Wind 01"
end

function onMapLoaded()
end

function initMap()
	-- get the current map context
	local map = Map.get()
	map:addTile("tile-background-ice-03", 0, 0)
	map:addTile("tile-background-ice-05", 0, 1)
	map:addTile("tile-background-ice-08", 0, 2)
	map:addTile("tile-background-ice-05", 0, 3)
	map:addTile("tile-background-ice-cave-art-02", 0, 4)
	map:addTile("tile-rock-slope-ice-right-01", 0, 5)
	map:addTile("tile-rock-ice-02", 0, 6)
	map:addTile("tile-rock-ice-02", 0, 7)
	map:addTile("tile-rock-ice-right-04", 1, 0)
	map:addTile("tile-rock-ice-right-05", 1, 1)
	map:addTile("tile-ground-ledge-ice-left-02", 1, 2)
	map:addTile("tile-background-ice-06", 1, 3)
	map:addTile("tile-background-ice-08", 1, 4)
	map:addTile("tile-background-ice-06", 1, 5)
	map:addTile("tile-ground-ice-big-01", 1, 6)
	map:addTile("tile-rock-ice-01", 2, 0)
	map:addTile("tile-rock-ice-02", 2, 1)
	map:addTile("tile-rock-ice-01", 2, 2)
	map:addTile("tile-rock-shim-ice-01", 2, 3)
	map:addTile("tile-background-ice-06", 2, 4)
	map:addTile("tile-background-ice-05", 2, 5)
	map:addTile("tile-background-ice-cave-art-02", 3, 0)
	map:addTile("tile-background-ice-cave-art-02", 3, 1)
	map:addTile("tile-ground-ledge-ice-right-02", 3, 2)
	map:addTile("tile-background-ice-05", 3, 3)
	map:addTile("tile-background-ice-03", 3, 4)
	map:addTile("tile-geyser-ice-01-active", 3, 5)
	map:addTile("tile-rock-ice-02", 3, 7)
	map:addTile("tile-background-ice-01", 4, 0)
	map:addTile("tile-background-ice-06", 4, 1)
	map:addTile("tile-ground-ice-05", 4, 2)
	map:addTile("tile-background-ice-01", 4, 3)
	map:addTile("tile-background-ice-01", 4, 4)
	map:addTile("tile-background-ice-cave-art-02", 4, 5)
	map:addTile("tile-background-ice-07", 4, 6)
	map:addTile("tile-background-ice-03", 4, 7)
	map:addTile("tile-background-ice-04", 5, 0)
	map:addTile("tile-background-ice-06", 5, 1)
	map:addTile("tile-background-ice-cave-art-02", 5, 2)
	map:addTile("tile-background-ice-04", 5, 3)
	map:addTile("tile-background-ice-02", 5, 4)
	map:addTile("tile-background-ice-05", 5, 5)
	map:addTile("tile-background-ice-06", 5, 6)
	map:addTile("tile-background-ice-07", 5, 7)
	map:addTile("tile-background-ice-05", 6, 0)
	map:addTile("tile-background-ice-06", 6, 1)
	map:addTile("tile-background-ice-08", 6, 2)
	map:addTile("tile-ground-ice-03", 6, 3)
	map:addTile("tile-rock-ice-02", 6, 4)
	map:addTile("tile-rock-shim-ice-01", 6, 5)
	map:addTile("tile-background-ice-08", 6, 6)
	map:addTile("tile-background-ice-cave-art-01", 6, 7)
	map:addTile("tile-background-ice-05", 7, 0)
	map:addTile("tile-background-ice-02", 7, 1)
	map:addTile("tile-background-ice-06", 7, 2)
	map:addTile("tile-background-ice-05", 7, 3)
	map:addTile("tile-background-ice-08", 7, 4)
	map:addTile("tile-background-ice-06", 7, 5)
	map:addTile("tile-background-ice-07", 7, 6)
	map:addTile("tile-background-ice-07", 7, 7)
	map:addTile("tile-background-ice-03", 8, 0)
	map:addTile("tile-background-ice-01", 8, 1)
	map:addTile("tile-background-ice-06", 8, 2)
	map:addTile("tile-background-ice-02", 8, 3)
	map:addTile("tile-background-ice-06", 8, 4)
	map:addTile("tile-background-ice-04", 8, 5)
	map:addTile("tile-background-ice-03", 8, 6)
	map:addTile("tile-background-ice-07", 8, 7)
	map:addTile("tile-rock-ice-02", 9, 0)
	map:addTile("tile-rock-ice-01", 9, 1)
	map:addTile("tile-rock-shim-ice-01", 9, 2)
	map:addTile("tile-background-ice-03", 9, 3)
	map:addTile("tile-background-ice-07", 9, 4)
	map:addTile("tile-background-ice-08", 9, 5)
	map:addTile("tile-rock-slope-ice-left-01", 9, 6)
	map:addTile("tile-rock-ice-02", 9, 7)
	map:addTile("tile-background-ice-08", 10, 0)
	map:addTile("tile-background-ice-04", 10, 1)
	map:addTile("tile-background-ice-08", 10, 2)
	map:addTile("tile-background-ice-04", 10, 3)
	map:addTile("tile-background-ice-06", 10, 4)
	map:addTile("tile-background-ice-05", 10, 5)
	map:addTile("tile-ground-ice-big-01", 10, 6)
	map:addTile("tile-background-ice-04", 11, 0)
	map:addTile("tile-background-ice-05", 11, 1)
	map:addTile("tile-background-ice-cave-art-02", 11, 2)
	map:addTile("tile-background-ice-06", 11, 3)
	map:addTile("tile-background-ice-01", 11, 4)
	map:addTile("tile-background-ice-07", 11, 5)
	map:addTile("tile-background-ice-07", 12, 0)
	map:addTile("tile-background-ice-02", 12, 1)
	map:addTile("tile-background-ice-cave-art-02", 12, 2)
	map:addTile("tile-background-ice-03", 12, 3)
	map:addTile("tile-ground-ice-03", 12, 4)
	map:addTile("tile-rock-ice-01", 12, 5)
	map:addTile("tile-rock-ice-02", 12, 6)
	map:addTile("tile-rock-ice-02", 12, 7)
	map:addTile("tile-rock-shim-ice-01", 13, 0)
	map:addTile("tile-background-ice-03", 13, 1)
	map:addTile("tile-background-ice-01", 13, 2)
	map:addTile("tile-ground-ice-03", 13, 3)
	map:addTile("tile-rock-slope-ice-right-02", 13, 4)
	map:addTile("tile-rock-slope-ice-right-01", 13, 5)
	map:addTile("tile-rock-ice-02", 13, 6)
	map:addTile("tile-rock-ice-02", 13, 7)
	map:addTile("tile-background-ice-03", 14, 0)
	map:addTile("tile-background-ice-05", 14, 1)
	map:addTile("tile-background-ice-cave-art-02", 14, 2)
	map:addTile("tile-background-ice-03", 14, 3)
	map:addTile("tile-background-ice-cave-art-02", 14, 4)
	map:addTile("tile-background-ice-06", 14, 5)
	map:addTile("tile-ground-ice-03", 14, 6)
	map:addTile("tile-rock-ice-02", 14, 7)
	map:addTile("tile-background-ice-02", 15, 0)
	map:addTile("tile-background-ice-05", 15, 1)
	map:addTile("tile-background-ice-cave-art-02", 15, 2)
	map:addTile("tile-background-ice-03", 15, 3)
	map:addTile("tile-background-ice-08", 15, 4)
	map:addTile("tile-background-ice-04", 15, 5)
	map:addTile("tile-packagetarget-ice-01-idle", 15, 6)
	map:addTile("tile-rock-ice-03", 15, 7)
	map:addTile("tile-rock-ice-02", 16, 0)
	map:addTile("tile-rock-ice-02", 16, 1)
	map:addTile("tile-rock-shim-ice-01", 16, 2)
	map:addTile("tile-background-ice-06", 16, 3)
	map:addTile("tile-background-ice-01", 16, 4)
	map:addTile("tile-ground-ice-big-01", 16, 5)
	map:addTile("tile-rock-ice-02", 16, 7)
	map:addTile("tile-rock-slope-ice-right-02", 17, 0)
	map:addTile("tile-background-ice-08", 17, 1)
	map:addTile("tile-background-ice-01", 17, 2)
	map:addTile("tile-background-ice-06", 17, 3)
	map:addTile("tile-background-ice-05", 17, 4)
	map:addTile("tile-rock-ice-03", 17, 7)
	map:addTile("tile-background-ice-08", 18, 0)
	map:addTile("tile-background-ice-04", 18, 1)
	map:addTile("tile-background-ice-03", 18, 2)
	map:addTile("tile-background-ice-01", 18, 3)
	map:addTile("tile-background-ice-06", 18, 4)
	map:addTile("tile-ground-ice-01", 18, 5)
	map:addTile("tile-rock-ice-big-01", 18, 6)
	map:addTile("tile-background-ice-01", 19, 0)
	map:addTile("tile-background-ice-04", 19, 1)
	map:addTile("tile-background-ice-02", 19, 2)
	map:addTile("tile-rock-slope-ice-left-01", 19, 3)
	map:addTile("tile-rock-ice-02", 19, 4)
	map:addTile("tile-rock-ice-02", 19, 5)
	map:addTile("tile-rock-slope-ice-left-02", 20, 0)
	map:addTile("tile-background-ice-04", 20, 1)
	map:addTile("tile-background-ice-04", 20, 2)
	map:addTile("tile-rock-slope-ice-right-01", 20, 3)
	map:addTile("tile-rock-ice-03", 20, 4)
	map:addTile("tile-ground-ledge-ice-right-01", 20, 5)
	map:addTile("tile-background-ice-01", 20, 6)
	map:addTile("tile-ground-ledge-ice-right-01", 20, 7)
	map:addTile("tile-rock-ice-01", 21, 0)
	map:addTile("tile-rock-slope-ice-left-02", 21, 1)
	map:addTile("tile-background-ice-07", 21, 2)
	map:addTile("tile-background-ice-cave-art-02", 21, 3)
	map:addTile("tile-background-ice-02", 21, 4)
	map:addTile("tile-background-ice-07", 21, 5)
	map:addTile("tile-background-ice-01", 21, 6)
	map:addTile("tile-ground-ledge-ice-right-02", 21, 7)
	map:addTile("tile-rock-ice-01", 22, 0)
	map:addTile("tile-rock-ice-01", 22, 1)
	map:addTile("tile-rock-slope-ice-left-02", 22, 2)
	map:addTile("tile-background-ice-08", 22, 3)
	map:addTile("tile-background-ice-04", 22, 4)
	map:addTile("tile-background-ice-cave-art-02", 22, 5)
	map:addTile("tile-background-ice-06", 22, 6)
	map:addTile("tile-ground-ice-05", 22, 7)
	map:addTile("tile-rock-ice-01", 23, 0)
	map:addTile("tile-rock-ice-01", 23, 1)
	map:addTile("tile-rock-ice-01", 23, 2)
	map:addTile("tile-rock-ice-01", 23, 3)
	map:addTile("tile-rock-ice-01", 23, 4)
	map:addTile("tile-rock-shim-ice-01", 23, 5)
	map:addTile("tile-background-ice-08", 23, 6)
	map:addTile("tile-ground-ice-05", 23, 7)
	map:addTile("tile-rock-ice-01", 24, 0)
	map:addTile("tile-rock-slope-ice-right-02", 24, 1)
	map:addTile("tile-background-ice-01", 24, 2)
	map:addTile("tile-background-ice-cave-art-02", 24, 3)
	map:addTile("tile-background-ice-cave-art-01", 24, 4)
	map:addTile("tile-background-ice-08", 24, 5)
	map:addTile("tile-background-ice-cave-art-02", 24, 6)
	map:addTile("tile-ground-ice-05", 24, 7)
	map:addTile("tile-background-ice-big-01", 25, 0)
	map:addTile("tile-background-ice-03", 25, 2)
	map:addTile("tile-background-ice-03", 25, 3)
	map:addTile("tile-background-ice-06", 25, 4)
	map:addTile("tile-background-ice-cave-art-02", 25, 5)
	map:addTile("tile-background-ice-08", 25, 6)
	map:addTile("tile-ground-ledge-ice-left-01", 25, 7)
	map:addTile("tile-ground-ice-02", 26, 2)
	map:addTile("tile-rock-ice-01", 26, 3)
	map:addTile("tile-rock-ice-02", 26, 4)
	map:addTile("tile-rock-ice-01", 26, 5)
	map:addTile("tile-rock-ice-02", 26, 6)
	map:addTile("tile-rock-ice-02", 26, 7)
	map:addTile("tile-background-ice-04", 27, 0)
	map:addTile("tile-background-ice-08", 27, 1)
	map:addTile("tile-background-ice-05", 27, 2)
	map:addTile("tile-rock-slope-ice-right-01", 27, 3)
	map:addTile("tile-ground-ice-02", 27, 4)
	map:addTile("tile-rock-ice-big-01", 27, 5)
	map:addTile("tile-rock-ice-02", 27, 7)
	map:addTile("tile-background-ice-07", 28, 0)
	map:addTile("tile-background-ice-04", 28, 1)
	map:addTile("tile-background-ice-04", 28, 2)
	map:addTile("tile-background-ice-04", 28, 3)
	map:addTile("tile-rock-ice-02", 28, 4)
	map:addTile("tile-rock-ice-02", 28, 7)
	map:addTile("tile-rock-ice-02", 29, 0)
	map:addTile("tile-rock-shim-ice-01", 29, 1)
	map:addTile("tile-background-ice-08", 29, 2)
	map:addTile("tile-background-ice-04", 29, 3)
	map:addTile("tile-ground-ice-02", 29, 4)
	map:addTile("tile-rock-ice-01", 29, 5)
	map:addTile("tile-rock-ice-01", 29, 6)
	map:addTile("tile-rock-ice-02", 29, 7)
	map:addTile("tile-background-ice-07", 30, 0)
	map:addTile("tile-background-ice-03", 30, 1)
	map:addTile("tile-background-ice-cave-art-02", 30, 2)
	map:addTile("tile-background-ice-04", 30, 3)
	map:addTile("tile-packagetarget-ice-01-idle", 30, 4)
	map:addTile("tile-rock-ice-02", 30, 5)
	map:addTile("tile-rock-ice-big-01", 30, 6)
	map:addTile("tile-background-ice-06", 31, 0)
	map:addTile("tile-background-ice-cave-art-02", 31, 1)
	map:addTile("tile-background-ice-04", 31, 2)
	map:addTile("tile-background-ice-04", 31, 3)
	map:addTile("tile-ground-ice-02", 31, 4)
	map:addTile("tile-rock-ice-01", 31, 5)
	map:addTile("tile-background-ice-01", 32, 0)
	map:addTile("tile-background-ice-01", 32, 1)
	map:addTile("tile-background-ice-04", 32, 2)
	map:addTile("tile-ground-ice-03", 32, 3)
	map:addTile("tile-rock-ice-02", 32, 4)
	map:addTile("tile-rock-ice-02", 32, 5)
	map:addTile("tile-rock-ice-01", 32, 6)
	map:addTile("tile-rock-ice-02", 32, 7)
	map:addTile("tile-rock-shim-ice-01", 33, 0)
	map:addTile("tile-background-ice-06", 33, 1)
	map:addTile("tile-background-ice-01", 33, 2)
	map:addTile("tile-ground-ice-big-01", 33, 3)
	map:addTile("tile-rock-ice-01", 33, 5)
	map:addTile("tile-rock-ice-big-01", 33, 6)
	map:addTile("tile-background-ice-01", 34, 0)
	map:addTile("tile-background-ice-01", 34, 1)
	map:addTile("tile-geyser-ice-01-active", 34, 2)
	map:addTile("tile-rock-ice-02", 34, 5)
	map:addTile("tile-background-ice-07", 35, 0)
	map:addTile("tile-background-ice-01", 35, 1)
	map:addTile("tile-ground-ice-01", 35, 2)
	map:addTile("tile-rock-ice-02", 35, 3)
	map:addTile("tile-rock-ice-02", 35, 4)
	map:addTile("tile-rock-ice-02", 35, 5)
	map:addTile("tile-rock-ice-01", 35, 6)
	map:addTile("tile-rock-ice-02", 35, 7)
	map:addTile("tile-background-ice-04", 36, 0)
	map:addTile("tile-background-ice-07", 36, 1)
	map:addTile("tile-background-ice-03", 36, 2)
	map:addTile("tile-rock-slope-ice-right-01", 36, 3)
	map:addTile("tile-rock-ice-01", 36, 4)
	map:addTile("tile-rock-ice-big-01", 36, 5)
	map:addTile("tile-rock-ice-01", 36, 7)
	map:addTile("tile-rock-shim-ice-01", 37, 0)
	map:addTile("tile-background-ice-02", 37, 1)
	map:addTile("tile-background-ice-04", 37, 2)
	map:addTile("tile-background-ice-01", 37, 3)
	map:addTile("tile-ground-ice-04", 37, 4)
	map:addTile("tile-rock-ice-02", 37, 7)
	map:addTile("tile-background-ice-08", 38, 0)
	map:addTile("tile-background-ice-04", 38, 1)
	map:addTile("tile-background-ice-03", 38, 2)
	map:addTile("tile-background-ice-cave-art-02", 38, 3)
	map:addTile("tile-ground-ice-04", 38, 4)
	map:addTile("tile-rock-ice-02", 38, 5)
	map:addTile("tile-rock-ice-02", 38, 6)
	map:addTile("tile-rock-ice-02", 38, 7)
	map:addTile("tile-rock-slope-ice-left-02", 39, 0)
	map:addTile("tile-background-ice-01", 39, 1)
	map:addTile("tile-background-ice-02", 39, 2)
	map:addTile("tile-background-ice-07", 39, 3)
	map:addTile("tile-rock-slope-ice-right-01", 39, 4)
	map:addTile("tile-rock-ice-03", 39, 5)
	map:addTile("tile-rock-slope-ice-right-02", 39, 6)
	map:addTile("tile-background-ice-03", 39, 7)
	map:addTile("tile-rock-ice-01", 40, 0)
	map:addTile("tile-rock-ice-02", 40, 1)
	map:addTile("tile-background-ice-08", 40, 2)
	map:addTile("tile-background-ice-08", 40, 3)
	map:addTile("tile-background-ice-cave-art-02", 40, 4)
	map:addTile("tile-background-ice-06", 40, 5)
	map:addTile("tile-background-ice-04", 40, 6)
	map:addTile("tile-background-ice-06", 40, 7)
	map:addTile("tile-rock-ice-02", 41, 0)
	map:addTile("tile-rock-ice-01", 41, 1)
	map:addTile("tile-rock-slope-ice-left-02", 41, 2)
	map:addTile("tile-background-ice-07", 41, 3)
	map:addTile("tile-background-ice-07", 41, 4)
	map:addTile("tile-background-ice-05", 41, 5)
	map:addTile("tile-background-ice-05", 41, 6)
	map:addTile("tile-background-ice-cave-art-01", 41, 7)
	map:addTile("tile-background-ice-04", 42, 0)
	map:addTile("tile-background-ice-04", 42, 1)
	map:addTile("tile-ground-ice-06", 42, 2)
	map:addTile("tile-rock-ice-big-01", 42, 3)
	map:addTile("tile-background-ice-big-01", 42, 5)
	map:addTile("tile-background-ice-05", 42, 7)
	map:addTile("tile-background-ice-07", 43, 0)
	map:addTile("tile-background-ice-01", 43, 1)
	map:addTile("tile-ground-ice-06", 43, 2)
	map:addTile("tile-background-ice-04", 43, 7)
	map:addTile("tile-background-ice-04", 44, 0)
	map:addTile("tile-background-ice-05", 44, 1)
	map:addTile("tile-ground-ice-06", 44, 2)
	map:addTile("tile-rock-ice-02", 44, 3)
	map:addTile("tile-rock-ice-02", 44, 4)
	map:addTile("tile-background-ice-03", 44, 5)
	map:addTile("tile-background-ice-08", 44, 6)
	map:addTile("tile-background-ice-cave-art-02", 44, 7)
	map:addTile("tile-background-ice-08", 45, 0)
	map:addTile("tile-background-ice-07", 45, 1)
	map:addTile("tile-background-ice-04", 45, 2)
	map:addTile("tile-background-ice-04", 45, 3)
	map:addTile("tile-background-ice-05", 45, 4)
	map:addTile("tile-background-ice-04", 45, 5)
	map:addTile("tile-background-ice-07", 45, 6)
	map:addTile("tile-background-ice-07", 45, 7)
	map:addTile("tile-background-ice-03", 46, 0)
	map:addTile("tile-background-ice-01", 46, 1)
	map:addTile("tile-background-ice-06", 46, 2)
	map:addTile("tile-background-ice-06", 46, 3)
	map:addTile("tile-background-ice-07", 46, 4)
	map:addTile("tile-background-ice-03", 46, 5)
	map:addTile("tile-background-ice-cave-art-02", 46, 6)
	map:addTile("tile-background-ice-cave-art-02", 46, 7)
	map:addTile("tile-background-ice-big-01", 47, 0)
	map:addTile("tile-background-ice-06", 47, 2)
	map:addTile("tile-background-ice-02", 47, 3)
	map:addTile("tile-ground-ice-04", 47, 4)
	map:addTile("tile-rock-ice-01", 47, 5)
	map:addTile("tile-rock-ice-01", 47, 6)
	map:addTile("tile-rock-ice-02", 47, 7)
	map:addTile("tile-background-ice-04", 48, 2)
	map:addTile("tile-background-ice-01", 48, 3)
	map:addTile("tile-packagetarget-ice-01-idle", 48, 4)
	map:addTile("tile-rock-ice-02", 48, 5)
	map:addTile("tile-rock-ice-03", 48, 6)
	map:addTile("tile-rock-ice-03", 48, 7)
	map:addTile("tile-background-ice-cave-art-02", 49, 0)
	map:addTile("tile-background-ice-01", 49, 1)
	map:addTile("tile-background-ice-04", 49, 2)
	map:addTile("tile-background-ice-04", 49, 3)
	map:addTile("tile-rock-ice-03", 49, 4)
	map:addTile("tile-rock-ice-01", 49, 5)
	map:addTile("tile-rock-ice-03", 49, 6)
	map:addTile("tile-rock-ice-01", 49, 7)
	map:addTile("tile-background-ice-cave-art-01", 50, 0)
	map:addTile("tile-background-ice-04", 50, 1)
	map:addTile("tile-background-ice-04", 50, 2)
	map:addTile("tile-rock-ice-03", 50, 3)
	map:addTile("tile-rock-ice-01", 50, 4)
	map:addTile("tile-rock-ice-03", 50, 5)
	map:addTile("tile-rock-ice-01", 50, 6)
	map:addTile("tile-rock-ice-03", 50, 7)
	map:addTile("tile-background-ice-05", 51, 0)
	map:addTile("tile-background-ice-cave-art-02", 51, 1)
	map:addTile("tile-background-ice-04", 51, 2)
	map:addTile("tile-ground-ice-04", 51, 3)
	map:addTile("tile-rock-ice-02", 51, 4)
	map:addTile("tile-rock-ice-02", 51, 5)
	map:addTile("tile-rock-slope-ice-right-02", 51, 6)
	map:addTile("tile-background-ice-06", 51, 7)
	map:addTile("tile-background-ice-01", 52, 0)
	map:addTile("tile-background-ice-04", 52, 1)
	map:addTile("tile-background-ice-cave-art-01", 52, 2)
	map:addTile("tile-ground-ice-big-01", 52, 3)
	map:addTile("tile-rock-slope-ice-right-02", 52, 5)
	map:addTile("tile-background-ice-02", 52, 6)
	map:addTile("tile-background-ice-04", 52, 7)
	map:addTile("tile-background-ice-big-01", 53, 0)
	map:addTile("tile-background-ice-02", 53, 2)
	map:addTile("tile-background-ice-04", 53, 5)
	map:addTile("tile-background-ice-06", 53, 6)
	map:addTile("tile-background-ice-cave-art-01", 53, 7)
	map:addTile("tile-background-ice-07", 54, 2)
	map:addTile("tile-ground-ice-03", 54, 3)
	map:addTile("tile-rock-ice-02", 54, 4)
	map:addTile("tile-rock-slope-ice-left-02", 54, 5)
	map:addTile("tile-background-ice-cave-art-02", 54, 6)
	map:addTile("tile-background-ice-cave-art-01", 54, 7)
	map:addTile("tile-background-ice-02", 55, 0)
	map:addTile("tile-background-ice-06", 55, 1)
	map:addTile("tile-background-ice-01", 55, 2)
	map:addTile("tile-ground-ice-01", 55, 3)
	map:addTile("tile-rock-ice-02", 55, 4)
	map:addTile("tile-rock-ice-02", 55, 5)
	map:addTile("tile-rock-slope-ice-left-02", 55, 6)
	map:addTile("tile-background-ice-cave-art-02", 55, 7)
	map:addTile("tile-background-ice-02", 56, 0)
	map:addTile("tile-background-ice-07", 56, 1)
	map:addTile("tile-background-ice-08", 56, 2)
	map:addTile("tile-ground-ice-big-01", 56, 3)
	map:addTile("tile-rock-slope-ice-right-02", 56, 5)
	map:addTile("tile-rock-ice-02", 56, 6)
	map:addTile("tile-rock-ice-02", 56, 7)
	map:addTile("tile-background-ice-03", 57, 0)
	map:addTile("tile-background-ice-cave-art-02", 57, 1)
	map:addTile("tile-background-ice-06", 57, 2)
	map:addTile("tile-rock-slope-ice-right-02", 57, 5)
	map:addTile("tile-background-ice-06", 57, 6)
	map:addTile("tile-background-ice-02", 57, 7)
	map:addTile("tile-background-ice-big-01", 58, 0)
	map:addTile("tile-background-ice-07", 58, 2)
	map:addTile("tile-ground-ice-01", 58, 3)
	map:addTile("tile-background-ice-cave-art-01", 58, 4)
	map:addTile("tile-background-ice-cave-art-02", 58, 5)
	map:addTile("tile-background-ice-05", 58, 6)
	map:addTile("tile-background-ice-01", 58, 7)
	map:addTile("tile-background-ice-07", 59, 2)
	map:addTile("tile-ground-ice-03", 59, 3)
	map:addTile("tile-background-ice-04", 59, 4)
	map:addTile("tile-background-ice-06", 59, 5)
	map:addTile("tile-background-ice-08", 59, 6)
	map:addTile("tile-background-ice-03", 59, 7)
	map:addTile("tile-background-ice-02", 60, 0)
	map:addTile("tile-background-ice-07", 60, 1)
	map:addTile("tile-background-ice-07", 60, 2)
	map:addTile("tile-ground-ice-03", 60, 3)
	map:addTile("tile-background-ice-03", 60, 4)
	map:addTile("tile-background-ice-cave-art-01", 60, 5)
	map:addTile("tile-background-ice-06", 60, 6)
	map:addTile("tile-background-ice-04", 60, 7)
	map:addTile("tile-background-ice-05", 61, 0)
	map:addTile("tile-background-ice-cave-art-02", 61, 1)
	map:addTile("tile-background-ice-04", 61, 2)
	map:addTile("tile-ground-ice-big-01", 61, 3)
	map:addTile("tile-rock-ice-02", 61, 5)
	map:addTile("tile-rock-shim-ice-01", 61, 6)
	map:addTile("tile-background-ice-03", 61, 7)
	map:addTile("tile-background-ice-08", 62, 0)
	map:addTile("tile-background-ice-07", 62, 1)
	map:addTile("tile-background-ice-01", 62, 2)
	map:addTile("tile-background-ice-05", 62, 5)
	map:addTile("tile-background-ice-07", 62, 6)
	map:addTile("tile-background-ice-06", 62, 7)

	map:addEmitter("item-package-ice", 6, 2, 1, 0, "")
	map:addEmitter("tree", 10, 4, 1, 0, "")
	map:addEmitter("tree", 17, 3, 1, 0, "")
	map:addEmitter("item-package-ice", 17, 4, 1, 0, "")
	map:addEmitter("tree", 32, 1, 1, 0, "")
	map:addEmitter("item-package-ice", 35.5, 1, 1, 0, "")
	map:addEmitter("tree", 43, 0, 1, 0, "")
	map:addEmitter("item-apple", 47, 3, 1, 0, "")
	map:addEmitter("npc-walking", 51, 2, 1, 0, "")
	map:addEmitter("tree", 52, 1, 1, 0, "")

	map:setSetting("width", "63")
	map:setSetting("height", "8")
	map:setSetting("fishnpc", "false")
	map:setSetting("flyingnpc", "false")
	map:setSetting("gravity", "9.81")
	map:setSetting("packagetransfercount", "3")
	map:addStartPosition("1", "4")
	map:setSetting("points", "100")
	map:setSetting("referencetime", "45")
	map:setSetting("sideborderfail", "true")
	map:setSetting("theme", "ice")
	map:setSetting("waterchangespeed", "0.2")
	map:setSetting("waterfallingdelay", "2000")
	map:setSetting("waterheight", "1")
	map:setSetting("waterrisingdelay", "0")
	map:setSetting("wind", "4.0")
end
