lddrr3dldurrdl4ulld5ld3l3dlddru10r5urullr6d6luul3u5ruudrr6d3r5ullrr5d6luurruruurullr3dldlldd3luuluulluur3urrd4rurrd4ldlulull3dlddrru5ruudd5ldlluur3urrd4rurrd4luld3rddrr3dldllddrrur4urullr6d3luurrdd5luul3u5ruudd5ldlluur3urrd4rurrd4lulldrurdrrddrr3dlddr4urullr6d6luul3u5ruudd5ldlluur3urrd4rurrd5lruld3r3d5ldlud3luuldld4rurr3dlddll3u3d7r4ulu5ldr3lulld4rl4drruldl3uddrru3ruruu5ldllulld3r4d7r3ud3r4ulld6l4rddrudd3r4ulld5l3rddldlluu
