#include "CaveExpressSpriteType.h"

namespace caveexpress {

namespace SpriteTypes {
SpriteType WATERFALL("waterfall");
SpriteType ROCK("rock");
SpriteType CAVE("cave");
SpriteType BRIDGE_LEFT("bridge-left");
SpriteType BRIDGE_RIGHT("bridge-right");
SpriteType BRIDGE_PLANK("bridge-plank");
SpriteType GROUND("ground");
SpriteType GROUND_LEFT("ground-left");
SpriteType GROUND_RIGHT("ground-right");
SpriteType SLOPE_LEFT("slope-left");
SpriteType SLOPE_RIGHT("slope-right");
SpriteType WINDOW("window");
SpriteType LAVA("lava");
SpriteType BACKGROUND("background");
SpriteType CAVE_SIGN("cave-sign");
SpriteType LIANE("liane");
SpriteType GEYSER_ICE("geyser-ice");
SpriteType GEYSER_ROCK("geyser-rock");
SpriteType PACKAGETARGET_ICE("packagetarget-ice");
SpriteType PACKAGETARGET_ROCK("packagetarget-rock");
}

}
