r3drruuruurrdrdduululuulddllurr6lddrulu4rdrddrdrrdrlulld3l3uludr3d3ruuluurdurrdldulullullddr3d3ruuldurruuluurdldllurr4ldlldrdrurdu3luu4rdrddrrul3d3ldllu4rdr3ururullu4ldlddrrdulluuru4rdrddldd3ldllurruulluuru4rurddlduu4ldllu6r5l3druulu3rdr
