ddlluu4ldd8r4luu6ldd9r3luu8ldd10r10l4uruul5dld9rdrruldlu8l6uluur7dld8r7l4u3ruulldluluur7dld5r4l4u5ruu4ldluluur7dld3ruu6ruuluu6ldluluur7dldruu8ruurruu9ldl3d7rddr3u4drruldl3u4ldd4rd3rulurldldluluu5ldd7rlluu7ldd7r7l6uluur7dld5r4l6u3lu3(ul)l3(dr)luluu3(rd)ululldrdrd3rur6dld3rll6u4luluurdrdulldrd3rur6durrddlluu4rddlluu5rdd4l5rd3ruuld6l7rddrruu8lrruurdldrdrru4lruu7l4u4luurdld3rur6d5u7rddr3dldrdrru3lr4uluur5dldrdrrull6ruuldrd4l3ruuldrdllrrddllu3l7urrddlruull5d
