drr2(ddll)uru5r7u5lu3ldlruuldl3d3lddrdrrdrr5drrudll5ullulluluu5rddluru3ldrrl4urrdlu4rddlur3dluuru5r7d5lul3ur4u3luldl3drddrrlululldr4urrdlul3d3u5rddluru3luldrdluldduu5r4dl3u6r7d5luluuddrd3ruullulrdrrulruulddr3drr7u5l4drrll5uld6r7drr7u6l4r7d5l2(ddrru)ldlulluu4rld4uluur5d3lululu4rlluuld4ur3duu7r7dldl7u6drr7u6l4r7d5l2(ddrru)ldlulluu4rld4uluur5d3l3(ul)lulrd3r5urddu7r7dldl7u6drr7u6l4r7d5luluu3rur3duu4lddrd4r4l2(ddrru)ldlull3uluu4r4d4u4lddr3drrdrruluulldll3ulu4rur3duu4l4drddl4urdduululur5urd7r7dldlu4ldlluurdl3u3rur3duu4l5ulldllu4rd8r7d6lrr3ulldrurdduu4l4u8r7d5lr3u4l7dll5ullulluluurlddrdrrdrr4drdr6ulu4rur3duu4l4u8r7d4lrr6u6drr7u6l
