u4rd7rdlduu6l3d4rururulr2(rddl)3ulu4lu5lddrrdd6rururrullrr3dluudlld6luulluu4r3d3u4l2(ddrr)4u3l7urdrll6d3r4ululul5d4urrdr8d2(lluu)rlddrrdd4ru3ruu4lul4ululuurdurrdlluldl6d3rdd6ululul5d6u3rdllrddr5d5rdd3ld4luulluu3rll5uruul6d4urrdr5d5rdd3ld4luulluu3r3lddrrdd4ru3ruu5l3ul3uluurrdllul6d4urr3dr3d5rdrru5l5r3dluuru4lrrdd3ld4luulluu3rll5urr3drdduuluur3dul3ull5dlddrrdd4rurrd3l
