d4lu12lrrddlldd3uddlluur4u4dld3ldlu4rur3u3l3duu3rddld3lrrd3rurru2(ulldd)rrurddrddlluruuldullull3u3rdr3dlluururddullddrrurdduuruu10rd3ruudd3luurrdullddrrllulluruu3rddllrruu3lddrd12ldlldll3u3rdr3dlluururddullddrr3u11r3urrdrdllruullddrd12ldlldll3u3rdr3dlluururdu12rdrrurruulluld3rddllullruullddrd12ldl3ul3urrdlul3drdllul3d3u3ruluurrdlul3drdllulddu3rd11ru4rdrru4lruullddrd12ldl4uluurrdlul3drdlrd12r3u3rdrd3lruullddrd12ldl4u3d11ru6rdd3ldluudr2(ruull)ddrd12ldl3u3dlddrrurruu8rdruu3rddldluudr2(ruull)ddrd10lddlldlluuru9r6lddllulu8r7l4drul3urrddldluulu7r7luu3lddlddrrd3ruulldldrrluurrdrddl3ulu6r6luu3l3dldrrd3ruulldldrrluurrdrddl3ulu5r4ldlld3ldllu4rd3ruulldldrrluurrdrddl3ulu4r3ldlld5lurrurdldrrd3ruulldldrrluurrdrddl3ulu3r3luu3ldrrurddr3dlluurlddrruulurrllul4urrdlul3dldrurddr3dlluurlddrruulurlul3ur4dr3dlluurlddrruu3d3rddll3ulurddrrdldl3u3dl3u
