textures = {
	["npc-fish-swimming-DIR-front-01"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.85546875,
		y0 = 0.5390625,
		x1 = 0.138671875,
		y1 = 0.12890625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 71,
		trimmedheight = 66,
		untrimmedwidth = 71,
		untrimmedheight = 66,
	},
	["npc-fish-swimming-DIR-front-02"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.576171875,
		y0 = 0.537109375,
		x1 = 0.140625,
		y1 = 0.12890625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 72,
		trimmedheight = 66,
		untrimmedwidth = 72,
		untrimmedheight = 66,
	},
	["npc-fish-swimming-DIR-front-03"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.435546875,
		y0 = 0.53515625,
		x1 = 0.140625,
		y1 = 0.12890625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 72,
		trimmedheight = 66,
		untrimmedwidth = 72,
		untrimmedheight = 66,
	},
	["npc-fish-swimming-DIR-front-04"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.291015625,
		y0 = 0.40625,
		x1 = 0.14453125,
		y1 = 0.130859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 74,
		trimmedheight = 67,
		untrimmedwidth = 74,
		untrimmedheight = 67,
	},
	["npc-fish-swimming-DIR-front-05"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0,
		y0 = 0.404296875,
		x1 = 0.146484375,
		y1 = 0.130859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 75,
		trimmedheight = 67,
		untrimmedwidth = 75,
		untrimmedheight = 67,
	},
	["npc-fish-swimming-DIR-front-06"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0,
		y0 = 0.2734375,
		x1 = 0.150390625,
		y1 = 0.130859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 77,
		trimmedheight = 67,
		untrimmedwidth = 77,
		untrimmedheight = 67,
	},
	["npc-fish-swimming-DIR-front-07"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.62890625,
		y0 = 0.404296875,
		x1 = 0.154296875,
		y1 = 0.1328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 79,
		trimmedheight = 68,
		untrimmedwidth = 79,
		untrimmedheight = 68,
	},
	["npc-fish-swimming-DIR-front-08"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.63671875,
		y0 = 0.271484375,
		x1 = 0.15625,
		y1 = 0.1328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 80,
		trimmedheight = 68,
		untrimmedwidth = 80,
		untrimmedheight = 68,
	},
	["npc-fish-swimming-DIR-front-09"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.31640625,
		y0 = 0.271484375,
		x1 = 0.158203125,
		y1 = 0.134765625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 81,
		trimmedheight = 69,
		untrimmedwidth = 81,
		untrimmedheight = 69,
	},
	["npc-fish-swimming-DIR-front-10"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.478515625,
		y0 = 0.138671875,
		x1 = 0.158203125,
		y1 = 0.134765625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 81,
		trimmedheight = 69,
		untrimmedwidth = 81,
		untrimmedheight = 69,
	},
	["npc-fish-swimming-DIR-front-11"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.16015625,
		y0 = 0,
		x1 = 0.16015625,
		y1 = 0.13671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 82,
		trimmedheight = 70,
		untrimmedwidth = 82,
		untrimmedheight = 70,
	},
	["npc-fish-swimming-DIR-front-12"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0,
		y0 = 0,
		x1 = 0.16015625,
		y1 = 0.13671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 82,
		trimmedheight = 70,
		untrimmedwidth = 82,
		untrimmedheight = 70,
	},
	["npc-fish-swimming-DIR-front-13"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.796875,
		y0 = 0,
		x1 = 0.158203125,
		y1 = 0.13671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 81,
		trimmedheight = 70,
		untrimmedwidth = 81,
		untrimmedheight = 70,
	},
	["npc-fish-swimming-DIR-front-14"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.638671875,
		y0 = 0,
		x1 = 0.158203125,
		y1 = 0.13671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 81,
		trimmedheight = 70,
		untrimmedwidth = 81,
		untrimmedheight = 70,
	},
	["npc-fish-swimming-DIR-front-15"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.48046875,
		y0 = 0,
		x1 = 0.158203125,
		y1 = 0.138671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 81,
		trimmedheight = 71,
		untrimmedwidth = 81,
		untrimmedheight = 71,
	},
	["npc-fish-swimming-DIR-front-16"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.796875,
		y0 = 0.26953125,
		x1 = 0.15625,
		y1 = 0.138671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 80,
		trimmedheight = 71,
		untrimmedwidth = 80,
		untrimmedheight = 71,
	},
	["npc-fish-swimming-DIR-front-17"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.158203125,
		y0 = 0.13671875,
		x1 = 0.158203125,
		y1 = 0.13671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 81,
		trimmedheight = 70,
		untrimmedwidth = 81,
		untrimmedheight = 70,
	},
	["npc-fish-swimming-DIR-front-18"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0,
		y0 = 0.13671875,
		x1 = 0.158203125,
		y1 = 0.13671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 81,
		trimmedheight = 70,
		untrimmedwidth = 81,
		untrimmedheight = 70,
	},
	["npc-fish-swimming-DIR-front-19"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.3203125,
		y0 = 0.134765625,
		x1 = 0.158203125,
		y1 = 0.13671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 81,
		trimmedheight = 70,
		untrimmedwidth = 81,
		untrimmedheight = 70,
	},
	["npc-fish-swimming-DIR-front-20"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.3203125,
		y0 = 0,
		x1 = 0.16015625,
		y1 = 0.134765625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 82,
		trimmedheight = 69,
		untrimmedwidth = 82,
		untrimmedheight = 69,
	},
	["npc-fish-swimming-DIR-front-21"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.638671875,
		y0 = 0.13671875,
		x1 = 0.158203125,
		y1 = 0.134765625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 81,
		trimmedheight = 69,
		untrimmedwidth = 81,
		untrimmedheight = 69,
	},
	["npc-fish-swimming-DIR-front-22"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.796875,
		y0 = 0.13671875,
		x1 = 0.158203125,
		y1 = 0.1328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 81,
		trimmedheight = 68,
		untrimmedwidth = 81,
		untrimmedheight = 68,
	},
	["npc-fish-swimming-DIR-front-23"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.474609375,
		y0 = 0.2734375,
		x1 = 0.154296875,
		y1 = 0.1328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 79,
		trimmedheight = 68,
		untrimmedwidth = 79,
		untrimmedheight = 68,
	},
	["npc-fish-swimming-DIR-front-24"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.783203125,
		y0 = 0.408203125,
		x1 = 0.150390625,
		y1 = 0.130859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 77,
		trimmedheight = 67,
		untrimmedwidth = 77,
		untrimmedheight = 67,
	},
	["npc-fish-swimming-DIR-front-25"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.150390625,
		y0 = 0.2734375,
		x1 = 0.146484375,
		y1 = 0.130859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 75,
		trimmedheight = 67,
		untrimmedwidth = 75,
		untrimmedheight = 67,
	},
	["npc-fish-swimming-DIR-front-26"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.146484375,
		y0 = 0.404296875,
		x1 = 0.14453125,
		y1 = 0.130859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 74,
		trimmedheight = 67,
		untrimmedwidth = 74,
		untrimmedheight = 67,
	},
	["npc-fish-swimming-DIR-front-27"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.435546875,
		y0 = 0.40625,
		x1 = 0.140625,
		y1 = 0.12890625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 72,
		trimmedheight = 66,
		untrimmedwidth = 72,
		untrimmedheight = 66,
	},
	["npc-fish-swimming-DIR-front-28"] = {
		image = "caveexpress-npc_fish-small",
		x0 = 0.716796875,
		y0 = 0.5390625,
		x1 = 0.138671875,
		y1 = 0.12890625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 71,
		trimmedheight = 66,
		untrimmedwidth = 71,
		untrimmedheight = 66,
	},
}
