textures = {
	["npc-mammut-attack-DIR-middle-01"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.626953125,
		y0 = 0.6201171875,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-attack-DIR-middle-02"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.41796875,
		y0 = 0.6201171875,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-attack-DIR-middle-03"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.208984375,
		y0 = 0.6201171875,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-attack-DIR-middle-04"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0,
		y0 = 0.93017578125,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-attack-DIR-middle-05"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0,
		y0 = 0.8681640625,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-attack-init-DIR-middle-01"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0,
		y0 = 0.80615234375,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-attack-init-DIR-middle-02"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0,
		y0 = 0.744140625,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-attack-init-DIR-middle-03"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0,
		y0 = 0.68212890625,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-attack-init-DIR-middle-04"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0,
		y0 = 0.6201171875,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-attack-init-DIR-middle-05"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.626953125,
		y0 = 0.55810546875,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-attack-init-DIR-middle-06"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.41796875,
		y0 = 0.55810546875,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-dazed-DIR-middle-01"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.208984375,
		y0 = 0.55810546875,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-dazed-DIR-middle-02"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0,
		y0 = 0.55810546875,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-dazed-DIR-middle-03"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.626953125,
		y0 = 0.49609375,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-dazed-DIR-middle-04"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.41796875,
		y0 = 0.49609375,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-dazed-DIR-middle-05"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.208984375,
		y0 = 0.49609375,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-dazed-DIR-middle-06"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0,
		y0 = 0.49609375,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-dazed-DIR-middle-07"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.626953125,
		y0 = 0.43408203125,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-dazed-DIR-middle-08"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.41796875,
		y0 = 0.43408203125,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-idle-DIR-middle-01"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.208984375,
		y0 = 0.43408203125,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-idle-DIR-middle-02"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0,
		y0 = 0.43408203125,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-idle-DIR-middle-03"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.626953125,
		y0 = 0.3720703125,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-idle-DIR-middle-04"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.41796875,
		y0 = 0.3720703125,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-idle-DIR-middle-05"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.208984375,
		y0 = 0.3720703125,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-idle-DIR-middle-06"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0,
		y0 = 0.3720703125,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-idle-DIR-middle-07"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.626953125,
		y0 = 0.31005859375,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-idle-DIR-middle-08"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.41796875,
		y0 = 0.31005859375,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-idle-DIR-middle-09"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.208984375,
		y0 = 0.31005859375,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-idle-DIR-middle-10"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0,
		y0 = 0.31005859375,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-idle-DIR-middle-11"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.626953125,
		y0 = 0.248046875,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-idle-DIR-middle-12"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.208984375,
		y0 = 0.43408203125,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-knockout-DIR-middle-01"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.208984375,
		y0 = 0.43408203125,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-knockout-DIR-middle-02"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.41796875,
		y0 = 0.248046875,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-knockout-DIR-middle-03"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.208984375,
		y0 = 0.248046875,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-turn-DIR-middle-01"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0,
		y0 = 0.248046875,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-turn-DIR-middle-02"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.626953125,
		y0 = 0.18603515625,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-turn-DIR-middle-03"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.41796875,
		y0 = 0.18603515625,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-turn-DIR-middle-04"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.208984375,
		y0 = 0.18603515625,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-turn-DIR-middle-05"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0,
		y0 = 0.18603515625,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-turn-DIR-middle-06"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.626953125,
		y0 = 0.1240234375,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-turn-DIR-middle-07"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.41796875,
		y0 = 0.1240234375,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-wakeup-DIR-middle-01"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.208984375,
		y0 = 0.1240234375,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-wakeup-DIR-middle-02"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.208984375,
		y0 = 0.55810546875,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-wakeup-DIR-middle-03"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0,
		y0 = 0.1240234375,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-wakeup-DIR-middle-04"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.626953125,
		y0 = 0.06201171875,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-wakeup-DIR-middle-05"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.41796875,
		y0 = 0.06201171875,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-wakeup-DIR-middle-06"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.208984375,
		y0 = 0.06201171875,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-wakeup-DIR-middle-07"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.208984375,
		y0 = 0.43408203125,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-walk-DIR-middle-01"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0,
		y0 = 0.06201171875,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-walk-DIR-middle-02"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.626953125,
		y0 = 0,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-walk-DIR-middle-03"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.41796875,
		y0 = 0,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-walk-DIR-middle-04"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0.208984375,
		y0 = 0,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
	["npc-mammut-walk-DIR-middle-05"] = {
		image = "caveexpress-npc_mammut-big",
		x0 = 0,
		y0 = 0,
		x1 = 0.208984375,
		y1 = 0.06201171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 127,
		untrimmedwidth = 214,
		untrimmedheight = 127,
	},
}
