#pragma once

namespace caveexpress {

namespace NPCState {
enum {
	NPC_IDLE,
	NPC_FALLING,
	NPC_SWIMMING,
	NPC_DYING,
	NPC_MOVING,
	NPC_FLYING,
	NPC_DAZED,
	NPC_DONE,
	NPC_COLLECTED,
	NPC_ATTACKING,
	NPC_ARRIVED,
	NPC_STRUGGLE
};
}

}
