6uluur5drddllull6u4ldr5dldd4rudllu9r5lu6rdru6l6urrdrrurdrdd5l5ruu6l4drdd4ld4lu10r4lu5rd10l4urr3d7r3l5urrdlul5dld6rurd9ldllu10rlu4l5u6rdd5lul4dld5r4l6u5rdrd5lul4d4l4ur3dld9r8l3u3lurrur4dld8r7l3u3luurrur5dld7r4ld4r
