3ulu3rurrd3lrr3drrddll4u5d5luuluuluurd3r3drrll3uluurdrrurrdl3drrddlluu3d5luu4rll3uluur4dldlluulu3rll3drdd5rurruulld4lr3uluurdrrurrd4l3dldr3u3l3drdd5rurruulluuddrrddlld5luul3u3r3dlr3u3lddrdrr5uldr4d3l3urru3rurrdl3drrddllu4lr3uluur4dldr3u3lddrldrl3urru3rurrd3lrr3drrddll4u5d5luul3urruur4d3urrurrd3lrr6d5luul3urruur3d
