ull5d5rdd3l3ruu7l4u4l3d3r3lddrrd3r3d4ruudd4luurr4ud4rdd3lr4drrdrr6u6dlluuldl3udd4luurr3uruu3lrdrrd3rdd3lr3drruldluudd4luurr4ud4rdd3lrddrudd5luurr3urullurrdd3rdd3lr3d4luurruu2(ddll)urd5r3urruu6lrr3dlldld4r3luurru3r4dl3urullr3d4luurruudrr5d4lud4r5urruu5lr3dlldld4r3ldd4r4urullr3d4luurr4u4dlluldduullulldldd4rd5r3ldd4r4urullr3d4luurr3u3d3ld5luurdld4rd5r3ldd4r4urullr3d4luurruud4ruu4lruulldrurdl4d3lduulldrdd5r3ldd4r4urullr3d4luurr4u4dllulddld5r3ldd4r4urullr3d4luurr3u3d5luull5u4rdrrdrldrl4urrdlul3d3u4rd3lulddllulldlul7d3rurddu3ldrrd5r3ldd4r4urullr3d4luurr4u4d3ldu5ld4rd5r3ldd4r4urullr3d4luurr3u3d3ldld5r3ldd4r4urullr3d4luurruud4ruuruurrdd4l
