textures = {
	["ui-npc-grandpa-middle-01"] = {
		image = "caveexpress-ui-player-grandpa-big",
		x0 = 0.8076171875,
		y0 = 0.162109375,
		x1 = 0.177734375,
		y1 = 0.15625,
		trimmedoffsetx = 47,
		trimmedoffsety = 7,
		trimmedwidth = 182,
		trimmedheight = 320,
		untrimmedwidth = 230,
		untrimmedheight = 328,
	},
	["ui-npc-grandpa-middle-02"] = {
		image = "caveexpress-ui-player-grandpa-big",
		x0 = 0.7841796875,
		y0 = 0.318359375,
		x1 = 0.2021484375,
		y1 = 0.15771484375,
		trimmedoffsetx = 39,
		trimmedoffsety = 6,
		trimmedwidth = 207,
		trimmedheight = 323,
		untrimmedwidth = 247,
		untrimmedheight = 331,
	},
	["ui-npc-grandpa-middle-03"] = {
		image = "caveexpress-ui-player-grandpa-big",
		x0 = 0.4541015625,
		y0 = 0.353515625,
		x1 = 0.21875,
		y1 = 0.154296875,
		trimmedoffsetx = 7,
		trimmedoffsety = 12,
		trimmedwidth = 224,
		trimmedheight = 316,
		untrimmedwidth = 232,
		untrimmedheight = 330,
	},
	["ui-npc-grandpa-middle-04"] = {
		image = "caveexpress-ui-player-grandpa-big",
		x0 = 0.279296875,
		y0 = 0.22021484375,
		x1 = 0.1748046875,
		y1 = 0.16357421875,
		trimmedoffsetx = 51,
		trimmedoffsety = 4,
		trimmedwidth = 179,
		trimmedheight = 335,
		untrimmedwidth = 231,
		untrimmedheight = 339,
	},
	["ui-npc-grandpa-middle-05"] = {
		image = "caveexpress-ui-player-grandpa-big",
		x0 = 0.279296875,
		y0 = 0.3837890625,
		x1 = 0.173828125,
		y1 = 0.16455078125,
		trimmedoffsetx = 47,
		trimmedoffsety = 2,
		trimmedwidth = 178,
		trimmedheight = 337,
		untrimmedwidth = 226,
		untrimmedheight = 339,
	},
	["ui-npc-grandpa-middle-06"] = {
		image = "caveexpress-ui-player-grandpa-big",
		x0 = 0,
		y0 = 0.39697265625,
		x1 = 0.216796875,
		y1 = 0.158203125,
		trimmedoffsetx = 32,
		trimmedoffsety = 9,
		trimmedwidth = 222,
		trimmedheight = 324,
		untrimmedwidth = 256,
		untrimmedheight = 336,
	},
	["ui-npc-grandpa-middle-07"] = {
		image = "caveexpress-ui-player-grandpa-big",
		x0 = 0.8076171875,
		y0 = 0,
		x1 = 0.1875,
		y1 = 0.162109375,
		trimmedoffsetx = 37,
		trimmedoffsety = 5,
		trimmedwidth = 192,
		trimmedheight = 332,
		untrimmedwidth = 230,
		untrimmedheight = 338,
	},
	["ui-player-middle-01"] = {
		image = "caveexpress-ui-player-grandpa-big",
		x0 = 0.4755859375,
		y0 = 0.1767578125,
		x1 = 0.30859375,
		y1 = 0.1767578125,
		trimmedoffsetx = 0,
		trimmedoffsety = 1,
		trimmedwidth = 316,
		trimmedheight = 362,
		untrimmedwidth = 340,
		untrimmedheight = 370,
	},
	["ui-player-middle-02"] = {
		image = "caveexpress-ui-player-grandpa-big",
		x0 = 0,
		y0 = 0.22021484375,
		x1 = 0.279296875,
		y1 = 0.1767578125,
		trimmedoffsetx = 11,
		trimmedoffsety = 0,
		trimmedwidth = 286,
		trimmedheight = 362,
		untrimmedwidth = 340,
		untrimmedheight = 370,
	},
	["ui-player-middle-03"] = {
		image = "caveexpress-ui-player-grandpa-big",
		x0 = 0.4755859375,
		y0 = 0,
		x1 = 0.33203125,
		y1 = 0.1767578125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 340,
		trimmedheight = 362,
		untrimmedwidth = 340,
		untrimmedheight = 370,
	},
	["ui-scene-player"] = {
		image = "caveexpress-ui-player-grandpa-big",
		x0 = 0,
		y0 = 0,
		x1 = 0.4755859375,
		y1 = 0.22021484375,
		trimmedoffsetx = 2,
		trimmedoffsety = 1,
		trimmedwidth = 487,
		trimmedheight = 451,
		untrimmedwidth = 493,
		untrimmedheight = 453,
	},
}
