uu6ldlru6r3d12l6u3r3drddurrurrd3lru6r3d11ldl6ulu3rurrdl3drddurru4rd5lru6r3d11ldlu4ruuluur3durru6rd7l7rdd11ldllu9r4luudd4l5uluur6d5urrurrdl4drdd3ldllu7r6l6urrur3dr3d3uluu3l6d4ruul3udr4d4l6urrurrd3lrrddr4d4l5uluur6d5u3rddr4d3ldllu3r
