3dldll3urd3lurdd4luurrdullddrrurrulld4rullr3drruruulld4ldrrurrurrddldlludrruruulldllrddrrurrdllr3ulldllu3rur3duu3ldd3luurrdd4luurrdd3rdd4lud4r3ururrddldlruruulldld3luullddrrldd4ruululrdrdrrurrdllr3ulldllu3rur3duu3l4d4luuluu4rdrrurrddldlruruulldllu4lddrdd4rurrurrdllr3ulldllu3rur3duu8lddrdd4ruuluru3rddldlruruu8lddrdd4ruudrrurrd3lrr3u4lddrulu3rurddu8lddrdd4r3ulu3rurd8ldd3rlldd4ru4ruld3l3u3rddrdll
