d3rdd4lrr4d6rulu4l4rdd5l3u3d8rulu6l4rdd5rulu5lrdd7rulu3l4u4rdduu4lddll7ud4r3d3u4ldd3r3luu4rdduull4u4ldd3r3luu4r3dull4dll3ud6lrruu7r3luu4rddll4d4ruullrrdd4l4drr3u3dlluu3lr4drddl5u3dll7u3d3rlddrr4urrll3u3dll4u4ldd3r3luu4rdduurr4drr6dldlldl5udrruu3lrdd4rddrd4ldl5u3dll7u3dll4ur2(rdd4rdd3l)dl4u3dll6udd3rlddrr6u6d3rdrd5ldl4u3dll4u3rlddrr3u3drrdd3rd6ld5luudd4r5u3dll4u3rl5d9ru8ldl4u3dll4urrdd4r4u4lrrdduurr6d4ru3ldl4u3d3ru6l3rdd4luu4rd5ruluull2(rrdd6l)4u4ldd3r3luu4rdduulluu6lrr4d4rlldd7l3ruurr8urruu6ldrd4r4luu3ldrd5r3luu8l3druluu3rdrdr4d4luudd4ruurr7du4l3u3d4ruu3l3rdd4luu6r6d4l3u3d4ruu3l3rdd4luurr4u4lddrrlluu4r4ull3d3u4rddlruull4dllrr3d3urr4dll6urr4uluur5dulldd3rl4urr7d3urr4d3l3rdd4luurr4ull6u3ldrrur5dulldd3rl4urr7d3urr4dlluu6l6u3rur4dulldd3rl4urr6d6u7lu4rur5d3urr4d3lruull3d3ull4drrll8u4ld7rur5d3urr4d3lruull4drrlldduull7u3ld6rur4d3urr4d3lruu4l4d2(rruu)5lulu5rur4d3urr4d4ruu3l3rdd4luuddll6u4r3d3u4l6d6ruull4u4ldd3r3lu9ldrd3rur4d3u3ld6r3lu5ldrddrrlluu6r6luu10rlldd4u4rdd
