rdd3rurld3l3ur4ldrl4u4rdduu4r4drddl5u4dlld2(3l3u)rrdrdd3u4rurrdl5dll3ullrrddlu4ldlu6r3d3luulurrl3d3rurr5u4lddullu5rur5drddlulld4lur3u4d3r4ulluulldr4dldr3uldr4urrdu3r4drddlull3ullruu3r4drdl5u3lddrddlu
