function getName()
	return "Map 06"
end

function onMapLoaded()
end

function initMap()
	-- get the current map context
	local map = Map.get()
	map:addTile("tile-rock-ice-big-01", 0, 0)
	map:addTile("tile-rock-ice-02", 0, 2)
	map:addTile("tile-ground-ledge-ice-right-02", 0, 3)
	map:addTile("tile-background-ice-03", 0, 4)
	map:addTile("tile-background-ice-01", 0, 5)
	map:addTile("tile-background-ice-08", 0, 6)
	map:addTile("tile-background-ice-08", 0, 7)
	map:addTile("tile-background-ice-06", 0, 8)
	map:addTile("tile-ground-ledge-ice-right-01", 0, 9)
	map:addTile("tile-background-ice-08", 0, 10)
	map:addTile("tile-background-ice-02", 0, 11)
	map:addTile("tile-rock-slope-ice-right-02", 1, 2)
	map:addTile("tile-background-ice-01", 1, 3)
	map:addTile("tile-background-ice-cave-art-01", 1, 4)
	map:addTile("tile-background-ice-01", 1, 5)
	map:addTile("tile-background-ice-08", 1, 6)
	map:addTile("tile-background-ice-05", 1, 7)
	map:addTile("tile-background-ice-02", 1, 8)
	map:addTile("tile-background-ice-04", 1, 9)
	map:addTile("bridge-wall-ice-left-01", 1, 9)
	map:addTile("tile-background-ice-03", 1, 10)
	map:addTile("tile-background-ice-08", 1, 11)
	map:addTile("tile-rock-ice-02", 2, 0)
	map:addTile("tile-rock-ice-01", 2, 1)
	map:addTile("tile-background-ice-02", 2, 2)
	map:addTile("tile-background-ice-01", 2, 3)
	map:addTile("tile-background-ice-03", 2, 4)
	map:addTile("tile-background-ice-cave-art-02", 2, 5)
	map:addTile("tile-background-ice-07", 2, 6)
	map:addTile("tile-background-ice-big-01", 2, 7)
	map:addTile("tile-background-ice-big-01", 2, 9)
	map:addTile("bridge-plank-ice-01", 2, 9)
	map:addTile("tile-background-ice-cave-art-02", 2, 11)
	map:addTile("tile-rock-ice-big-01", 3, 0)
	map:addTile("tile-background-ice-01", 3, 2)
	map:addTile("tile-background-ice-03", 3, 3)
	map:addTile("tile-background-ice-01", 3, 4)
	map:addTile("tile-ground-ice-big-01", 3, 5)
	map:addTile("bridge-plank-ice-01", 3, 9)
	map:addTile("tile-rock-ice-02", 3, 11)
	map:addTile("tile-background-ice-05", 4, 2)
	map:addTile("tile-background-ice-04", 4, 3)
	map:addTile("tile-background-ice-01", 4, 4)
	map:addTile("tile-background-ice-06", 4, 7)
	map:addTile("tile-background-ice-06", 4, 8)
	map:addTile("tile-background-ice-04", 4, 9)
	map:addTile("bridge-wall-ice-right-01", 4, 9)
	map:addTile("tile-background-ice-02", 4, 10)
	map:addTile("tile-rock-ice-02", 4, 11)
	map:addTile("tile-rock-ice-01", 5, 0)
	map:addTile("tile-rock-slope-ice-right-02", 5, 1)
	map:addTile("tile-background-ice-cave-art-01", 5, 2)
	map:addTile("tile-background-ice-big-01", 5, 3)
	map:addTile("tile-background-ice-06", 5, 5)
	map:addTile("tile-ground-ledge-ice-right-01", 5, 6)
	map:addTile("tile-background-ice-big-01", 5, 7)
	map:addTile("tile-ground-ice-01", 5, 9)
	map:addTile("tile-rock-ice-01", 5, 10)
	map:addTile("tile-rock-ice-03", 5, 11)
	map:addTile("tile-ground-ledge-ice-right-02", 6, 0)
	map:addTile("tile-background-ice-06", 6, 1)
	map:addTile("tile-background-ice-cave-art-01", 6, 2)
	map:addTile("tile-rock-slope-ice-left-01", 6, 5)
	map:addTile("tile-ground-ledge-ice-right-02", 6, 6)
	map:addTile("tile-ground-ice-01", 6, 9)
	map:addTile("tile-rock-ice-big-01", 6, 10)
	map:addTile("tile-background-ice-04", 7, 0)
	map:addTile("tile-background-ice-01", 7, 1)
	map:addTile("tile-background-ice-02", 7, 2)
	map:addTile("tile-background-ice-04", 7, 3)
	map:addTile("tile-rock-slope-ice-left-01", 7, 4)
	map:addTile("tile-rock-slope-ice-right-02", 7, 5)
	map:addTile("tile-background-ice-03", 7, 6)
	map:addTile("tile-background-ice-03", 7, 7)
	map:addTile("tile-background-ice-01", 7, 8)
	map:addTile("tile-ground-ice-06", 7, 9)
	map:addTile("tile-background-ice-04", 8, 0)
	map:addTile("tile-background-ice-08", 8, 1)
	map:addTile("tile-background-ice-05", 8, 2)
	map:addTile("tile-rock-slope-ice-left-01", 8, 3)
	map:addTile("tile-rock-slope-ice-right-02", 8, 4)
	map:addTile("tile-background-ice-02", 8, 5)
	map:addTile("tile-background-ice-06", 8, 6)
	map:addTile("tile-background-ice-05", 8, 7)
	map:addTile("tile-ground-ice-03", 8, 8)
	map:addTile("tile-rock-ice-01", 8, 9)
	map:addTile("tile-rock-ice-01", 8, 10)
	map:addTile("tile-rock-ice-02", 8, 11)
	map:addTile("tile-background-ice-06", 9, 0)
	map:addTile("tile-background-ice-01", 9, 1)
	map:addTile("tile-rock-slope-ice-left-01", 9, 2)
	map:addTile("tile-rock-ice-03", 9, 3)
	map:addTile("tile-background-ice-cave-art-02", 9, 4)
	map:addTile("tile-background-ice-05", 9, 5)
	map:addTile("tile-background-ice-06", 9, 6)
	map:addTile("tile-ground-ice-04", 9, 7)
	map:addTile("tile-rock-ice-01", 9, 8)
	map:addTile("tile-rock-ice-02", 9, 9)
	map:addTile("tile-rock-ice-03", 9, 10)
	map:addTile("tile-rock-ice-02", 9, 11)
	map:addTile("tile-background-ice-04", 10, 0)
	map:addTile("tile-background-ice-08", 10, 1)
	map:addTile("tile-ground-ice-01", 10, 2)
	map:addTile("tile-rock-ice-03", 10, 3)
	map:addTile("tile-background-ice-01", 10, 4)
	map:addTile("tile-background-ice-04", 10, 5)
	map:addTile("tile-background-ice-08", 10, 6)
	map:addTile("tile-background-ice-cave-art-02", 10, 7)
	map:addTile("tile-background-ice-03", 10, 8)
	map:addTile("tile-ground-ice-06", 10, 9)
	map:addTile("tile-rock-ice-03", 10, 10)
	map:addTile("tile-rock-ice-01", 10, 11)
	map:addTile("tile-background-ice-01", 11, 0)
	map:addTile("tile-background-ice-08", 11, 1)
	map:addTile("tile-ground-ice-01", 11, 2)
	map:addTile("tile-rock-ice-big-01", 11, 3)
	map:addTile("tile-background-ice-03", 11, 5)
	map:addTile("tile-background-ice-06", 11, 6)
	map:addTile("tile-background-ice-05", 11, 7)
	map:addTile("tile-background-ice-03", 11, 8)
	map:addTile("tile-ground-ice-02", 11, 9)
	map:addTile("tile-rock-ice-01", 11, 10)
	map:addTile("tile-rock-ice-02", 11, 11)
	map:addTile("tile-background-ice-06", 12, 0)
	map:addTile("tile-background-ice-02", 12, 1)
	map:addTile("tile-ground-ice-01", 12, 2)
	map:addTile("tile-ground-ledge-ice-left-01", 12, 5)
	map:addTile("tile-background-ice-06", 12, 6)
	map:addTile("tile-background-ice-08", 12, 7)
	map:addTile("tile-background-ice-02", 12, 8)
	map:addTile("tile-background-ice-04", 12, 9)
	map:addTile("bridge-wall-ice-left-01", 12, 9)
	map:addTile("tile-background-ice-05", 12, 10)
	map:addTile("tile-background-ice-02", 12, 11)
	map:addTile("tile-background-ice-04", 13, 0)
	map:addTile("tile-background-ice-01", 13, 1)
	map:addTile("tile-ground-ice-01", 13, 2)
	map:addTile("tile-rock-ice-big-01", 13, 3)
	map:addTile("tile-rock-ice-02", 13, 5)
	map:addTile("tile-background-ice-06", 13, 6)
	map:addTile("tile-background-ice-01", 13, 7)
	map:addTile("tile-background-ice-01", 13, 8)
	map:addTile("tile-background-ice-02", 13, 9)
	map:addTile("bridge-wall-ice-right-01", 13, 9)
	map:addTile("tile-background-ice-02", 13, 10)
	map:addTile("tile-rock-ice-02", 13, 11)
	map:addTile("tile-background-ice-02", 14, 0)
	map:addTile("tile-background-ice-window-02", 14, 1)
	map:addTile("tile-ground-ice-04", 14, 2)
	map:addTile("tile-rock-slope-ice-right-02", 14, 5)
	map:addTile("tile-background-ice-05", 14, 6)
	map:addTile("tile-background-ice-cave-art-02", 14, 7)
	map:addTile("tile-background-ice-cave-art-02", 14, 8)
	map:addTile("tile-ground-ice-02", 14, 9)
	map:addTile("tile-rock-ice-03", 14, 10)
	map:addTile("tile-rock-ice-02", 14, 11)
	map:addTile("tile-background-ice-08", 15, 0)
	map:addTile("tile-ground-ice-01", 15, 2)
	map:addTile("tile-rock-ice-03", 15, 3)
	map:addTile("tile-rock-slope-ice-right-02", 15, 4)
	map:addTile("tile-background-ice-cave-art-02", 15, 5)
	map:addTile("tile-background-ice-03", 15, 6)
	map:addTile("tile-background-ice-06", 15, 7)
	map:addTile("tile-background-ice-02", 15, 8)
	map:addTile("tile-packagetarget-ice-01-idle", 15, 9)
	map:addTile("tile-rock-ice-03", 15, 10)
	map:addTile("tile-rock-ice-03", 15, 11)
	map:addTile("tile-rock-ice-01", 16, 0)
	map:addTile("tile-rock-ice-big-01", 16, 1)
	map:addTile("tile-rock-slope-ice-right-02", 16, 3)
	map:addTile("tile-background-ice-03", 16, 4)
	map:addTile("tile-background-ice-02", 16, 5)
	map:addTile("tile-background-ice-cave-art-02", 16, 6)
	map:addTile("tile-background-ice-05", 16, 7)
	map:addTile("tile-background-ice-07", 16, 8)
	map:addTile("tile-rock-ice-02", 16, 9)
	map:addTile("tile-rock-ice-03", 16, 10)
	map:addTile("tile-rock-ice-02", 16, 11)
	map:addTile("tile-rock-ice-02", 17, 0)
	map:addTile("tile-ground-ledge-ice-left-02", 17, 3)
	map:addTile("tile-background-ice-04", 17, 4)
	map:addTile("tile-background-ice-big-01", 17, 5)
	map:addTile("tile-background-ice-big-01", 17, 7)
	map:addTile("tile-background-ice-05", 17, 9)
	map:addTile("bridge-wall-ice-left-01", 17, 9)
	map:addTile("tile-background-ice-03", 17, 10)
	map:addTile("tile-background-ice-07", 17, 11)
	map:addTile("tile-rock-ice-03", 18, 0)
	map:addTile("tile-rock-ice-01", 18, 1)
	map:addTile("tile-rock-ice-big-01", 18, 2)
	map:addTile("tile-background-ice-07", 18, 4)
	map:addTile("tile-background-ice-06", 18, 9)
	map:addTile("bridge-wall-ice-right-01", 18, 9)
	map:addTile("tile-background-ice-08", 18, 10)
	map:addTile("tile-background-ice-07", 18, 11)
	map:addTile("tile-rock-ice-01", 19, 0)
	map:addTile("tile-rock-ice-02", 19, 1)
	map:addTile("tile-background-ice-01", 19, 4)
	map:addTile("tile-background-ice-cave-art-02", 19, 5)
	map:addTile("tile-background-ice-big-01", 19, 6)
	map:addTile("tile-background-ice-01", 19, 8)
	map:addTile("tile-ground-ice-06", 19, 9)
	map:addTile("tile-rock-ice-02", 19, 10)
	map:addTile("tile-rock-ice-02", 19, 11)
	map:addTile("tile-rock-ice-02", 20, 0)
	map:addTile("tile-rock-ice-01", 20, 1)
	map:addTile("tile-rock-ice-02", 20, 2)
	map:addTile("tile-rock-slope-ice-right-02", 20, 3)
	map:addTile("tile-background-ice-08", 20, 4)
	map:addTile("tile-background-ice-01", 20, 5)
	map:addTile("tile-background-ice-07", 20, 8)
	map:addTile("tile-ground-ice-04", 20, 9)
	map:addTile("tile-rock-ice-03", 20, 10)
	map:addTile("tile-rock-ice-01", 20, 11)
	map:addTile("tile-rock-ice-big-01", 21, 0)
	map:addTile("tile-rock-ice-01", 21, 2)
	map:addTile("tile-background-ice-04", 21, 3)
	map:addTile("tile-background-ice-01", 21, 4)
	map:addTile("tile-background-ice-07", 21, 5)
	map:addTile("tile-background-ice-07", 21, 6)
	map:addTile("tile-background-ice-01", 21, 7)
	map:addTile("tile-rock-ice-big-01", 21, 8)
	map:addTile("tile-rock-ice-03", 21, 10)
	map:addTile("tile-rock-ice-01", 21, 11)
	map:addTile("tile-rock-ice-02", 22, 2)
	map:addTile("tile-background-ice-02", 22, 3)
	map:addTile("tile-background-ice-05", 22, 4)
	map:addTile("tile-background-ice-07", 22, 5)
	map:addTile("tile-background-ice-01", 22, 6)
	map:addTile("tile-background-ice-01", 22, 7)
	map:addTile("tile-rock-ice-02", 22, 10)
	map:addTile("tile-rock-ice-01", 22, 11)
	map:addTile("tile-rock-ice-01", 23, 0)
	map:addTile("tile-rock-ice-02", 23, 1)
	map:addTile("tile-rock-ice-01", 23, 2)
	map:addTile("tile-rock-slope-ice-left-02", 23, 3)
	map:addTile("tile-background-ice-06", 23, 4)
	map:addTile("tile-background-ice-04", 23, 5)
	map:addTile("tile-background-ice-07", 23, 6)
	map:addTile("tile-rock-ice-big-01", 23, 7)
	map:addTile("tile-rock-ice-02", 23, 9)
	map:addTile("tile-rock-ice-01", 23, 10)
	map:addTile("tile-rock-ice-02", 23, 11)
	map:addTile("tile-rock-ice-02", 24, 0)
	map:addTile("tile-rock-ice-01", 24, 1)
	map:addTile("tile-rock-ice-big-01", 24, 2)
	map:addTile("tile-background-ice-05", 24, 4)
	map:addTile("tile-background-ice-05", 24, 5)
	map:addTile("tile-background-ice-04", 24, 6)
	map:addTile("tile-rock-ice-01", 24, 9)
	map:addTile("tile-rock-ice-big-01", 24, 10)
	map:addTile("tile-rock-ice-03", 25, 0)
	map:addTile("tile-rock-ice-02", 25, 1)
	map:addTile("tile-rock-shim-ice-01", 25, 4)
	map:addTile("tile-background-ice-08", 25, 5)
	map:addTile("tile-background-ice-02", 25, 6)
	map:addTile("tile-ground-ice-05", 25, 7)
	map:addTile("tile-background-ice-02", 25, 8)
	map:addTile("tile-background-ice-01", 25, 9)
	map:addTile("tile-rock-ice-left-05", 26, 0)
	map:addTile("tile-background-ice-01", 26, 1)
	map:addTile("tile-background-ice-cave-art-02", 26, 2)
	map:addTile("tile-ground-ledge-ice-right-01", 26, 3)
	map:addTile("tile-background-ice-01", 26, 4)
	map:addTile("tile-background-ice-04", 26, 5)
	map:addTile("tile-background-ice-01", 26, 6)
	map:addTile("tile-ground-ice-05", 26, 7)
	map:addTile("tile-background-ice-03", 26, 8)
	map:addTile("tile-background-ice-06", 26, 9)
	map:addTile("tile-background-ice-big-01", 26, 10)
	map:addTile("tile-background-ice-03", 27, 0)
	map:addTile("tile-background-ice-01", 27, 1)
	map:addTile("tile-background-ice-window-02", 27, 2)
	map:addTile("tile-ground-ledge-ice-right-02", 27, 3)
	map:addTile("tile-background-ice-02", 27, 4)
	map:addTile("tile-background-ice-04", 27, 5)
	map:addTile("tile-background-ice-03", 27, 6)
	map:addTile("tile-background-ice-07", 27, 7)
	map:addTile("bridge-wall-ice-right-01", 27, 7)
	map:addTile("tile-background-ice-05", 27, 8)
	map:addTile("tile-background-ice-03", 27, 9)
	map:addTile("tile-background-ice-cave-art-02", 28, 0)
	map:addTile("tile-background-ice-08", 28, 1)
	map:addTile("tile-ground-ice-05", 28, 3)
	map:addTile("tile-background-ice-big-01", 28, 4)
	map:addTile("tile-background-ice-window-02", 28, 6)
	map:addTile("tile-ground-ledge-ice-left-01", 28, 7)
	map:addTile("tile-background-ice-06", 28, 8)
	map:addTile("tile-background-ice-06", 28, 9)
	map:addTile("tile-background-ice-01", 28, 10)
	map:addTile("tile-rock-ice-02", 28, 11)
	map:addTile("tile-background-ice-08", 29, 0)
	map:addTile("tile-background-ice-cave-art-01", 29, 1)
	map:addTile("tile-background-ice-01", 29, 2)
	map:addTile("tile-background-ice-06", 29, 3)
	map:addTile("tile-ground-ice-04", 29, 7)
	map:addTile("tile-rock-ice-big-01", 29, 8)
	map:addTile("tile-rock-ice-big-01", 29, 10)
	map:addTile("tile-background-ice-01", 30, 0)
	map:addTile("tile-background-ice-02", 30, 1)
	map:addTile("tile-background-ice-06", 30, 2)
	map:addTile("tile-background-ice-big-01", 30, 3)
	map:addTile("tile-background-ice-05", 30, 5)
	map:addTile("tile-background-ice-cave-art-01", 30, 6)
	map:addTile("tile-ground-ice-03", 30, 7)
	map:addTile("tile-background-ice-cave-art-01", 31, 0)
	map:addTile("tile-background-ice-01", 31, 1)
	map:addTile("tile-background-ice-cave-art-01", 31, 2)
	map:addTile("tile-background-ice-05", 31, 5)
	map:addTile("tile-background-ice-07", 31, 6)
	map:addTile("tile-ground-ice-03", 31, 7)
	map:addTile("tile-rock-ice-01", 31, 8)
	map:addTile("tile-rock-ice-02", 31, 9)
	map:addTile("tile-rock-ice-01", 31, 10)
	map:addTile("tile-rock-ice-02", 31, 11)

	map:addCave("tile-cave-ice-01", 15, 1, "npc-man", 5000)
	map:addCave("tile-cave-ice-01", 28, 2, "none", 5000)
	map:addCave("tile-cave-ice-01", 29, 6, "none", 5000)

	map:addEmitter("tree", 3, 3, 1, 0, "")
	map:addEmitter("tree", 3, 3, 1, 0, "")
	map:addEmitter("item-stone", 5, 4, 1, 0, "")
	map:addEmitter("item-stone", 5, 5, 1, 0, "")
	map:addEmitter("item-stone", 5.1, 5, 1, 0, "")
	map:addEmitter("item-stone", 6, 4, 1, 0, "")
	map:addEmitter("tree", 10, 0, 1, 0, "")
	map:addEmitter("tree", 10, 7, 1, 0, "")
	map:addEmitter("npc-walking", 10, 8, 1, 0, "")
	map:addEmitter("item-stone", 14, 8, 1, 0, "")
	map:addEmitter("item-stone", 16.2, 8, 1, 0, "")
	map:addEmitter("npc-walking", 19, 8, 1, 0, "right=false")
	map:addEmitter("npc-walking", 23, 6, 1, 0, "")
	map:addEmitter("tree", 30, 5, 1, 0, "")

	map:setSetting("width", "32")
	map:setSetting("height", "12")
	map:setSetting("fishnpc", "true")
	map:setSetting("flyingnpc", "true")
	map:setSetting("gravity", "9.81")
	map:setSetting("packagetransfercount", "3")
	map:addStartPosition("21", "7")
	map:setSetting("points", "100")
	map:setSetting("referencetime", "50")
	map:setSetting("theme", "ice")
	map:setSetting("waterchangespeed", "0")
	map:setSetting("waterfallingdelay", "0")
	map:setSetting("waterheight", "2.7")
	map:setSetting("waterrisingdelay", "0")
	map:setSetting("wind", "0.0")
end
