4u2(rruurrdd)rrdr2(ddll)ddrruudrlddru5lu3ld3(dr)ullul10urrdd3(rruu)llrr5d3u2(lldd)lluu4lu4(ul)luu16rddrr6dllrr14dlluuluudlu3l3(rd)rurdurr6u4lddll3ululu3l6d2(rdrdr)ddluldllurr3lululuuludldld4(dr)ru3drr3ulldllu3r4lululldrd5r5lulld6r7ldll3(ur)ulddldl3d4lu2(ururr)u3(ru)rruu4luulldru3rddllulurrl3dluruulldldrrddlurrurruu4ldldldruuruuldldrddrddluulldrrddldlruuruulldldrdrddlldd3r3d4luull16ur5(rd)dlldldduururruulldd4ululullddrrdrluurdrdull4ur4(rd)d4rdu4lu3(ul)lulddurruurd3ullddul3duur3uldd4u6r3d4ldd3uld4rdlurrurrdldlu3rdlrrdrrullru8l7rullrrdd3rulullddr3druudd3rddrrulrurrddlr4urrddlruullddrrululuururruu22lddrrd6rddrrurudr3d3ru3(ur)rlldldlluru5lddlddrrulruruu6r3(ld)dluuddlddlluudrudd2(lluu)3dluluu4r4ldllu4r3drrdr4d2(lluu)ddlluuruudrldlluurrddlddluuruulldr3d5r4drru3dlldldllddll5d4luull14urrdrurrurrddldlur3dllulurddrruruurruuddrrdd3lruuluulluu3lddrddrrdrrd3rdd3l3ullddruruu3ruu4ru5d4l2(4ruul)uurrdlddrul3druddr3drruu4ruull3u5l5r3dllu3lddrulu3lrruu6r3dllull4dluudlu3l4drdrdrruruullud4ruurud3lrrddludlddluddlluruddrdrrdrru3r4dlldd8luulu4luurullulldd3luur3urudl3d3ldrdrr4u4drruululdlluuldrrl3drrdrd4r7lurdr3d4luulluu3r3l4u4rddlu4rd3(dl)lur4l4u3rurdl3d3u3l6drrdd22ruurr4u3ldllddlluulur3(lu)l4ull4dr3dluruu3ldl3drddrruu3l3uru3r3drddlrurrdru3r4udruuruu3r10dlldd8luulludrrddrruuluruu3lddrr6luuluu3luurdldldrd3rurdl3ullulddu4rdldd4rurdl3urru5r5ldllur8ull4d7ruu4lrruu6r3drrdd4lulrd4r8ullddrr4ulld3luld4rdrr6dlluulu5ldd5rldr3u8l8dldr5ull3du4ldduulldrldlluudrddurruu3ruu3l3du3rddrr4u4l4ruulruulldd5l5d5u3l6durl3urrlluu3r3d3urr3dul11rud3ldd3rud3ldd4rlud3ldd4lrudrrddllud7ruu4l2(rudr)dd3ludrrud3rulr3drr3luddlluud10l5(udrr)3d4ruullulrdrrddrruull4r4u3l3dulruul4ruu4lrdu3r4u3l3d3u3r10dlldd22luull14u3rdrdu7rdurrdd4lrrdd3rluurr4d8u7rdr3d4u3ldu5lddlluuluulluu7ldd3rdd5r3ldulld3u3lu3l4urruu22rddlddl4d3ulluu2(lldd)5r2(ldul)ld3urruurrdd3r3uruu22lddll4d3ru7rdd5r5ld3u7l4drdurlluu5rdur5ldluu3l4urruu22rddlldrdd3ld3ull3durluu4ldd3r3ld3ull3durluu9ldd8r3l2(dull)duluu3(rdur)r2(du6r)duurdur11(uulldd)lldd2(rrll4d)r2(rllddr)r2(ll4drr)ddrruudd4r4(uuddrr)u2(udd4ru)urruullrr6ullrr4ullrruullrr8ull
