rd3rd3ru3r5drruululuu3luu3r5urrddldlu3drud4ldd4ruddlddrrddll4uru3ld3l4urr3drd3l3rdd4luuru3l3d4luu3rlluurrdrdlu3rd3ru3rdrdl3drruulrddll4uru3ld3l4urr3drd3l3rdd4luur3u4ldd3rd4r3drl4urr3drrddll4uru3ld4lu3luu3ru3r3dr3dlld3rl4urr3drrddll3uddllu4ld5r5l4u3lulldl3d4rd4r4lulld4ru4r3uluu3r3urruull4drd3lu3ld4ldd3rd3r3uru3lrrd3rurul3urrddlruull4drd3lu3ld4ldd3rd3r3ur3u4lddrd3l3u4ldd3rllddrrudllu3lu3ld4lur4ullddrluurr4dld3ru3r4dll3ul4ulr4dll3ulluurr4dld3ru3r3luurru3lrd4rddl3d4ruu3l3rdd3ld3l3udd4ldr4dlluurlddrr4ulu3rd3ru4ruu3l3u4l3drddld3r3l3dlru4ruulu3r3drrd4r4ulld3luldulld3l3ul3u4r3d3rdd3ld3lu3l3dllddrr4ulu3rd3ru4ruu3l3u4l3drddld3r3ldd4ruulu3rdrlull3dlld3lru4rdllulluur3ul3u4r3d3rdrrd3r4dllu4ldll3u3l3ul3u4rullrr4drr4ulld4l3dll3ulluurr4dld3r3urru3lrd4rdd3l3rd3rdrrd3r4dllu4ldll2(3u3l)3ulluurr4dld3ru3r3ldll4urrd4ru5l7r3drddrru3r3u4rurl3d3lrr3d4r3uluurruull4drd3l3ullu3rld4lurrdrrdd3ld4ldllul3u4rurr3d4rd3rdd4luu3r3urruull4dr2(d3lu3l)rrd4ru3rd3rdd4ld3l3dllu4ldll4urrdr3udd3l4drrurrd4r3u3ru4ruu3l3u4lulld4lull3d3urrd4rurrd4r3d3rdd4ld3l3dllu4ldll2(3u3l)3ulluurr4dld3ru3rd3rurd4lu3ldll4u6r3d3urrd4rurrd4r3d3rdd4ld3l3dllu4ldll3u3l3ulu3rdru2(3l3d)llddrr4ulu3rlldldr3dlluurlddrr3uddrru4rdrrurrd4r3u3ru4ruu3l3u4lulld4lu8l4d3rdduu4l4drulu3rd3r3lu3luu4rddl3d4ruu3lu3l5dlluurlddrr4ulu3rd4rddlld3lru4ruu4lu3luu4rdd3l3dllddrr4ulu3rd3rurd4lu3luu4rdduu3lulur3ullddrluurr4dld3r3ldd3rdr3ulur3d3l4drru4rdrrurrd4r3u3r3ur3ullu3rld4ldd3rdrudrr3urruull4drd3l3rdd4luuru3ldlu3rd3rurul3urrddlruull4drd3l3rdd4luu4r4dluru3l3ruu3lul3drd3lrru3r3drrddllullu4luudd4rdrr3uru3l3ruu4lddrd3luld3ru3r4d2(llu4ld)7l7rurrd4ru4rdrrur5ul4ulld4lu5r7ld4lu8ldl8dlddrr4ulu3rdru3l4d8rurrd9l13ru4rdrrur8uruull3duu8ld4lu8ldl8dlddrru14rurrd3rlu4ld14l3ulurluur4u8rdrru9l7rd4ru8rdr8drddll4uru3l3ruu4lddrdlu3r4dllu4ld5r19lul8uluurr4dldr4u8rd4ru8r3drd3luld4r5drddll4urulruul4u8ldllu9r19ldl5dr4d20rur8uruull4drdl
