dlldr4d4rdd3r3uluulur3drddl5ulu9r7ldl6dllurdr5ulu9r8l5dllurdr4ulu8r7l4dllurdr4u4d4lddlur3d3l3uru5rdr4u8ruulur9ld8r7ldldr3d4lddlulu5rdr4ulu8r7l4d4l4dl3ulldr7urrdlul5d5rdr4ulu7r6l4d4l3dluudllur5urrdlul4d5rdr5u4d4lddludllur4urrdlul3d5rdr4u7ruulur8ld7r6ldldr3d4lddludlluru5rdr5u4d4lddlulu5rdr4u6r7lu7r6lulu7r
