textures = {
	["npc-fish-swimming-DIR-front-01"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.1435546875,
		y0 = 0.5380859375,
		x1 = 0.138671875,
		y1 = 0.12890625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 142,
		trimmedheight = 132,
		untrimmedwidth = 142,
		untrimmedheight = 132,
	},
	["npc-fish-swimming-DIR-front-02"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.4599609375,
		y0 = 0.53515625,
		x1 = 0.1396484375,
		y1 = 0.12890625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 143,
		trimmedheight = 132,
		untrimmedwidth = 143,
		untrimmedheight = 132,
	},
	["npc-fish-swimming-DIR-front-03"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.6162109375,
		y0 = 0.404296875,
		x1 = 0.1416015625,
		y1 = 0.1298828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 145,
		trimmedheight = 133,
		untrimmedwidth = 145,
		untrimmedheight = 133,
	},
	["npc-fish-swimming-DIR-front-04"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0,
		y0 = 0.41015625,
		x1 = 0.1435546875,
		y1 = 0.1298828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 147,
		trimmedheight = 133,
		untrimmedwidth = 147,
		untrimmedheight = 133,
	},
	["npc-fish-swimming-DIR-front-05"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.3134765625,
		y0 = 0.4072265625,
		x1 = 0.146484375,
		y1 = 0.130859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 150,
		trimmedheight = 134,
		untrimmedwidth = 150,
		untrimmedheight = 134,
	},
	["npc-fish-swimming-DIR-front-06"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.7841796875,
		y0 = 0.4033203125,
		x1 = 0.150390625,
		y1 = 0.1318359375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 154,
		trimmedheight = 135,
		untrimmedwidth = 154,
		untrimmedheight = 135,
	},
	["npc-fish-swimming-DIR-front-07"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.630859375,
		y0 = 0.271484375,
		x1 = 0.1533203125,
		y1 = 0.1328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 157,
		trimmedheight = 136,
		untrimmedwidth = 157,
		untrimmedheight = 136,
	},
	["npc-fish-swimming-DIR-front-08"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.1572265625,
		y0 = 0.2744140625,
		x1 = 0.15625,
		y1 = 0.1337890625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 160,
		trimmedheight = 137,
		untrimmedwidth = 160,
		untrimmedheight = 137,
	},
	["npc-fish-swimming-DIR-front-09"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.7958984375,
		y0 = 0.1376953125,
		x1 = 0.158203125,
		y1 = 0.1337890625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 162,
		trimmedheight = 137,
		untrimmedwidth = 162,
		untrimmedheight = 137,
	},
	["npc-fish-swimming-DIR-front-10"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.6376953125,
		y0 = 0,
		x1 = 0.1591796875,
		y1 = 0.134765625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 163,
		trimmedheight = 138,
		untrimmedwidth = 163,
		untrimmedheight = 138,
	},
	["npc-fish-swimming-DIR-front-11"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0,
		y0 = 0,
		x1 = 0.16015625,
		y1 = 0.1357421875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 164,
		trimmedheight = 139,
		untrimmedwidth = 164,
		untrimmedheight = 139,
	},
	["npc-fish-swimming-DIR-front-12"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.3193359375,
		y0 = 0,
		x1 = 0.1591796875,
		y1 = 0.13671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 163,
		trimmedheight = 140,
		untrimmedwidth = 163,
		untrimmedheight = 140,
	},
	["npc-fish-swimming-DIR-front-13"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0,
		y0 = 0.1357421875,
		x1 = 0.1591796875,
		y1 = 0.13671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 163,
		trimmedheight = 140,
		untrimmedwidth = 163,
		untrimmedheight = 140,
	},
	["npc-fish-swimming-DIR-front-14"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.796875,
		y0 = 0,
		x1 = 0.158203125,
		y1 = 0.1376953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 162,
		trimmedheight = 141,
		untrimmedwidth = 162,
		untrimmedheight = 141,
	},
	["npc-fish-swimming-DIR-front-15"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.31640625,
		y0 = 0.13671875,
		x1 = 0.1572265625,
		y1 = 0.1376953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 161,
		trimmedheight = 141,
		untrimmedwidth = 161,
		untrimmedheight = 141,
	},
	["npc-fish-swimming-DIR-front-16"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0,
		y0 = 0.2724609375,
		x1 = 0.1572265625,
		y1 = 0.1376953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 161,
		trimmedheight = 141,
		untrimmedwidth = 161,
		untrimmedheight = 141,
	},
	["npc-fish-swimming-DIR-front-17"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.1591796875,
		y0 = 0.13671875,
		x1 = 0.1572265625,
		y1 = 0.1376953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 161,
		trimmedheight = 141,
		untrimmedwidth = 161,
		untrimmedheight = 141,
	},
	["npc-fish-swimming-DIR-front-18"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.6376953125,
		y0 = 0.134765625,
		x1 = 0.158203125,
		y1 = 0.13671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 162,
		trimmedheight = 140,
		untrimmedwidth = 162,
		untrimmedheight = 140,
	},
	["npc-fish-swimming-DIR-front-19"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.16015625,
		y0 = 0,
		x1 = 0.1591796875,
		y1 = 0.13671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 163,
		trimmedheight = 140,
		untrimmedwidth = 163,
		untrimmedheight = 140,
	},
	["npc-fish-swimming-DIR-front-20"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.478515625,
		y0 = 0,
		x1 = 0.1591796875,
		y1 = 0.1357421875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 163,
		trimmedheight = 139,
		untrimmedwidth = 163,
		untrimmedheight = 139,
	},
	["npc-fish-swimming-DIR-front-21"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.478515625,
		y0 = 0.1357421875,
		x1 = 0.158203125,
		y1 = 0.134765625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 162,
		trimmedheight = 138,
		untrimmedwidth = 162,
		untrimmedheight = 138,
	},
	["npc-fish-swimming-DIR-front-22"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.4736328125,
		y0 = 0.2705078125,
		x1 = 0.1572265625,
		y1 = 0.1337890625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 161,
		trimmedheight = 137,
		untrimmedwidth = 161,
		untrimmedheight = 137,
	},
	["npc-fish-swimming-DIR-front-23"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.3134765625,
		y0 = 0.2744140625,
		x1 = 0.1552734375,
		y1 = 0.1328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 159,
		trimmedheight = 136,
		untrimmedwidth = 159,
		untrimmedheight = 136,
	},
	["npc-fish-swimming-DIR-front-24"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.7841796875,
		y0 = 0.271484375,
		x1 = 0.1513671875,
		y1 = 0.1318359375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 155,
		trimmedheight = 135,
		untrimmedwidth = 155,
		untrimmedheight = 135,
	},
	["npc-fish-swimming-DIR-front-25"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.46875,
		y0 = 0.404296875,
		x1 = 0.1474609375,
		y1 = 0.130859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 151,
		trimmedheight = 134,
		untrimmedwidth = 151,
		untrimmedheight = 134,
	},
	["npc-fish-swimming-DIR-front-26"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.1572265625,
		y0 = 0.408203125,
		x1 = 0.1435546875,
		y1 = 0.1298828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 147,
		trimmedheight = 133,
		untrimmedwidth = 147,
		untrimmedheight = 133,
	},
	["npc-fish-swimming-DIR-front-27"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.6162109375,
		y0 = 0.5341796875,
		x1 = 0.140625,
		y1 = 0.1298828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 144,
		trimmedheight = 133,
		untrimmedwidth = 144,
		untrimmedheight = 133,
	},
	["npc-fish-swimming-DIR-front-28"] = {
		image = "caveexpress-npc_fish-big",
		x0 = 0.7568359375,
		y0 = 0.53515625,
		x1 = 0.138671875,
		y1 = 0.12890625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 142,
		trimmedheight = 132,
		untrimmedwidth = 142,
		untrimmedheight = 132,
	},
}
