textures = {
	["car-black-02-front-01"] = {
		image = "miniracer-1-big",
		x0 = 0.953125,
		y0 = 0.1279296875,
		x1 = 0.03466796875,
		y1 = 0.056640625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 71,
		trimmedheight = 116,
		untrimmedwidth = 71,
		untrimmedheight = 116,
	},
	["car-black-05-front-01"] = {
		image = "miniracer-1-big",
		x0 = 0.96484375,
		y0 = 0.3701171875,
		x1 = 0.0341796875,
		y1 = 0.05908203125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 70,
		trimmedheight = 121,
		untrimmedwidth = 70,
		untrimmedheight = 121,
	},
	["car-blue-02-front-01"] = {
		image = "miniracer-1-big",
		x0 = 0.953125,
		y0 = 0.185546875,
		x1 = 0.03466796875,
		y1 = 0.056640625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 71,
		trimmedheight = 116,
		untrimmedwidth = 71,
		untrimmedheight = 116,
	},
	["car-blue-05-front-01"] = {
		image = "miniracer-1-big",
		x0 = 0.96484375,
		y0 = 0.43017578125,
		x1 = 0.0341796875,
		y1 = 0.05908203125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 70,
		trimmedheight = 121,
		untrimmedwidth = 70,
		untrimmedheight = 121,
	},
	["car-green-02-front-01"] = {
		image = "miniracer-1-big",
		x0 = 0.2548828125,
		y0 = 0.2431640625,
		x1 = 0.03466796875,
		y1 = 0.056640625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 71,
		trimmedheight = 116,
		untrimmedwidth = 71,
		untrimmedheight = 116,
	},
	["car-green-05-front-01"] = {
		image = "miniracer-1-big",
		x0 = 0.4853515625,
		y0 = 0.4296875,
		x1 = 0.0341796875,
		y1 = 0.05908203125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 70,
		trimmedheight = 121,
		untrimmedwidth = 70,
		untrimmedheight = 121,
	},
	["car-red-02-front-01"] = {
		image = "miniracer-1-big",
		x0 = 0.2548828125,
		y0 = 0.30078125,
		x1 = 0.03466796875,
		y1 = 0.056640625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 71,
		trimmedheight = 116,
		untrimmedwidth = 71,
		untrimmedheight = 116,
	},
	["car-red-05-front-01"] = {
		image = "miniracer-1-big",
		x0 = 0.4453125,
		y0 = 0.48486328125,
		x1 = 0.0341796875,
		y1 = 0.05908203125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 70,
		trimmedheight = 121,
		untrimmedwidth = 70,
		untrimmedheight = 121,
	},
	["car-yellow-02-front-01"] = {
		image = "miniracer-1-big",
		x0 = 0.19140625,
		y0 = 0.94140625,
		x1 = 0.03466796875,
		y1 = 0.056640625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 71,
		trimmedheight = 116,
		untrimmedwidth = 71,
		untrimmedheight = 116,
	},
	["car-yellow-05-front-01"] = {
		image = "miniracer-1-big",
		x0 = 0.8486328125,
		y0 = 0.3818359375,
		x1 = 0.0341796875,
		y1 = 0.05908203125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 70,
		trimmedheight = 121,
		untrimmedwidth = 70,
		untrimmedheight = 121,
	},
	["oil-01-middle-01"] = {
		image = "miniracer-1-big",
		x0 = 0.8984375,
		y0 = 0.4970703125,
		x1 = 0.05322265625,
		y1 = 0.04638671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 109,
		trimmedheight = 95,
		untrimmedwidth = 109,
		untrimmedheight = 95,
	},
	["road-asphalt-08-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.2783203125,
		y0 = 0.94140625,
		x1 = 0.05078125,
		y1 = 0.05029296875,
		trimmedoffsetx = 24,
		trimmedoffsety = 25,
		trimmedwidth = 104,
		trimmedheight = 103,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-65-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.341796875,
		y0 = 0.318359375,
		x1 = 0.05078125,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 104,
		trimmedheight = 103,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-07-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.330078125,
		y0 = 0.94140625,
		x1 = 0.05078125,
		y1 = 0.05029296875,
		trimmedoffsetx = 24,
		trimmedoffsety = 25,
		trimmedwidth = 104,
		trimmedheight = 103,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-10-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.19140625,
		y0 = 0.19140625,
		x1 = 0.05029296875,
		y1 = 0.05078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 24,
		trimmedwidth = 103,
		trimmedheight = 104,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-15-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.0009765625,
		y0 = 0.0009765625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-16-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.0009765625,
		y0 = 0.064453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-18-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.0009765625,
		y0 = 0.1279296875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-19-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.0009765625,
		y0 = 0.19140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-20-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.0009765625,
		y0 = 0.2548828125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-21-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.0009765625,
		y0 = 0.318359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-22-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.0009765625,
		y0 = 0.3818359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-23-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.0009765625,
		y0 = 0.4453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-24-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.0009765625,
		y0 = 0.5087890625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-25-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.0009765625,
		y0 = 0.572265625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-26-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.0009765625,
		y0 = 0.6357421875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-27-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.0009765625,
		y0 = 0.69921875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-28-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.0009765625,
		y0 = 0.7626953125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-29-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.0009765625,
		y0 = 0.826171875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-30-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.0009765625,
		y0 = 0.8896484375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-32-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.095703125,
		y0 = 0.0009765625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-33-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.1591796875,
		y0 = 0.0009765625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-34-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.22265625,
		y0 = 0.0009765625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-35-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.2861328125,
		y0 = 0.0009765625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-36-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.349609375,
		y0 = 0.0009765625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-37-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.4130859375,
		y0 = 0.0009765625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-38-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.4765625,
		y0 = 0.0009765625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-39-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.5400390625,
		y0 = 0.0009765625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-40-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.603515625,
		y0 = 0.0009765625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-41-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.6669921875,
		y0 = 0.0009765625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-42-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.73046875,
		y0 = 0.0009765625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-43-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.7939453125,
		y0 = 0.0009765625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-44-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.857421875,
		y0 = 0.0009765625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-45-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.9208984375,
		y0 = 0.0009765625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-46-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.064453125,
		y0 = 0.064453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-47-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.064453125,
		y0 = 0.1279296875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-48-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.064453125,
		y0 = 0.19140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-50-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.064453125,
		y0 = 0.2548828125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-53-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.064453125,
		y0 = 0.318359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-54-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.064453125,
		y0 = 0.3818359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-55-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.064453125,
		y0 = 0.4453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-56-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.064453125,
		y0 = 0.5087890625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-57-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.064453125,
		y0 = 0.572265625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-58-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.064453125,
		y0 = 0.6357421875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-59-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.064453125,
		y0 = 0.69921875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-60-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.064453125,
		y0 = 0.7626953125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-61-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.24267578125,
		y0 = 0.19140625,
		x1 = 0.05029296875,
		y1 = 0.05078125,
		trimmedoffsetx = 25,
		trimmedoffsety = 0,
		trimmedwidth = 103,
		trimmedheight = 104,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-62-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.064453125,
		y0 = 0.826171875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-63-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.064453125,
		y0 = 0.8896484375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-64-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.3818359375,
		y0 = 0.43359375,
		x1 = 0.05078125,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 104,
		trimmedheight = 103,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-66-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.14013671875,
		y0 = 0.064453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-67-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.20361328125,
		y0 = 0.064453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-68-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.26708984375,
		y0 = 0.064453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-69-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.33056640625,
		y0 = 0.064453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-70-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.39404296875,
		y0 = 0.064453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-71-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.45751953125,
		y0 = 0.064453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-72-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.52099609375,
		y0 = 0.064453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-73-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.58447265625,
		y0 = 0.064453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-74-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.64794921875,
		y0 = 0.064453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-75-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.71142578125,
		y0 = 0.064453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-76-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.77490234375,
		y0 = 0.064453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-77-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.83837890625,
		y0 = 0.064453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-78-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.90185546875,
		y0 = 0.064453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-79-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.1279296875,
		y0 = 0.1279296875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-80-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.1279296875,
		y0 = 0.19140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-81-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.1279296875,
		y0 = 0.2548828125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-82-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.1279296875,
		y0 = 0.318359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-83-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.1279296875,
		y0 = 0.3818359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-84-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.1279296875,
		y0 = 0.4453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-85-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.1279296875,
		y0 = 0.5087890625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-86-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.1279296875,
		y0 = 0.572265625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-87-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.1279296875,
		y0 = 0.6357421875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-88-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.1279296875,
		y0 = 0.69921875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-89-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.1279296875,
		y0 = 0.7626953125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-90-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.1279296875,
		y0 = 0.826171875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-01-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.1279296875,
		y0 = 0.8896484375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-02-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.19140625,
		y0 = 0.1279296875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-03-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.2548828125,
		y0 = 0.1279296875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-04-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.3818359375,
		y0 = 0.3818359375,
		x1 = 0.05078125,
		y1 = 0.05029296875,
		trimmedoffsetx = 24,
		trimmedoffsety = 25,
		trimmedwidth = 104,
		trimmedheight = 103,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-05-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.318359375,
		y0 = 0.1279296875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-06-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.3818359375,
		y0 = 0.1279296875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-07-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.22705078125,
		y0 = 0.94140625,
		x1 = 0.05029296875,
		y1 = 0.05078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 24,
		trimmedwidth = 103,
		trimmedheight = 104,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-09-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.4453125,
		y0 = 0.1279296875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-10-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.5087890625,
		y0 = 0.1279296875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-12-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.572265625,
		y0 = 0.1279296875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-13-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.6357421875,
		y0 = 0.1279296875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-15-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.69921875,
		y0 = 0.1279296875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-16-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.7626953125,
		y0 = 0.1279296875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-17-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.826171875,
		y0 = 0.1279296875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-18-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.8896484375,
		y0 = 0.1279296875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-19-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.19140625,
		y0 = 0.2431640625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-20-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.2939453125,
		y0 = 0.19140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-21-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.357421875,
		y0 = 0.19140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-22-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.4208984375,
		y0 = 0.19140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-23-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.484375,
		y0 = 0.19140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-24-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.5478515625,
		y0 = 0.19140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-25-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.611328125,
		y0 = 0.19140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-26-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.6748046875,
		y0 = 0.19140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-27-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.73828125,
		y0 = 0.19140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-29-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.8017578125,
		y0 = 0.19140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-30-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.865234375,
		y0 = 0.19140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-31-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.9287109375,
		y0 = 0.2431640625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-32-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.29052734375,
		y0 = 0.2548828125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-33-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.19140625,
		y0 = 0.306640625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-34-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.35400390625,
		y0 = 0.2548828125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-35-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.41748046875,
		y0 = 0.2548828125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-36-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.48095703125,
		y0 = 0.2548828125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-37-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.54443359375,
		y0 = 0.2548828125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-38-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.60791015625,
		y0 = 0.2548828125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-39-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.67138671875,
		y0 = 0.2548828125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-40-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.73486328125,
		y0 = 0.2548828125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-41-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.79833984375,
		y0 = 0.2548828125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-42-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.86181640625,
		y0 = 0.2548828125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-43-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.92529296875,
		y0 = 0.306640625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-44-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.19140625,
		y0 = 0.3701171875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-45-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.19140625,
		y0 = 0.43359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-47-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.19140625,
		y0 = 0.4970703125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-50-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.19140625,
		y0 = 0.560546875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-51-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.19140625,
		y0 = 0.6240234375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-52-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.19140625,
		y0 = 0.6875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-53-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.19140625,
		y0 = 0.7509765625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-54-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.19140625,
		y0 = 0.814453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-55-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.19140625,
		y0 = 0.8779296875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-56-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.2548828125,
		y0 = 0.3701171875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-57-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.2548828125,
		y0 = 0.43359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-58-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.29052734375,
		y0 = 0.318359375,
		x1 = 0.05029296875,
		y1 = 0.05078125,
		trimmedoffsetx = 25,
		trimmedoffsety = 0,
		trimmedwidth = 103,
		trimmedheight = 104,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-59-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.2548828125,
		y0 = 0.4970703125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-60-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.2548828125,
		y0 = 0.560546875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-61-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.43359375,
		y0 = 0.43359375,
		x1 = 0.05078125,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 104,
		trimmedheight = 103,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-62-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.96533203125,
		y0 = 0.064453125,
		x1 = 0.03173828125,
		y1 = 0.0625,
		trimmedoffsetx = 63,
		trimmedoffsety = 0,
		trimmedwidth = 65,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-63-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.2548828125,
		y0 = 0.6240234375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-64-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.2548828125,
		y0 = 0.6875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-65-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.2548828125,
		y0 = 0.7509765625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-66-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.2548828125,
		y0 = 0.814453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-67-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.2548828125,
		y0 = 0.8779296875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-68-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.318359375,
		y0 = 0.3701171875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-69-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.318359375,
		y0 = 0.43359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-70-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.318359375,
		y0 = 0.4970703125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-71-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.318359375,
		y0 = 0.560546875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-72-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.318359375,
		y0 = 0.6240234375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-73-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.318359375,
		y0 = 0.6875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-74-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.318359375,
		y0 = 0.7509765625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-75-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.318359375,
		y0 = 0.814453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-76-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.318359375,
		y0 = 0.8779296875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-77-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.3935546875,
		y0 = 0.318359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-78-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.45703125,
		y0 = 0.318359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-79-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.5205078125,
		y0 = 0.318359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-80-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.583984375,
		y0 = 0.318359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-81-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.6474609375,
		y0 = 0.318359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-82-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.7109375,
		y0 = 0.318359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-83-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.7744140625,
		y0 = 0.318359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-84-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.837890625,
		y0 = 0.318359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-85-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.9013671875,
		y0 = 0.3701171875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-86-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.3818359375,
		y0 = 0.490234375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-87-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.53125,
		y0 = 0.3818359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-88-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.5947265625,
		y0 = 0.3818359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-89-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.658203125,
		y0 = 0.3818359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-90-back-01"] = {
		image = "miniracer-1-big",
		x0 = 0.7216796875,
		y0 = 0.3818359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["rock-06-middle-01"] = {
		image = "miniracer-1-big",
		x0 = 0.05126953125,
		y0 = 0.953125,
		x1 = 0.04345703125,
		y1 = 0.0400390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 89,
		trimmedheight = 82,
		untrimmedwidth = 89,
		untrimmedheight = 82,
	},
	["rock-07-middle-01"] = {
		image = "miniracer-1-big",
		x0 = 0.43359375,
		y0 = 0.3818359375,
		x1 = 0.0478515625,
		y1 = 0.046875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 96,
		untrimmedwidth = 98,
		untrimmedheight = 96,
	},
	["rock-15-middle-01"] = {
		image = "miniracer-1-big",
		x0 = 0.0009765625,
		y0 = 0.953125,
		x1 = 0.04931640625,
		y1 = 0.041015625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 101,
		trimmedheight = 84,
		untrimmedwidth = 101,
		untrimmedheight = 84,
	},
	["rock-17-middle-01"] = {
		image = "miniracer-1-big",
		x0 = 0.095703125,
		y0 = 0.953125,
		x1 = 0.04345703125,
		y1 = 0.0400390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 89,
		trimmedheight = 82,
		untrimmedwidth = 89,
		untrimmedheight = 82,
	},
	["rock-18-middle-01"] = {
		image = "miniracer-1-big",
		x0 = 0.482421875,
		y0 = 0.3818359375,
		x1 = 0.0478515625,
		y1 = 0.046875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 96,
		untrimmedwidth = 98,
		untrimmedheight = 96,
	},
	["tent-blue-front-01"] = {
		image = "miniracer-1-big",
		x0 = 0.78515625,
		y0 = 0.3818359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tent-red-front-01"] = {
		image = "miniracer-1-big",
		x0 = 0.8837890625,
		y0 = 0.43359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["ui/icon-campaign"] = {
		image = "miniracer-1-big",
		x0 = 0.5205078125,
		y0 = 0.4453125,
		x1 = 0.0625,
		y1 = 0.060546875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 124,
		untrimmedwidth = 128,
		untrimmedheight = 124,
	},
	["ui/icon-google-login"] = {
		image = "miniracer-1-big",
		x0 = 0.837890625,
		y0 = 0.4970703125,
		x1 = 0.0595703125,
		y1 = 0.0595703125,
		trimmedoffsetx = 11,
		trimmedoffsety = 11,
		trimmedwidth = 122,
		trimmedheight = 122,
		untrimmedwidth = 144,
		untrimmedheight = 144,
	},
	["ui/map-icon-locked"] = {
		image = "miniracer-1-big",
		x0 = 0.583984375,
		y0 = 0.4453125,
		x1 = 0.0625,
		y1 = 0.060546875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 124,
		untrimmedwidth = 128,
		untrimmedheight = 124,
	},
	["ui/map-icon-unlocked-0"] = {
		image = "miniracer-1-big",
		x0 = 0.6474609375,
		y0 = 0.4453125,
		x1 = 0.0625,
		y1 = 0.060546875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 124,
		untrimmedwidth = 128,
		untrimmedheight = 124,
	},
	["ui/map-icon-unlocked-1"] = {
		image = "miniracer-1-big",
		x0 = 0.7109375,
		y0 = 0.4453125,
		x1 = 0.0625,
		y1 = 0.060546875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 124,
		untrimmedwidth = 128,
		untrimmedheight = 124,
	},
	["ui/map-icon-unlocked-2"] = {
		image = "miniracer-1-big",
		x0 = 0.7109375,
		y0 = 0.4453125,
		x1 = 0.0625,
		y1 = 0.060546875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 124,
		untrimmedwidth = 128,
		untrimmedheight = 124,
	},
	["ui/map-icon-unlocked-3"] = {
		image = "miniracer-1-big",
		x0 = 0.7109375,
		y0 = 0.4453125,
		x1 = 0.0625,
		y1 = 0.060546875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 124,
		untrimmedwidth = 128,
		untrimmedheight = 124,
	},
	["ui/map-icon-unlocked"] = {
		image = "miniracer-1-big",
		x0 = 0.7744140625,
		y0 = 0.4453125,
		x1 = 0.0625,
		y1 = 0.060546875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 124,
		untrimmedwidth = 128,
		untrimmedheight = 124,
	},
}
