uu4l2(dlulull)ulldrdrurrd4rd6rddluru4lu4luluuruuddlddllrddru3rddru4rddluru3l3ruurruull3durrul3urruulld3ldd4lullddrrul3rddrdd4lull2(ddru3r)drru4l4ur3u3r3dl3d3ur3ulluul4dl4d5ldlu4rddru3rdrru3lrruurrulul3dur5u3lddl4dllddrruudrrdrrullruur4urru4lulldrrlddlddruu4lulldrrl3urruullddrrululdlluuld3luuld5luurdld4rd4rdrddldduuruurrluuld3luuld4luurdld3r3lddllddrr3udlldr3dllddrru3ruu4rdrruulldrdru4luuluu4rdrr2(uuld3l)ulld4r4dl3d3l3ur3u3dl3d3ruurrl4u5rurd4luuld3lulld3rllddlldrdr3udl5d3ruur4urruullddullulldrrlddl5drrddruu3lulldrr
