ddllu4lulldllulddu3rurrd5lul3druu7rd4r4d2(lluu)ru7lulddu7rddlldlluuddrrurrd3l3r3u7lulddrddldrl3d3ldllu4rdr3udrrd3ruul4udd4r3u6luld4lulldrddl3drdul3uruu3rurdrddldrdl3d3ldllur6u6d3r2(druud)4ruurudll5u4r3d3lrddll4udd4r3u6lul4d3u7rd4r3dlru7lrddll4udd4r3u6lul3duu7r6drddl7uru7lulddu7r8d3r3ululrdr3d3l7uru7luldl3d3u3lulld4rur3duu8rd4rdd3ldl3uru8lulddu4r3d6rddruru3ldl3uru8luld
