u3(ul)u10l3drr3dldl6ulu8rddrr3d4ru3(ul)uull3duu8l3drrddldl5ulu8r3drurdldrurdrdrru3(ul)uull3duu8l3drruldluulu8r3drurdldrdrrdrr3u3(lu)ullddu8lddrrddldl4ulu8r3drruldlud3r3(dr)ru4(ul)uull3duu8l5d4ruldrdrru5ldl5ulu8rld4(dr)rd3ru4(ul)uull3drduluu8l9dr4uruldl4ulu8rld3(dr)dd5ru4(ul)uull3duu8l9d3ruruuru4ldl5ulu8rldd3rddurdrdd3ru4(ul)uullddu8ldd3rdlddrrullrrdd3ldl6ulu9r8lddrrddldl4ulu8r7lddrrdldl3ulu6r4(dr)r3(ul)u7l7rdrdrddrrddllu3(ul)u3(dr)r3(ul)u5l5rdrdrdd3(lu)drdrrululu4l4rdrddluur3d3rdldluurul3d5ru4(ul)uulld4l3rddrr4d4ru3ldlu3(ul)urull3rurrd4(dr)d4luululrdr3dlu3(ul)uu3r3ld3(dr)r3(ul)rdrdd3(lu)drdrr3(ul)rdrddluudlu
