4luullddlluru2(3rdd3l)ud3ruu4r4urruulluurdr2(3dll3u)rl3drr4d4rddrruurrdld2(3luu3r)du3l2(4dll)ddrul3ull3drl3urr3d6u3drrulrurruu3ldldduulu3lddrudrddrr3ululldd3ldrdrrudrdd3(lu)urururrur3ulldrldlldd3ururuuldl3dll3(ur)rd4rddrrdd3luluuddrd3ruulduluull3rdrdrrulu3luu3(rd)dl4dlldlluururrlldlddrrurruu3dldlddrur3urr3(dl)lddlluurl2(lruu)lu4ldu2(udrr)ur4ulrrlddrl9d6u3rdurrduu
