rdrlull3d3ldd4rururdd4urr3dlr3ullddlddrurr3u3ldduu4rurrd5lrr5drddl6uddlldllurd5luu3r3urrddu4rurrd5ldlddld4luu3r3urrd3r3dlld5l5rurr3ullddlduruurr3dlld4l4ruuld3ruuldrdlldllrruu3(ld)d3ruullruurrdluldrdlurr2(3ul3d)
