textures = {
	["npc-woman-falling-middle-01"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.64453125,
		y0 = 0.5625,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-falling-middle-02"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.515625,
		y0 = 0.75,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-falling-middle-03"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.515625,
		y0 = 0.5625,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-falling-middle-04"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.7734375,
		y0 = 0.375,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-falling-middle-05"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.64453125,
		y0 = 0.375,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-falling-middle-06"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.515625,
		y0 = 0.375,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-falling-middle-07"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.38671875,
		y0 = 0.75,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-idle-middle-01"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.38671875,
		y0 = 0.5625,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-idle-middle-02"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.38671875,
		y0 = 0.375,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-idle-middle-03"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.7734375,
		y0 = 0.1875,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-swimming-idle-middle-01"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.64453125,
		y0 = 0.1875,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-swimming-idle-middle-02"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.515625,
		y0 = 0.1875,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-swimming-left-middle-01"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.38671875,
		y0 = 0.1875,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-swimming-left-middle-02"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.2578125,
		y0 = 0.75,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-swimming-left-middle-03"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.2578125,
		y0 = 0.5625,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-swimming-right-middle-01"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.2578125,
		y0 = 0.375,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-swimming-right-middle-02"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.2578125,
		y0 = 0.1875,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-swimming-right-middle-03"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.12890625,
		y0 = 0.75,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-walk-left-middle-01"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.12890625,
		y0 = 0.5625,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-walk-left-middle-02"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.12890625,
		y0 = 0.375,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-walk-left-middle-03"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.12890625,
		y0 = 0.1875,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-walk-left-middle-04"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.7734375,
		y0 = 0,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-walk-left-middle-05"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.64453125,
		y0 = 0,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-walk-left-middle-06"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.515625,
		y0 = 0,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-walk-left-middle-07"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.38671875,
		y0 = 0,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-walk-right-middle-01"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.2578125,
		y0 = 0,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-walk-right-middle-02"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0.12890625,
		y0 = 0,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-walk-right-middle-03"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0,
		y0 = 0.75,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-walk-right-middle-04"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0,
		y0 = 0.5625,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-walk-right-middle-05"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0,
		y0 = 0.375,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-walk-right-middle-06"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0,
		y0 = 0.1875,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
	["npc-woman-walk-right-middle-07"] = {
		image = "caveexpress-npc_woman-big",
		x0 = 0,
		y0 = 0,
		x1 = 0.12890625,
		y1 = 0.1875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 96,
		untrimmedwidth = 66,
		untrimmedheight = 96,
	},
}
