uuruurrd4r7u5luuruuldll6dldrlddlddrrddllulldd2(lluuruu)rur3u3r3l3dldlddrdrruu3r3uldluudrr3dlludrddllrdd3ruurrd4r7u5luuruuldll4dlddldlddrruuddlddrrddllulldd2(lluuruu)rur3u3rdu3l3dldlddrdrruurrddldd3ruurrdrruluuruuldlld3lddldd3ruurrdrruld3r7u5luuruuldlldd4l3dl3(dld)dllu4l7d5rddlddrurr6ur3uruulluurrdrruu2(rrddldd)ldl3d3l3r3ururuululldd3l3drurddull3urrduruurrdrddldl3dlluull3uruuruu3lddllu4l7d5rddlddrurr4urrddl3r3ururuulullddlluuruu3lddllu4l7d5rddlddrurruurud3r3ururuulullddlluuruulluurrdullddlddllulldrddlddrurrur
