3l3uldll3uruurrdru4luurdldrddluu4dlddll5urrdr3d3rddluru3l3ulull5drrdru3l5urrdrddld3rdrulu3ruu5r3dldd4ruuruulu5ldllurdru6r3dluuru6luld6rddlur3uruul4d5ldluud5rddrurul4ulldrur4d5ldlu3r3dlddr4u4d3r4ulu4ldllurdru4rdrru6ldllurlddllu3rld4lu3rdrulurd3ldd3l3uruul4dld3rdruulu3rdru3ldd3l3ur4ul6dld3rdruulurrldd3l7ulldrur6dld3rdrulu3rulldd3l5u3rdllul4dld3rdrulurrld3l4u3r3urrdd4lul5dld3rdruulu4rldlld3l4u3r3urdrd4lul5dld3rdrulurrld3l4u3ldrrur3dld3rdruulu3rlldd3l3u3l4drrdrulu3rdruulurr
