npcgrandpa = {
	walkleft = "npc-cave-walk",
	walkright = "npc-cave-walk",
}

npcwoman = {
	walkleft = "npc-cave-walk",
	walkright = "npc-cave-walk",
}

npcman = {
	walkleft = "npc-cave-walk",
	walkright = "npc-cave-walk",
}

npcflying = {
	flying = "npc-flying-flying",
	flyingleft = "npc-flying-flying",
	flyingright = "npc-flying-flying",
}

npcwalking = {
	walkleft = "npc-walking-walk",
	walkright = "npc-walking-walk",
	attackinitleft = "npc-walking-attack-init",
	attackinitright = "npc-walking-attack-init",
	attackleft = "npc-walking-attack",
	attackright = "npc-walking-attack",
	knockoutleft = "npc-walking-knockout",
	knockoutright = "npc-walking-knockout",
	dazed = "npc-walking-dazed",
	dazedleft = "npc-walking-dazed",
	dazedright = "npc-walking-dazed",
}

npcmammut = {
	walkleft = "npc-mammut-walk",
	walkright = "npc-mammut-walk",
	attackinitleft = "npc-mammut-attack-init",
	attackinitright = "npc-mammut-attack-init",
	attackleft = "npc-mammut-attack",
	attackright = "npc-mammut-attack",
	knockoutleft = "npc-mammut-knockout",
	knockoutright = "npc-mammut-knockout",
	dazed = "npc-mammut-dazed",
	dazedleft = "npc-mammut-dazed",
	dazedright = "npc-mammut-dazed",
}

npcblowing = {
	idle = "npc-blowing-idle",
	idleleft = "npc-blowing-idle",
	idleright = "npc-blowing-idle",
	dazed = "npc-blowing-dazed",
	dazedleft = "npc-blowing-dazed",
	dazedright = "npc-blowing-dazed",
}

player = {
	flying = "player-flying",
	flyingleft = "player-flying",
	flyingright = "player-flying",
}

tree = {
	dazed = "tree-dazed",
	dazedleft = "tree-dazed",
	dazedright = "tree-dazed",
}

tilepackagetargetice = {
	active = "tile-packagetarget-active",
}

tilepackagetargetrock = {
	active = "tile-packagetarget-active",
}

tilegeyserice = {
	active = "tile-geyser-active",
}

tilegeyserrock = {
	active = "tile-geyser-active",
}
