l5drddl6ull3dlddrrlluuruul3dur4ulldlddldrrl3ururrdrr4drddlulldlluudrrluuruul3dur4ulldl3drl3ururrd3ru4l3r5drddl6uru3l3dldl3drrurldll2(3urr)4drddl6urulldl3dlldd3r3luurdur3urr4drddl5u4dlldllu3rlluur3ururrdl4drddl6urul
