textures = {
	["ui-npc-mammut-middle-01"] = {
		image = "caveexpress-ui-npc-mammut-small",
		x0 = 0.3095703125,
		y0 = 0.4921875,
		x1 = 0.3095703125,
		y1 = 0.4921875,
		trimmedoffsetx = 36,
		trimmedoffsety = 2,
		trimmedwidth = 317,
		trimmedheight = 252,
		untrimmedwidth = 427,
		untrimmedheight = 254,
	},
	["ui-npc-mammut-middle-02"] = {
		image = "caveexpress-ui-npc-mammut-small",
		x0 = 0,
		y0 = 0,
		x1 = 0.3134765625,
		y1 = 0.4921875,
		trimmedoffsetx = 32,
		trimmedoffsety = 2,
		trimmedwidth = 321,
		trimmedheight = 252,
		untrimmedwidth = 427,
		untrimmedheight = 254,
	},
	["ui-npc-mammut-middle-03"] = {
		image = "caveexpress-ui-npc-mammut-small",
		x0 = 0.615234375,
		y0 = 0,
		x1 = 0.2998046875,
		y1 = 0.4921875,
		trimmedoffsetx = 47,
		trimmedoffsety = 2,
		trimmedwidth = 307,
		trimmedheight = 252,
		untrimmedwidth = 427,
		untrimmedheight = 254,
	},
	["ui-npc-mammut-middle-04"] = {
		image = "caveexpress-ui-npc-mammut-small",
		x0 = 0.3134765625,
		y0 = 0,
		x1 = 0.3017578125,
		y1 = 0.4921875,
		trimmedoffsetx = 44,
		trimmedoffsety = 2,
		trimmedwidth = 309,
		trimmedheight = 252,
		untrimmedwidth = 427,
		untrimmedheight = 254,
	},
	["ui-npc-mammut-middle-05"] = {
		image = "caveexpress-ui-npc-mammut-small",
		x0 = 0,
		y0 = 0.4921875,
		x1 = 0.3095703125,
		y1 = 0.4921875,
		trimmedoffsetx = 36,
		trimmedoffsety = 2,
		trimmedwidth = 317,
		trimmedheight = 252,
		untrimmedwidth = 427,
		untrimmedheight = 254,
	},
}
