3ldlddrrurr3d7l7ururrdllrruuruu7l3d3r9dld5ruu3r3u3luurd4lruruu3l7dld5ru3r3ulldluru4lrr3u3l8dld4ruu4r3ulluuld4l3u3rddrd3lrr3u3l7dld4ru4r3ulldlluru3lrr3u3l8dld3rll10u3l3u7rddl4drruuruul5d4lrr3u3l7dld3ru5r3ul2(luuru)urdrdllul3drdlld4l3u3rddrd3lrr3u3l7dldrrl5u3r5urrdrruuldrdlul3drdllruruluurrdlu3l4drd3lrr3u3l8d8urrulu4r3drdllr3urruuldrdlulluu7l3drrur9dlddrrul8u3rddrd3lrr3u3l7dldr7uluruu5r3drdllr4uluu7l3drrur8drddllur7u3rddrd3lrr3u3l7drdl5u5r4urruuldrdlul3drdllr4ull4drd3lrr3u3l8d5u3rddru3r3d5l5r3ullu4lrr3u3l7durd
