dlddldd3lull5uluurd3rurrdlddll4dldrull3urluuluur4d3u3rurrdlddlldll3u3rurd4l3drr3dlddrurrururrdldllrr4uruul4dldldllull3urru3rlld3luulu4rdu3l3drrurd3l3drruuddll6u3r3dl5dlur4ur3u3l6drd3rururrdldllrr4uruul4dldldll3uddll6u3rddrrlluu3l6drrddlu3rururrdldllrr4uruuld3luu3l6drdruudll6u3rdd3r3dldldlrurur3u3luu3l6drddruudrrururrdld3l3r5u3l3urrdldldrrl3uld3l6drddru4r4uruuld3lud3r3dldld3lul6u3rurddldrrluu4l6drd3rururrdld4ldlu5ruuldrd4l4r4uruul4drdluldrd3l
