3rdrrurulrrurrdrddldduuruurllullu3(ld)8luurdld7rd3(dr)d4r3(ur)4u3(lu)4lddrddld9ldlu10ruruulu3(ld)uru3rddld3luururruurrdlu3rdldlrurrdlrrdrddllululrurrdlddrur3dluddlluruuddl3d4luluu4rurld4lddrdrruudrd3lurlluurdu3luu3rdu3luururrdduulldrllddruddu7ldllu8r
