4drdd3ruururrdllu4ldluudrruullddr3d3ruuru4ldl3u4rdullddl3d3ruurullr3d3lddlddr6uruldluuddllddrrlluu5luurdld8r4dlddr6udd3r3u3l3ruulluu3lddrddrdlr7drrul3d4luu3r7udd3r3u3l3ruulluu3lddrddr8d3ldd4ruurul3dlludlluu3r7udd3r3u3l3ruulld3ullddrurdrr5d3lddl5drruuruldl7u6d4rdllu3l3drruuruldl6ud3luululldlluurdld4r
