llrruuludr2(rul3d)ldurrdururulur4uldr3ululldrdl4urddl6dldll6ururldl6drrur6uruulldurrddlddrulddrl4d3l6urrllddrudrllddrulddrdrruulrdd3r5ulr3d4rdrddluld4rulld5ldldd5rurudld5luuru5rurrddlruulldllurd4l3u3rdllu3ldldllddldd3rurrururrudlluludrddldd5ru2(uddllurl)5dldllurul4druul5u3l4drdrlul4u3r5drddlludrruuluurdl4ullul5drrlluurduuluurrdrddlruulur3luururrurrdrddlddr3dlulrruuld3uruululldrlddrurlu3ldrllddrrdrrllulld4luluurdru4ldrru6ruulu4ldlduru4rdrdd6ldlluurlddrrurrdlurrdrurruulu4ld2(duurrdlr)rd3rddld3ld3ludrru4ruruu3ldlduu4rddlullrdrruull
