rurr3drddrrurrd6ldluud8rddldlluuddrruulu4l4rdrddlluuru3lullrdl5r3urdrdd6l3r3druud3rullu4ldlluurd4ruurd3ur4d5ldlu4r3ulurl3drd4lrul5u3rur6drd3lrr6u4l7druul3urulu3rur4drruldlddrd4ldl5uruu3r5drd3lrr6u3lddl5drurrddrud3rullu4l3r6u3lddl4d3rddruru4l3r5dl4urullrr6u4l4d3ulldrurdd
