textures = {
	["bridge-plank-01-front-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0,
		y0 = 0,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["bridge-plank-ice-01-front-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.125,
		y0 = 0,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["bridge-wall-ice-left-01-front-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.25,
		y0 = 0,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["bridge-wall-ice-right-01-front-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.375,
		y0 = 0,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["bridge-wall-left-01-front-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.5,
		y0 = 0,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["bridge-wall-right-01-front-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.625,
		y0 = 0,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["bubble-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.75,
		y0 = 0,
		x1 = 0.015625,
		y1 = 0.015625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 8,
		trimmedheight = 8,
		untrimmedwidth = 8,
		untrimmedheight = 8,
	},
	["bubble-02"] = {
		image = "caveexpress-entity-small",
		x0 = 0.765625,
		y0 = 0,
		x1 = 0.00390625,
		y1 = 0.00390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 2,
		trimmedheight = 2,
		untrimmedwidth = 2,
		untrimmedheight = 2,
	},
	["bubble-04"] = {
		image = "caveexpress-entity-small",
		x0 = 0.765625,
		y0 = 0,
		x1 = 0.00390625,
		y1 = 0.00390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 2,
		trimmedheight = 2,
		untrimmedwidth = 2,
		untrimmedheight = 2,
	},
	["bubble-07"] = {
		image = "caveexpress-entity-small",
		x0 = 0.765625,
		y0 = 0,
		x1 = 0.00390625,
		y1 = 0.00390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 2,
		trimmedheight = 2,
		untrimmedwidth = 2,
		untrimmedheight = 2,
	},
	["bubble-03"] = {
		image = "caveexpress-entity-small",
		x0 = 0.76953125,
		y0 = 0,
		x1 = 0.009765625,
		y1 = 0.009765625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 5,
		trimmedheight = 5,
		untrimmedwidth = 5,
		untrimmedheight = 5,
	},
	["bubble-05"] = {
		image = "caveexpress-entity-small",
		x0 = 0.779296875,
		y0 = 0,
		x1 = 0.01171875,
		y1 = 0.01171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 6,
		trimmedheight = 6,
		untrimmedwidth = 6,
		untrimmedheight = 6,
	},
	["bubble-06"] = {
		image = "caveexpress-entity-small",
		x0 = 0.791015625,
		y0 = 0,
		x1 = 0.01171875,
		y1 = 0.01171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 6,
		trimmedheight = 6,
		untrimmedwidth = 6,
		untrimmedheight = 6,
	},
	["bubble-08"] = {
		image = "caveexpress-entity-small",
		x0 = 0.802734375,
		y0 = 0,
		x1 = 0.0078125,
		y1 = 0.005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 4,
		trimmedheight = 3,
		untrimmedwidth = 4,
		untrimmedheight = 3,
	},
	["bubble-09"] = {
		image = "caveexpress-entity-small",
		x0 = 0.810546875,
		y0 = 0,
		x1 = 0.01171875,
		y1 = 0.01171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 6,
		trimmedheight = 6,
		untrimmedwidth = 6,
		untrimmedheight = 6,
	},
	["cave-sign-01-front-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.822265625,
		y0 = 0,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["cave-sign-02-front-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["cave-sign-03-front-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.125,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["cave-sign-04-front-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.25,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["cave-sign-05-front-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.375,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["cave-sign-06-front-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.5,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["cave-sign-07-front-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.625,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["cavenumber1"] = {
		image = "caveexpress-entity-small",
		x0 = 0.75,
		y0 = 0.125,
		x1 = 0.083984375,
		y1 = 0.046875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 43,
		trimmedheight = 24,
		untrimmedwidth = 43,
		untrimmedheight = 24,
	},
	["cavenumber2"] = {
		image = "caveexpress-entity-small",
		x0 = 0.833984375,
		y0 = 0.125,
		x1 = 0.083984375,
		y1 = 0.046875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 43,
		trimmedheight = 24,
		untrimmedwidth = 43,
		untrimmedheight = 24,
	},
	["cavenumber3"] = {
		image = "caveexpress-entity-small",
		x0 = 0,
		y0 = 0.25,
		x1 = 0.083984375,
		y1 = 0.046875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 43,
		trimmedheight = 24,
		untrimmedwidth = 43,
		untrimmedheight = 24,
	},
	["cavenumber4"] = {
		image = "caveexpress-entity-small",
		x0 = 0.083984375,
		y0 = 0.25,
		x1 = 0.083984375,
		y1 = 0.046875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 43,
		trimmedheight = 24,
		untrimmedwidth = 43,
		untrimmedheight = 24,
	},
	["cavenumber5"] = {
		image = "caveexpress-entity-small",
		x0 = 0.16796875,
		y0 = 0.25,
		x1 = 0.083984375,
		y1 = 0.046875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 43,
		trimmedheight = 24,
		untrimmedwidth = 43,
		untrimmedheight = 24,
	},
	["cavenumber6"] = {
		image = "caveexpress-entity-small",
		x0 = 0.251953125,
		y0 = 0.25,
		x1 = 0.083984375,
		y1 = 0.046875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 43,
		trimmedheight = 24,
		untrimmedwidth = 43,
		untrimmedheight = 24,
	},
	["cavenumber7"] = {
		image = "caveexpress-entity-small",
		x0 = 0.3359375,
		y0 = 0.25,
		x1 = 0.083984375,
		y1 = 0.046875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 43,
		trimmedheight = 24,
		untrimmedwidth = 43,
		untrimmedheight = 24,
	},
	["cavenumber8"] = {
		image = "caveexpress-entity-small",
		x0 = 0.419921875,
		y0 = 0.25,
		x1 = 0.083984375,
		y1 = 0.046875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 43,
		trimmedheight = 24,
		untrimmedwidth = 43,
		untrimmedheight = 24,
	},
	["icon-cavenumber1"] = {
		image = "caveexpress-entity-small",
		x0 = 0.50390625,
		y0 = 0.25,
		x1 = 0.025390625,
		y1 = 0.017578125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 13,
		trimmedheight = 9,
		untrimmedwidth = 13,
		untrimmedheight = 9,
	},
	["icon-cavenumber2"] = {
		image = "caveexpress-entity-small",
		x0 = 0.529296875,
		y0 = 0.25,
		x1 = 0.025390625,
		y1 = 0.017578125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 13,
		trimmedheight = 9,
		untrimmedwidth = 13,
		untrimmedheight = 9,
	},
	["icon-cavenumber3"] = {
		image = "caveexpress-entity-small",
		x0 = 0.5546875,
		y0 = 0.25,
		x1 = 0.025390625,
		y1 = 0.017578125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 13,
		trimmedheight = 9,
		untrimmedwidth = 13,
		untrimmedheight = 9,
	},
	["icon-cavenumber4"] = {
		image = "caveexpress-entity-small",
		x0 = 0.580078125,
		y0 = 0.25,
		x1 = 0.025390625,
		y1 = 0.017578125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 13,
		trimmedheight = 9,
		untrimmedwidth = 13,
		untrimmedheight = 9,
	},
	["icon-cavenumber5"] = {
		image = "caveexpress-entity-small",
		x0 = 0.60546875,
		y0 = 0.25,
		x1 = 0.025390625,
		y1 = 0.017578125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 13,
		trimmedheight = 9,
		untrimmedwidth = 13,
		untrimmedheight = 9,
	},
	["icon-cavenumber6"] = {
		image = "caveexpress-entity-small",
		x0 = 0.630859375,
		y0 = 0.25,
		x1 = 0.025390625,
		y1 = 0.017578125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 13,
		trimmedheight = 9,
		untrimmedwidth = 13,
		untrimmedheight = 9,
	},
	["icon-cavenumber7"] = {
		image = "caveexpress-entity-small",
		x0 = 0.65625,
		y0 = 0.25,
		x1 = 0.025390625,
		y1 = 0.017578125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 13,
		trimmedheight = 9,
		untrimmedwidth = 13,
		untrimmedheight = 9,
	},
	["icon-cavenumber8"] = {
		image = "caveexpress-entity-small",
		x0 = 0.681640625,
		y0 = 0.25,
		x1 = 0.025390625,
		y1 = 0.017578125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 13,
		trimmedheight = 9,
		untrimmedwidth = 13,
		untrimmedheight = 9,
	},
	["icon-targetcave"] = {
		image = "caveexpress-entity-small",
		x0 = 0.70703125,
		y0 = 0.25,
		x1 = 0.01171875,
		y1 = 0.0078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 6,
		trimmedheight = 4,
		untrimmedwidth = 6,
		untrimmedheight = 4,
	},
	["item-apple-idle-front-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.71875,
		y0 = 0.25,
		x1 = 0.04296875,
		y1 = 0.048828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 22,
		trimmedheight = 25,
		untrimmedwidth = 22,
		untrimmedheight = 25,
	},
	["item-banana-idle-front-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.76171875,
		y0 = 0.25,
		x1 = 0.048828125,
		y1 = 0.044921875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 25,
		trimmedheight = 23,
		untrimmedwidth = 25,
		untrimmedheight = 23,
	},
	["item-bomb-idle-front-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.810546875,
		y0 = 0.25,
		x1 = 0.056640625,
		y1 = 0.056640625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 29,
		trimmedheight = 29,
		untrimmedwidth = 29,
		untrimmedheight = 29,
	},
	["item-egg-idle-front-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.8671875,
		y0 = 0.25,
		x1 = 0.04296875,
		y1 = 0.05078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 22,
		trimmedheight = 26,
		untrimmedwidth = 22,
		untrimmedheight = 26,
	},
	["item-package-ice-idle-middle-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.91015625,
		y0 = 0.25,
		x1 = 0.064453125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 33,
		trimmedheight = 32,
		untrimmedwidth = 33,
		untrimmedheight = 32,
	},
	["item-package-idle-middle-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0,
		y0 = 0.3125,
		x1 = 0.064453125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 33,
		trimmedheight = 32,
		untrimmedwidth = 33,
		untrimmedheight = 32,
	},
	["item-stone-idle-front-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.064453125,
		y0 = 0.3125,
		x1 = 0.08203125,
		y1 = 0.0546875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 42,
		trimmedheight = 28,
		untrimmedwidth = 42,
		untrimmedheight = 28,
	},
	["item-stone-idle-front-02"] = {
		image = "caveexpress-entity-small",
		x0 = 0.146484375,
		y0 = 0.3125,
		x1 = 0.08203125,
		y1 = 0.0546875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 42,
		trimmedheight = 28,
		untrimmedwidth = 42,
		untrimmedheight = 28,
	},
	["item-stone-idle-front-03"] = {
		image = "caveexpress-entity-small",
		x0 = 0.228515625,
		y0 = 0.3125,
		x1 = 0.08203125,
		y1 = 0.0546875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 42,
		trimmedheight = 28,
		untrimmedwidth = 42,
		untrimmedheight = 28,
	},
	["liane-01-front-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.310546875,
		y0 = 0.3125,
		x1 = 0.033203125,
		y1 = 0.244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 17,
		trimmedheight = 125,
		untrimmedwidth = 17,
		untrimmedheight = 125,
	},
	["particle-water"] = {
		image = "caveexpress-entity-small",
		x0 = 0.34375,
		y0 = 0.3125,
		x1 = 0.00390625,
		y1 = 0.00390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 2,
		trimmedheight = 2,
		untrimmedwidth = 2,
		untrimmedheight = 2,
	},
	["player-crashed-middle-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.34765625,
		y0 = 0.3125,
		x1 = 0.125,
		y1 = 0.111328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 57,
		untrimmedwidth = 64,
		untrimmedheight = 57,
	},
	["player-flying-middle-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.47265625,
		y0 = 0.3125,
		x1 = 0.125,
		y1 = 0.111328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 57,
		untrimmedwidth = 64,
		untrimmedheight = 57,
	},
	["player-flying-middle-02"] = {
		image = "caveexpress-entity-small",
		x0 = 0.59765625,
		y0 = 0.3125,
		x1 = 0.125,
		y1 = 0.111328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 57,
		untrimmedwidth = 64,
		untrimmedheight = 57,
	},
	["player-flying-middle-03"] = {
		image = "caveexpress-entity-small",
		x0 = 0.72265625,
		y0 = 0.3125,
		x1 = 0.125,
		y1 = 0.111328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 57,
		untrimmedwidth = 64,
		untrimmedheight = 57,
	},
	["rope"] = {
		image = "caveexpress-entity-small",
		x0 = 0.84765625,
		y0 = 0.3125,
		x1 = 0.0625,
		y1 = 0.0078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 32,
		trimmedheight = 4,
		untrimmedwidth = 32,
		untrimmedheight = 4,
	},
	["snow-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.91015625,
		y0 = 0.3125,
		x1 = 0.01171875,
		y1 = 0.01171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 6,
		trimmedheight = 6,
		untrimmedwidth = 6,
		untrimmedheight = 6,
	},
	["sparkle-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.921875,
		y0 = 0.3125,
		x1 = 0.00390625,
		y1 = 0.00390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 2,
		trimmedheight = 2,
		untrimmedwidth = 2,
		untrimmedheight = 2,
	},
	["sparkle-02"] = {
		image = "caveexpress-entity-small",
		x0 = 0.92578125,
		y0 = 0.3125,
		x1 = 0.001953125,
		y1 = 0.001953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 1,
		trimmedheight = 1,
		untrimmedwidth = 1,
		untrimmedheight = 1,
	},
	["sparkle-03"] = {
		image = "caveexpress-entity-small",
		x0 = 0.927734375,
		y0 = 0.3125,
		x1 = 0.00390625,
		y1 = 0.00390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 2,
		trimmedheight = 2,
		untrimmedwidth = 2,
		untrimmedheight = 2,
	},
	["tree-dazed-middle-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0,
		y0 = 0.556640625,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tree-idle-middle-03"] = {
		image = "caveexpress-entity-small",
		x0 = 0,
		y0 = 0.556640625,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tree-idle-middle-01"] = {
		image = "caveexpress-entity-small",
		x0 = 0.25,
		y0 = 0.556640625,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tree-idle-middle-02"] = {
		image = "caveexpress-entity-small",
		x0 = 0.5,
		y0 = 0.556640625,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
}
