#include <miniracer/shared/MiniRacerEntityType.h>

namespace miniracer {

namespace EntityTypes {
EntityType ROAD("road");
EntityType MOVEABLE("moveable");
EntityType LAND("land");
EntityType SOLID("solid");
EntityType DECAL("decal");
EntityType PLAYER("player");
}

}
