drruu4lulld4r3d3luu3dlddr3urrddlruurrddll4rdrru4l3u3rdduulluurrdd4luur3lulld4rdd4ruulul3dld4luu3dlddr3u3r3ur3lulld4rdd4ruululddurrdd4luurl3dlddlruulluu3dlddr3u3ru4ruululddurrdd3lruu4lulld5rlddr3d3l5rdrru6luulluudd3ru4rdd4ululddu4lulld5r4l4dlddr5uddrrddl5rdrru6l5r3u3l3ruululddulldduullulld5r4l4dlddr5uddrrddl6r3u3ldlru3ruululddulldduullulld5r4l4dlddr5u4d4rud3r3u3l3ruululddu4lulld5r4l5d7r3ullrruululdd
