textures = {
	["npc-flying-falling-DIR-middle-01"] = {
		image = "caveexpress-npc_flying-big",
		x0 = 0,
		y0 = 0.873046875,
		x1 = 0.828125,
		y1 = 0.07275390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 106,
		trimmedheight = 149,
		untrimmedwidth = 106,
		untrimmedheight = 149,
	},
	["npc-flying-falling-DIR-middle-02"] = {
		image = "caveexpress-npc_flying-big",
		x0 = 0,
		y0 = 0.80029296875,
		x1 = 0.828125,
		y1 = 0.07275390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 106,
		trimmedheight = 149,
		untrimmedwidth = 106,
		untrimmedheight = 149,
	},
	["npc-flying-falling-DIR-middle-03"] = {
		image = "caveexpress-npc_flying-big",
		x0 = 0,
		y0 = 0.7275390625,
		x1 = 0.828125,
		y1 = 0.07275390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 106,
		trimmedheight = 149,
		untrimmedwidth = 106,
		untrimmedheight = 149,
	},
	["npc-flying-falling-DIR-middle-04"] = {
		image = "caveexpress-npc_flying-big",
		x0 = 0,
		y0 = 0.65478515625,
		x1 = 0.828125,
		y1 = 0.07275390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 106,
		trimmedheight = 149,
		untrimmedwidth = 106,
		untrimmedheight = 149,
	},
	["npc-flying-falling-DIR-middle-05"] = {
		image = "caveexpress-npc_flying-big",
		x0 = 0,
		y0 = 0.58203125,
		x1 = 0.828125,
		y1 = 0.07275390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 106,
		trimmedheight = 149,
		untrimmedwidth = 106,
		untrimmedheight = 149,
	},
	["npc-flying-flying-DIR-middle-01"] = {
		image = "caveexpress-npc_flying-big",
		x0 = 0,
		y0 = 0.50927734375,
		x1 = 0.828125,
		y1 = 0.07275390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 106,
		trimmedheight = 149,
		untrimmedwidth = 106,
		untrimmedheight = 149,
	},
	["npc-flying-flying-DIR-middle-02"] = {
		image = "caveexpress-npc_flying-big",
		x0 = 0,
		y0 = 0.4365234375,
		x1 = 0.828125,
		y1 = 0.07275390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 106,
		trimmedheight = 149,
		untrimmedwidth = 106,
		untrimmedheight = 149,
	},
	["npc-flying-flying-DIR-middle-03"] = {
		image = "caveexpress-npc_flying-big",
		x0 = 0,
		y0 = 0.36376953125,
		x1 = 0.828125,
		y1 = 0.07275390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 106,
		trimmedheight = 149,
		untrimmedwidth = 106,
		untrimmedheight = 149,
	},
	["npc-flying-flying-DIR-middle-04"] = {
		image = "caveexpress-npc_flying-big",
		x0 = 0,
		y0 = 0.291015625,
		x1 = 0.828125,
		y1 = 0.07275390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 106,
		trimmedheight = 149,
		untrimmedwidth = 106,
		untrimmedheight = 149,
	},
	["npc-flying-flying-DIR-middle-05"] = {
		image = "caveexpress-npc_flying-big",
		x0 = 0,
		y0 = 0.21826171875,
		x1 = 0.828125,
		y1 = 0.07275390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 106,
		trimmedheight = 149,
		untrimmedwidth = 106,
		untrimmedheight = 149,
	},
	["npc-flying-flying-DIR-middle-06"] = {
		image = "caveexpress-npc_flying-big",
		x0 = 0,
		y0 = 0.1455078125,
		x1 = 0.828125,
		y1 = 0.07275390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 106,
		trimmedheight = 149,
		untrimmedwidth = 106,
		untrimmedheight = 149,
	},
	["npc-flying-flying-DIR-middle-07"] = {
		image = "caveexpress-npc_flying-big",
		x0 = 0,
		y0 = 0.07275390625,
		x1 = 0.828125,
		y1 = 0.07275390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 106,
		trimmedheight = 149,
		untrimmedwidth = 106,
		untrimmedheight = 149,
	},
	["npc-flying-flying-DIR-middle-08"] = {
		image = "caveexpress-npc_flying-big",
		x0 = 0,
		y0 = 0,
		x1 = 0.828125,
		y1 = 0.07275390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 106,
		trimmedheight = 149,
		untrimmedwidth = 106,
		untrimmedheight = 149,
	},
}
