textures = {
	["tile-background-01-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0,
		y0 = 0.6875,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-background-02-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0,
		y0 = 0.625,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-background-03-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0,
		y0 = 0.5625,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-background-04-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0,
		y0 = 0.5,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-background-big-01-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0.5,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-background-cave-art-01-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0.875,
		y0 = 0.4375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-background-window-01-off"] = {
		image = "caveexpress-environment-small",
		x0 = 0.75,
		y0 = 0.4375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-background-window-01-on"] = {
		image = "caveexpress-environment-small",
		x0 = 0.625,
		y0 = 0.4375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-background-window-02-off"] = {
		image = "caveexpress-environment-small",
		x0 = 0.5,
		y0 = 0.4375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-background-window-02-on"] = {
		image = "caveexpress-environment-small",
		x0 = 0.375,
		y0 = 0.4375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-cave-01-off"] = {
		image = "caveexpress-environment-small",
		x0 = 0.25,
		y0 = 0.4375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-cave-01-on"] = {
		image = "caveexpress-environment-small",
		x0 = 0.125,
		y0 = 0.4375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-cave-02-off"] = {
		image = "caveexpress-environment-small",
		x0 = 0,
		y0 = 0.4375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-cave-02-on"] = {
		image = "caveexpress-environment-small",
		x0 = 0.875,
		y0 = 0.375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-geyser-rock-01-active-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0.25,
		y0 = 0.25,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 128,
		untrimmedwidth = 64,
		untrimmedheight = 128,
	},
	["tile-geyser-rock-01-active-back-02"] = {
		image = "caveexpress-environment-small",
		x0 = 0.125,
		y0 = 0.25,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 128,
		untrimmedwidth = 64,
		untrimmedheight = 128,
	},
	["tile-geyser-rock-01-active-back-03"] = {
		image = "caveexpress-environment-small",
		x0 = 0,
		y0 = 0.25,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 128,
		untrimmedwidth = 64,
		untrimmedheight = 128,
	},
	["tile-geyser-rock-01-active-back-04"] = {
		image = "caveexpress-environment-small",
		x0 = 0.875,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 128,
		untrimmedwidth = 64,
		untrimmedheight = 128,
	},
	["tile-geyser-rock-01-active-back-05"] = {
		image = "caveexpress-environment-small",
		x0 = 0.75,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 128,
		untrimmedwidth = 64,
		untrimmedheight = 128,
	},
	["tile-geyser-rock-01-active-back-06"] = {
		image = "caveexpress-environment-small",
		x0 = 0.625,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 128,
		untrimmedwidth = 64,
		untrimmedheight = 128,
	},
	["tile-geyser-rock-01-idle-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0.5,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 128,
		untrimmedwidth = 64,
		untrimmedheight = 128,
	},
	["tile-geyser-rock-01-idle-back-02"] = {
		image = "caveexpress-environment-small",
		x0 = 0.375,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 128,
		untrimmedwidth = 64,
		untrimmedheight = 128,
	},
	["tile-geyser-rock-01-idle-back-03"] = {
		image = "caveexpress-environment-small",
		x0 = 0.25,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 128,
		untrimmedwidth = 64,
		untrimmedheight = 128,
	},
	["tile-geyser-rock-01-idle-back-04"] = {
		image = "caveexpress-environment-small",
		x0 = 0.375,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 128,
		untrimmedwidth = 64,
		untrimmedheight = 128,
	},
	["tile-ground-01-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0.75,
		y0 = 0.375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-ground-02-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0.625,
		y0 = 0.375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-ground-03-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0.5,
		y0 = 0.375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-ground-04-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0.375,
		y0 = 0.375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-ground-05-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0.25,
		y0 = 0.375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-ground-06-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0.125,
		y0 = 0.375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-ground-ledge-DIR-01-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0,
		y0 = 0.375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-ground-ledge-DIR-02-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0.875,
		y0 = 0.3125,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-lava-rock-DIR-01-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0.75,
		y0 = 0.3125,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-lava-rock-DIR-01-back-02"] = {
		image = "caveexpress-environment-small",
		x0 = 0.625,
		y0 = 0.3125,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-reference"] = {
		image = "caveexpress-environment-small",
		x0 = 0.75,
		y0 = 0.375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-rock-01-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0.5,
		y0 = 0.3125,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-rock-02-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0.375,
		y0 = 0.3125,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-rock-03-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0.875,
		y0 = 0.25,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-rock-DIR-04-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0.75,
		y0 = 0.25,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-rock-big-01-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0.25,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-rock-big-02-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-rock-shim-01-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0.625,
		y0 = 0.25,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-rock-slope-DIR-01-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0.5,
		y0 = 0.25,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-rock-slope-DIR-02-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0.375,
		y0 = 0.25,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-waterfall-01-back-01"] = {
		image = "caveexpress-environment-small",
		x0 = 0.125,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 128,
		untrimmedwidth = 64,
		untrimmedheight = 128,
	},
	["tile-waterfall-01-back-02"] = {
		image = "caveexpress-environment-small",
		x0 = 0,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 128,
		untrimmedwidth = 64,
		untrimmedheight = 128,
	},
	["tile-waterfall-01-back-03"] = {
		image = "caveexpress-environment-small",
		x0 = 0.875,
		y0 = 0,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 128,
		untrimmedwidth = 64,
		untrimmedheight = 128,
	},
	["tile-waterfall-01-back-04"] = {
		image = "caveexpress-environment-small",
		x0 = 0.75,
		y0 = 0,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 128,
		untrimmedwidth = 64,
		untrimmedheight = 128,
	},
}
