ld3luu5ldd7ru3r5d3lulu5lud5rdrd3r5u3ldlluu5lddrdd3rdru4luuluu5rddrru3r5d4ldluud5r5u3lddrulurrld3luu5ldd6r5l5dldrurrddluruldl5ud3rdrdrrulu4l4rddlud5r4uruuldllddlulluu5ldd3rll5dldrurrddluruldl5ud3rdrru4l3rdd5r4uruuldlld3luu5lddrrl5dldrurrddluruldl5ud4rdd5r4uruuldlld3luu5lddrluu5rdd3ruuldrdllru7rddlur3dlu3luuru3luldrdl
