u10l3(dl)4drrd8r4d4r7ur3ullrr3dl7d4l4ur2(rdl3u)rduruurr3dl7d4l3ur4u8ldldd6rdru7luuru6rurdr3d5ldrru3r3ururuurr3dl7d4l3ur4u8ldlddrrdrrurrdru3ldrr4lulluuru4rurd3r3d3l3r3ururuurr3dl7d4l3ur4u8ldlddrrd5r5lulld4rulrdrruld5l3ururrurd5r3dllrr3ururuurr3dl7d4l3ur4u8ldl3d7rurld7l3uru9ruruurr3dl7d4l3u8l3uruuruu9rddld6luld3r2(ulld4r)ull3ruu9lddld3r2(ulrdrr)ul4ruu9ldd2(ld4rul)l6ruu9lddld4rull8ruu9lddlddl3d9ruuruuddlddllur4drruldl3u8l3ururrl3u9rdd8l8ruu9lddlddlddruu3drruld3r2(ulld4r)ullr4d4ru3ldl3ul3(urd3l)urlluurd3l4u3(ru)10rdd9lddlduldduurruu9ruu10l3(dl)4drr3u11ruudd8ldlull5d10r4u4d10l5urruu9rdd8l7r5d10luull4u3(ru)10rdd9lddll5d8rdd4r6ur3ul
