4u3ru3rdrrlu4luu5rdrurdr3dlddlluuddrruuluuddrr3ulu7ldd3rdrrlu4luu7rdr3dlddlluu3r3ulu7ldd3r3drd3ruulullrdrrddllulluuru3lrr3drru3r3ulu7lddrd4l3r3u5rd2(rddll)uuru3lrr3drd3ruul4u6ldd3r3drru3r3ulul3dllrddlluuru3ld3lul6dldr6u4rurr3drd3ruul4u6ldd3r3drru3ruululddllrddlluuru3ld3lul6drdl6u4rurrd3rurrddll4u6lddrd3luld3ru3r3drrurullrddlluuru3lrrd3r3u6lddrd3lulldr5dllddrulurdr6urul6drrdlrddluuruldl6u5dllddrulurdr4u
