textures = {
	["npc-man-falling-middle-01"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0,
		y0 = 0.609375,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-falling-middle-02"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.609375,
		y0 = 0.533203125,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-falling-middle-03"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.40625,
		y0 = 0.533203125,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-falling-middle-04"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.203125,
		y0 = 0.533203125,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-falling-middle-05"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0,
		y0 = 0.533203125,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-idle-middle-01"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.609375,
		y0 = 0.45703125,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-idle-middle-02"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.40625,
		y0 = 0.45703125,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-idle-middle-03"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.203125,
		y0 = 0.45703125,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-idle-middle-04"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0,
		y0 = 0.45703125,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-swimming-idle-middle-01"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.609375,
		y0 = 0.380859375,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-swimming-idle-middle-02"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.40625,
		y0 = 0.380859375,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-swimming-idle-middle-03"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.203125,
		y0 = 0.380859375,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-swimming-idle-middle-04"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0,
		y0 = 0.380859375,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-swimming-left-middle-01"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.609375,
		y0 = 0.3046875,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-swimming-left-middle-02"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.40625,
		y0 = 0.3046875,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-swimming-left-middle-03"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.203125,
		y0 = 0.3046875,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-swimming-right-middle-01"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0,
		y0 = 0.3046875,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-swimming-right-middle-02"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.609375,
		y0 = 0.228515625,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-swimming-right-middle-03"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.40625,
		y0 = 0.228515625,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-walk-left-middle-01"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.203125,
		y0 = 0.228515625,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-walk-left-middle-02"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0,
		y0 = 0.228515625,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-walk-left-middle-03"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.609375,
		y0 = 0.15234375,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-walk-left-middle-04"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.40625,
		y0 = 0.15234375,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-walk-left-middle-05"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.203125,
		y0 = 0.15234375,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-walk-left-middle-06"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0,
		y0 = 0.15234375,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-walk-left-middle-07"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.609375,
		y0 = 0.076171875,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-walk-right-middle-01"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.40625,
		y0 = 0.076171875,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-walk-right-middle-02"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.203125,
		y0 = 0.076171875,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-walk-right-middle-03"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0,
		y0 = 0.076171875,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-walk-right-middle-04"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.609375,
		y0 = 0,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-walk-right-middle-05"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.40625,
		y0 = 0,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-walk-right-middle-06"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0.203125,
		y0 = 0,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
	["npc-man-walk-right-middle-07"] = {
		image = "caveexpress-npc_man-small",
		x0 = 0,
		y0 = 0,
		x1 = 0.203125,
		y1 = 0.076171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 39,
		untrimmedwidth = 52,
		untrimmedheight = 39,
	},
}
