d3ldldlddrrd3rdrr4urr3d5uruu2(l4dl)lu3lulluururu6r6ldldlddrrd3rdrr4uludrddlur3dlluluurrllddlluurdrdlul3drdl4ullu3(ur)rdl3drdlul3dlddur4ullu3(ur)4drdrdrruulullddlul3drddu3lulddrdruur4ulluururrddrdlu3ru3ruu3lddullul3dl4drd3lrr3urrulul4drdlluldrr3u3rdrr3u3lrruu3lddrdl3uruurd4rddllrruuruuldrd4lddullul3dl4drdllr3urrul3uruurdrdllul3dl4drdl3urruldrrdrrdruruldl3u3lrr3u3rddllrru2(u3ldd)l4dlddlurr3urruldrrd6ru3ldl3u3lrr3u3r4duullrru2(u3ldd)l4drdllulddurr3urruldrrd6ruuldlldl3u3lrr3u3r4duullrru2(u3ldd)l4drdlluldrr3urruldrrd5rulldl3u3lrr3u3rddllrru2(u3ldd)l4drdllr3urruldrrd8rurrd7ldl4u3lrruu3lddl4drdl3urrul4u6rddllrruu3lddrd3lrruu3lddl4dldr3urrulul4d
