ur3u3rdrr4uldr3uld3lu7l7drd5l4r8u3rdllul7drd4l3r8u5rd4lul7drd3l6r5u3l3r3drrul4rdrr5u5l3d3u5r5dllu3l4u4lull6drd5l4r4u4r3drruldd8l3r7urrdlul5duu4r3du5rdrru6ldd7l3ru5l4r3u4rdd7ruuldrd6ld8l3r3u4rdd6ruuldrd5ld7lrr3u4rddrr4u3r3drd5ld6lr3u4r3drr5u4r3drd6ldd6lr4u4r4drd6l
