rdurdrrullruuldrdd3luurrldu3ldldlruruu3(ld)l3(ru)u4(ld)uru4r3(dl)ruruu3rdrrdrrullu3lrddrurr3dlluuddrruul3urdlddrddlururulu3lu3lddru3r4luuldld3rlddluruulldrdrrurrlulddllur3ldrrddluulurdlldrrddluulldruurdrddlu
