d3r4urll3u2(rrdd)lul3ullddr4drd7ldl3uruulldrurdl3d7r4urudrrulldll3urrddrdl3ullddrluurrddl3dlurddrd7ldl4ulull3u4r4(dr)rdrdd7l3uru3lrr4d7ruulul4(lu)5l4druuluu5r4(dr)rururuull3dr3drd7ldl4ulu3l3u5r4(dr)rdrdd7l3uru3lrr4d7ruuluur3drd7ldl4u3d7r5urrdlul4duu3l3(ul)u5lddrul3drurrdr3d7r7l3urrdlulddld6r5l3uluur4dld5r4l4u4luurdld3rur4dld4r3l4u4l4ur3dld3rur4dld3r
