-- create a new campaign
local c = Campaign.new("rock")
-- set an ingame icon for this campaign
c:setSetting("icon", "icon-campaign-rock")
-- set the on screen message when this campaign is activated
c:setSetting("text", "Rock Campaign")
-- now add all maps
c:addMaps("rock-01")
c:addMaps("rock-02")
c:addMaps("rock-03")
c:addMaps("rock-04")
c:addMaps("rock-05")
c:addMaps("rock-06")
c:addMaps("rock-07")
c:addMaps("rock-08")
c:addMaps("rock-09")
c:addMaps("rock-10")
c:addMaps("rock-11")
c:addMaps("rock-12")
c:addMaps("rock-13")
c:addMaps("rock-14")
c:addMaps("rock-15")
c:addMaps("rock-16")
c:addMaps("rock-17")
